@@ -23,25 +23,10 @@ import java.util.Iterator;
 import java.util.List;
 
 import javax.persistence.EntityExistsException;
-import javax.persistence.EntityManager;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
-import com.clustercontrol.fault.HinemosUnknown;
-import com.clustercontrol.fault.PrivilegeDuplicate;
-import com.clustercontrol.fault.PrivilegeNotFound;
-import com.clustercontrol.fault.RoleNotFound;
-import com.clustercontrol.fault.RoleDuplicate;
-import com.clustercontrol.fault.UnEditableRole;
-import com.clustercontrol.fault.UsedObjectPrivilege;
-import com.clustercontrol.fault.UsedRole;
-import com.clustercontrol.fault.UserNotFound;
-import com.clustercontrol.jobmanagement.model.JobFileCheckEntity;
-import com.clustercontrol.jobmanagement.model.JobMstEntity;
-import com.clustercontrol.jobmanagement.model.JobScheduleEntity;
-import com.clustercontrol.monitor.run.model.MonitorInfoEntity;
-import com.clustercontrol.notify.model.NotifyInfoEntity;
 import com.clustercontrol.accesscontrol.bean.ObjectPrivilegeInfo;
 import com.clustercontrol.accesscontrol.bean.PrivilegeConstant.ObjectPrivilegeMode;
 import com.clustercontrol.accesscontrol.bean.RoleIdConstant;
@@ -60,7 +45,22 @@ import com.clustercontrol.accesscontrol.util.ObjectPrivilegeUtil;
 import com.clustercontrol.accesscontrol.util.QueryUtil;
 import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.calendar.model.CalInfoEntity;
+import com.clustercontrol.commons.util.HinemosEntityManager;
 import com.clustercontrol.commons.util.JpaTransactionManager;
+import com.clustercontrol.fault.HinemosUnknown;
+import com.clustercontrol.fault.PrivilegeDuplicate;
+import com.clustercontrol.fault.PrivilegeNotFound;
+import com.clustercontrol.fault.RoleDuplicate;
+import com.clustercontrol.fault.RoleNotFound;
+import com.clustercontrol.fault.UnEditableRole;
+import com.clustercontrol.fault.UsedObjectPrivilege;
+import com.clustercontrol.fault.UsedRole;
+import com.clustercontrol.fault.UserNotFound;
+import com.clustercontrol.jobmanagement.model.JobFileCheckEntity;
+import com.clustercontrol.jobmanagement.model.JobMstEntity;
+import com.clustercontrol.jobmanagement.model.JobScheduleEntity;
+import com.clustercontrol.monitor.run.model.MonitorInfoEntity;
+import com.clustercontrol.notify.model.NotifyInfoEntity;
 
 /**
  * ロール情報を更新するファクトリクラス<BR>
@@ -129,7 +129,7 @@ public class RoleModifier {
 	 */
 	public static void deleteRoleInfo(String roleId, String modifyUserId) throws RoleNotFound, UnEditableRole, UsedRole, HinemosUnknown {
 
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 
 		if(roleId != null && roleId.compareTo("") != 0 && modifyUserId != null && modifyUserId.compareTo("") != 0){
 			try {
@@ -227,11 +227,6 @@ public class RoleModifier {
 			// ロール情報の取得
 			roleEntity = QueryUtil.getRolePK(roleId);
 
-			// ALL_USERSロールは割り当て変更不可
-			if (roleEntity != null && roleEntity.getRoleId().equals(RoleIdConstant.ALL_USERS)) {
-				throw new UnEditableRole();
-			}
-			
 			//システムロールである場合、システムユーザ（hinemos）が含まれてない場合は変更不可
 			if (roleEntity != null && (roleEntity.getRoleType().equals(RoleTypeConstant.SYSTEM_ROLE))) {
 				boolean existsFlg = false;
@@ -275,7 +270,7 @@ public class RoleModifier {
 			Iterator<UserEntity> userIter = userEntities.iterator();
 			while(userIter.hasNext()) {
 				UserEntity entity = userIter.next();
-				if (notDelPkList == null 
+				if (notDelPkList == null
 						|| notDelPkList.size() == 0
 						|| !notDelPkList.contains(entity.getUserId())) {
 					delPkList.add(entity.getUserId());
@@ -284,7 +279,7 @@ public class RoleModifier {
 			}
 			roleEntity.setUserEntities(userEntities);
 
-			
+
 			// ユーザの修正
 			// ユーザへのロールの追加
 			for (String userId : addPkList) {
@@ -352,14 +347,14 @@ public class RoleModifier {
 			if (roleEntity != null && roleEntity.getRoleId().equals(RoleIdConstant.ADMINISTRATORS)) {
 				throw new UnEditableRole();
 			}
-			
+
 			List<SystemPrivilegeEntityPK> systemPrivilegeEntityPkList = new ArrayList<SystemPrivilegeEntityPK>();
-			
+
 			if (systemPrivileges != null && systemPrivileges.size() > 0) {
 				for (SystemPrivilegeInfo systemPrivilegeInfo : systemPrivileges) {
 					SystemPrivilegeEntityPK entityPk = new SystemPrivilegeEntityPK(
-							roleId, 
-							systemPrivilegeInfo.getSystemFunction(), 
+							roleId,
+							systemPrivilegeInfo.getSystemFunction(),
 							systemPrivilegeInfo.getSystemPrivilege());
 					try {
 						QueryUtil.getSystemPrivilegePK(entityPk);
@@ -397,7 +392,7 @@ public class RoleModifier {
 			throws PrivilegeDuplicate, UsedObjectPrivilege, HinemosUnknown {
 
 		JpaTransactionManager jtm = new JpaTransactionManager();
-		EntityManager em = jtm.getEntityManager();
+		HinemosEntityManager em = jtm.getEntityManager();
 
 		try {
 			// 現在日時を取得
@@ -419,6 +414,9 @@ public class RoleModifier {
 			// 更新対象オブジェクトのオーナーロールIDを取得しておく
 			ObjectPrivilegeTargetEntity objectPrivilegeTargetEntity
 			= (ObjectPrivilegeTargetEntity)ObjectPrivilegeUtil.getObjectPrivilegeObject(objectType, objectId, ObjectPrivilegeMode.READ);
+			if (objectPrivilegeTargetEntity == null) {
+				m_log.warn("unknown object : objectType=" + objectType + ", objectId=" + objectId);
+			}
 			String ownerRoleId = objectPrivilegeTargetEntity.getOwnerRoleId();
 			if(list != null
 					&& list.size() > 0
@@ -474,7 +472,7 @@ public class RoleModifier {
 								referObjectType = HinemosModuleConstant.MONITOR;
 								break;
 							}
-							
+
 							// ジョブ
 							referList = em.createNamedQuery("JobMstEntity.findByFacilityIdOwnerRoleId", JobMstEntity.class)
 									.setParameter("objectId", objectId)
@@ -484,7 +482,7 @@ public class RoleModifier {
 								referObjectType = HinemosModuleConstant.JOB;
 								break;
 							}
-							
+
 							// ファイルチェック
 							referList = em.createNamedQuery("JobFileCheckEntity.findByFacilityIdOwnerRoleId", JobFileCheckEntity.class)
 									.setParameter("objectId", objectId)
@@ -494,7 +492,7 @@ public class RoleModifier {
 								referObjectType = HinemosModuleConstant.JOB_FILE_CHECK;
 								break;
 							}
-							
+
 							// 通知（ログエスカレーション）
 							referList = em.createNamedQuery("NotifyInfoEntity.findByEscalateFacilityIdOwnerRoleId", NotifyInfoEntity.class)
 									.setParameter("objectId", objectId)
@@ -504,7 +502,7 @@ public class RoleModifier {
 								referObjectType = HinemosModuleConstant.PLATFORM_NOTIFY;
 								break;
 							}
-							
+
 							// 通知（ジョブ）
 							referList = em.createNamedQuery("NotifyInfoEntity.findByExecFacilityIdOwnerRoleId", NotifyInfoEntity.class)
 									.setParameter("objectId", objectId)
@@ -527,7 +525,7 @@ public class RoleModifier {
 								referObjectType = HinemosModuleConstant.JOB_FILE_CHECK;
 								break;
 							}
-							
+
 							// スケジュール
 							referList = em.createNamedQuery("JobScheduleEntity.findByJobUnitIdOwnerRoleId", JobScheduleEntity.class)
 									.setParameter("objectId", objectId)
@@ -537,7 +535,7 @@ public class RoleModifier {
 								referObjectType = HinemosModuleConstant.JOB_SCHEDULE;
 								break;
 							}
-							
+
 							// 通知（ジョブ）
 							referList = em.createNamedQuery("NotifyInfoEntity.findByJobUnitIdOwnerRoleId", NotifyInfoEntity.class)
 									.setParameter("objectId", objectId)
@@ -547,7 +545,7 @@ public class RoleModifier {
 								referObjectType = HinemosModuleConstant.PLATFORM_NOTIFY;
 								break;
 							}
-						
+
 						} else if (HinemosModuleConstant.PLATFORM_CALENDAR.equals(objectType)) {
 							/*
 							 *  カレンダの場合
@@ -561,7 +559,7 @@ public class RoleModifier {
 								referObjectType = HinemosModuleConstant.MONITOR;
 								break;
 							}
-							
+
 							// ジョブ
 							referList = em.createNamedQuery("JobMstEntity.findByCalendarIdOwnerRoleId", JobMstEntity.class)
 									.setParameter("objectId", objectId)
@@ -571,7 +569,7 @@ public class RoleModifier {
 								referObjectType = HinemosModuleConstant.JOB;
 								break;
 							}
-							
+
 							// ファイルチェック
 							referList = em.createNamedQuery("JobFileCheckEntity.findByCalendarIdOwnerRoleId", JobFileCheckEntity.class)
 									.setParameter("objectId", objectId)
@@ -581,7 +579,7 @@ public class RoleModifier {
 								referObjectType = HinemosModuleConstant.JOB_FILE_CHECK;
 								break;
 							}
-							
+
 							// スケジュール
 							referList = em.createNamedQuery("JobScheduleEntity.findByCalendarIdOwnerRoleId", JobScheduleEntity.class)
 									.setParameter("objectId", objectId)
@@ -591,8 +589,8 @@ public class RoleModifier {
 								referObjectType = HinemosModuleConstant.JOB_SCHEDULE;
 								break;
 							}
-							
-							
+
+
 						} else if (HinemosModuleConstant.PLATFORM_CALENDAR_PATTERN.equals(objectType)) {
 							/*
 							 * カレンダパターンの場合
@@ -606,7 +604,7 @@ public class RoleModifier {
 								referObjectType = HinemosModuleConstant.PLATFORM_CALENDAR;
 								break;
 							}
-							
+
 						} else if (HinemosModuleConstant.PLATFORM_NOTIFY.equals(objectType)) {
 							/*
 							 *  通知の場合
@@ -620,7 +618,7 @@ public class RoleModifier {
 								referObjectType = HinemosModuleConstant.MONITOR;
 								break;
 							}
-							
+
 							// ジョブ
 							referList = em.createNamedQuery("JobMstEntity.findByNotifyIdOwnerRoleId", JobMstEntity.class)
 									.setParameter("objectId", objectId)
@@ -630,7 +628,7 @@ public class RoleModifier {
 								referObjectType = HinemosModuleConstant.JOB;
 								break;
 							}
-							
+
 						} else if (HinemosModuleConstant.PLATFORM_MAIL_TEMPLATE.equals(objectType)) {
 							/*
 							 *  メールテンプレート
@@ -641,7 +639,7 @@ public class RoleModifier {
 									.setParameter("ownerRoleId", deletePk.getRoleId())
 									.getResultList();
 							referObjectType = HinemosModuleConstant.PLATFORM_NOTIFY;
-						} 
+						}
 					}
 					ObjectPrivilegeEntity deleteEntity = null;
 					try {
@@ -663,12 +661,13 @@ public class RoleModifier {
 			}
 
 		} catch (UsedObjectPrivilege e) {
-			m_log.info("replaceObjectPrivilegeInfo() failure to add a entity.");
+			m_log.debug("replaceObjectPrivilegeInfo() failure to add a entity. " + e.getMessage());
 			throw e;
 		} catch (EntityExistsException e) {
-			m_log.info("replaceObjectPrivilegeInfo() failure to add a entity.");
+			m_log.debug("replaceObjectPrivilegeInfo() failure to add a entity. " + e.getMessage());
 			throw new PrivilegeDuplicate(e.getMessage(), e);
 		} catch (Exception e) {
+			m_log.warn("replaceObjectPrivilegeInfo() failure to add a entity. " + e.getMessage(), e);
 			throw new HinemosUnknown(e.getMessage(), e);
 		}
 		m_log.info("successful in modifing a entity.");
