@@ -15,18 +15,15 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.accesscontrol.view;
 
-import org.eclipse.jface.action.ActionContributionItem;
-import org.eclipse.jface.action.IMenuListener;
-import org.eclipse.jface.action.IMenuManager;
-import org.eclipse.jface.action.IToolBarManager;
 import org.eclipse.jface.action.MenuManager;
-import org.eclipse.jface.action.Separator;
 import org.eclipse.jface.viewers.ISelection;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Menu;
+import org.eclipse.ui.PlatformUI;
+import org.eclipse.ui.commands.ICommandService;
 
 import com.clustercontrol.accesscontrol.composite.UserListComposite;
 import com.clustercontrol.accesscontrol.composite.action.UserListSelectionChangedListener;
@@ -34,24 +31,29 @@ import com.clustercontrol.accesscontrol.view.action.ModifyPasswordAction;
 import com.clustercontrol.accesscontrol.view.action.UserAddAction;
 import com.clustercontrol.accesscontrol.view.action.UserDeleteAction;
 import com.clustercontrol.accesscontrol.view.action.UserModifyAction;
+import com.clustercontrol.accesscontrol.view.action.UserRefreshAction;
 import com.clustercontrol.bean.Property;
+import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.view.CommonViewPart;
 
 /**
  * アクセス[ユーザ]ビュークラス<BR>
- * 
+ *
  * クライアントの画面を構成します。
- * 
- * @version 2.0.0
+ *
+ * @version 5.0.0
  * @since 2.0.0
  */
 public class UserListView extends CommonViewPart {
 	/** ビューID */
-	public static final String ID = "com.clustercontrol.accesscontrol.view.UserListView";
+	public static final String ID = UserListView.class.getName();
 
 	/** アクセス[ユーザ]ビュー用のコンポジット */
 	private UserListComposite m_userList = null;
 
+	/** 選択レコード数 */
+	private int rowNum = 0;
+
 	/**
 	 * コンストラクタ
 	 */
@@ -61,9 +63,9 @@ public class UserListView extends CommonViewPart {
 
 	/**
 	 * ビューを構築します。
-	 * 
+	 *
 	 * @param parent 親コンポジット
-	 * 
+	 *
 	 * @see org.eclipse.ui.IWorkbenchPart#createPartControl(org.eclipse.swt.widgets.Composite)
 	 * @see #createContextMenu()
 	 * @see #update()
@@ -76,6 +78,7 @@ public class UserListView extends CommonViewPart {
 		layout.marginWidth = 0;
 
 		m_userList = new UserListComposite(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, null, m_userList);
 		GridData gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.verticalAlignment = GridData.FILL;
@@ -96,60 +99,23 @@ public class UserListView extends CommonViewPart {
 
 	/**
 	 * コンテキストメニューを作成します。
-	 * 
+	 *
 	 * @see org.eclipse.jface.action.MenuManager
 	 * @see org.eclipse.swt.widgets.Menu
 	 */
 	private void createContextMenu() {
 		MenuManager menuManager = new MenuManager();
 		menuManager.setRemoveAllWhenShown(true);
-		menuManager.addMenuListener(new IMenuListener() {
-			/* (non-Javadoc)
-			 * @see org.eclipse.jface.action.IMenuListener#menuAboutToShow(org.eclipse.jface.action.IMenuManager)
-			 */
-			@Override
-			public void menuAboutToShow(IMenuManager manager) {
-				//メニュー項目設定
-				fillContextMenu(manager);
-			}
-		});
 
 		Menu menu = menuManager.createContextMenu(m_userList.getTable());
+		WidgetTestUtil.setTestId(this, null, menu);
 		m_userList.getTable().setMenu(menu);
-	}
-
-	/**
-	 * コンテキストメニューに項目を追加します。
-	 * 
-	 * @param manager メニューマネージャ
-	 * 
-	 * @see org.eclipse.jface.action.IToolBarManager
-	 * @see org.eclipse.jface.action.IMenuManager
-	 */
-	private void fillContextMenu(IMenuManager manager) {
-		//ビューのアクションのインスタンスを取得
-		IToolBarManager toolbar =
-				this.getViewSite().getActionBars().getToolBarManager();
-		ActionContributionItem userAdd =
-				(ActionContributionItem) toolbar.find(UserAddAction.ID);
-		ActionContributionItem userModify =
-				(ActionContributionItem) toolbar.find(UserModifyAction.ID);
-		ActionContributionItem userDelete =
-				(ActionContributionItem) toolbar.find(UserDeleteAction.ID);
-		ActionContributionItem modifyPassword =
-				(ActionContributionItem) toolbar.find(ModifyPasswordAction.ID);
-
-		//ポップアップメニューにアクションを追加
-		manager.add(userAdd.getAction());
-		manager.add(userModify.getAction());
-		manager.add(userDelete.getAction());
-		manager.add(new Separator());
-		manager.add(modifyPassword.getAction());
+		getSite().registerContextMenu( menuManager, m_userList.getTableViewer() );
 	}
 
 	/**
 	 * ビューを更新します。
-	 * 
+	 *
 	 * @see com.clustercontrol.accesscontrol.composite.UserListComposite#update()
 	 * @see com.clustercontrol.accesscontrol.composite.UserListComposite#update(Property)
 	 */
@@ -159,33 +125,43 @@ public class UserListView extends CommonViewPart {
 
 	/**
 	 * アクセス[ユーザ]ビュー用のコンポジットを返します。
-	 * 
+	 *
 	 * @return アクセス[ユーザ]ビュー用のコンポジット
 	 */
 	public UserListComposite getComposite() {
 		return m_userList;
 	}
 
+	/**
+	 * 選択レコード数を返します。
+	 * @return rowNum
+	 */
+	public int getSelectedNum(){
+		return this.rowNum;
+	}
+
 	/**
 	 * ビューのアクションの有効/無効を設定します。
-	 * 
+	 *
 	 * @param num 選択イベント数
 	 * @param selection ボタン（アクション）を有効にするための情報
 	 */
 	public void setEnabledAction(int num, ISelection selection) {
-		//ビューアクションの使用可/不可を設定
-		super.setEnabledAction(UserModifyAction.ID, selection);
-		super.setEnabledAction(UserDeleteAction.ID, selection);
-		super.setEnabledAction(ModifyPasswordAction.ID, selection);
+		this.rowNum = num;
 
-		if (num > 0){
-			super.setEnabledAction(UserModifyAction.ID, true);
-			super.setEnabledAction(UserDeleteAction.ID, true);
-			super.setEnabledAction(ModifyPasswordAction.ID, true);
-		} else {
-			super.setEnabledAction(UserModifyAction.ID, false);
-			super.setEnabledAction(UserDeleteAction.ID, false);
-			super.setEnabledAction(ModifyPasswordAction.ID, false);
+		//ビューアクションの使用可/不可を設定
+		ICommandService service = (ICommandService) PlatformUI.getWorkbench().getService( ICommandService.class );
+		if( null != service ){
+			service.refreshElements(UserModifyAction.ID, null);
+			service.refreshElements(UserAddAction.ID, null);
+			service.refreshElements(UserDeleteAction.ID, null);
+			service.refreshElements(UserRefreshAction.ID, null);
+			service.refreshElements(ModifyPasswordAction.ID, null);
+
+			// Update ToolBar after elements refreshed
+			// WARN : Both ToolBarManager must be updated after updateActionBars(), otherwise icon won't change.
+			getViewSite().getActionBars().updateActionBars();
+			getViewSite().getActionBars().getToolBarManager().update(false);
 		}
 	}
-}
\ No newline at end of file
+}
