@@ -19,6 +19,7 @@ import java.text.ParseException;
 import java.text.SimpleDateFormat;
 import java.util.ArrayList;
 import java.util.Date;
+
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.eclipse.jface.dialogs.IDialogConstants;
@@ -42,6 +43,7 @@ import org.eclipse.swt.widgets.Text;
 import com.clustercontrol.bean.PropertyDefineConstant;
 import com.clustercontrol.bean.RequiredFieldColorConstant;
 import com.clustercontrol.util.Messages;
+import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.ws.calendar.CalendarDetailInfo;
 import com.clustercontrol.ws.calendar.CalendarInfo;
 import com.clustercontrol.calendar.action.AddCalendar;
@@ -49,6 +51,7 @@ import com.clustercontrol.calendar.action.GetCalendar;
 import com.clustercontrol.calendar.action.GetCalendarDetailTableDefine;
 import com.clustercontrol.calendar.action.ModifyCalendar;
 import com.clustercontrol.calendar.composite.CalendarDetailInfoComposite;
+import com.clustercontrol.composite.ManagerListComposite;
 import com.clustercontrol.composite.RoleIdListComposite;
 import com.clustercontrol.composite.RoleIdListComposite.Mode;
 import com.clustercontrol.dialog.CommonDialog;
@@ -57,7 +60,7 @@ import com.clustercontrol.dialog.ValidateResult;
 
 /**
  * カレンダ設定作成・変更ダイアログクラス<BR>
- * 
+ *
  * @version 4.1.0
  * @since 2.0.0
  */
@@ -75,54 +78,57 @@ public class CalendarDialog extends CommonDialog{
 	/** 変更用ダイアログ判別フラグ */
 	private int mode;
 	/** カレンダID */
-	private Text txtCalID = null;
+	private Text calIdText = null;
 	/** カレンダ名 */
-	private Text txtCalName = null;
+	private Text calNameText = null;
 	/** 有効期間（開始） */
-	private Text txtCalTimeFrom = null;
+	private Text calTimeFromText = null;
 	/** 有効期間（終了） */
-	private Text txtCalTimeTo = null;
+	private Text calTimeToText = null;
 	/** 入力値を保持するオブジェクト */
 	private CalendarInfo inputData = null;
 	/** カレンダ詳細情報 */
-	private CalendarDetailInfoComposite m_calendarDetailComposite = null;
+	private CalendarDetailInfoComposite calDetailComposite = null;
 	/** オーナーロールID用テキスト */
-	private RoleIdListComposite m_ownerRoleId = null;
+	private RoleIdListComposite calRoleIdListComposite = null;
 	private String ownerRoleId = null;
+	/** マネージャ名 */
+	private String managerName = null;
+	/** マネージャ名コンボボックス用コンポジット */
+	private ManagerListComposite m_managerComposite = null;
 
 	// ----- 共通メンバ変数 ----- //
 	private Shell shell = null;
-	private Group groupCal = null; //カレンダ設定グループ
-	private Group groupCalDetail = null;// カレンダ詳細グループ
-	private Text txtCalDescription = null;
-	private Button btnTimeFrom = null;
-	private Button btnTimeTo = null;
+	private Group calGroup = null; //カレンダ設定グループ
+	private Group calDetailGroup = null;// カレンダ詳細グループ
+	private Text calDescription = null;
+	private Button calTimeFromButton = null;
+	private Button calTimeToButton = null;
 
 	// ----- コンストラクタ ----- //
 	/**
 	 * 作成用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent
 	 *            親のシェルオブジェクト
 	 */
-	public CalendarDialog(Shell parent) {
-		super(parent);
-	}
-	public CalendarDialog(Shell parent, String id, int mode) {
+	public CalendarDialog(Shell parent, String managerName, String id, int mode) {
 		super(parent);
+		this.managerName = managerName;
 		this.calendarId = id;
 		this.mode = mode;
 	}
 	// ----- instance メソッド ----- //
 	/**
 	 * ダイアログエリアを生成します。
-	 * 
+	 *
 	 * @param parent
 	 *            親のインスタンス
 	 */
 	@Override
 	protected void customizeDialog(Composite parent) {
 		shell = this.getShell();
+
 		// タイトル
 		shell.setText(Messages.getString("dialog.calendar.calendar.create.modify"));
 		GridData gridData = new GridData();
@@ -133,23 +139,60 @@ public class CalendarDialog extends CommonDialog{
 		/*
 		 * カレンダ設定グループ
 		 */
-		groupCal = new Group(parent, SWT.NONE);
+		calGroup = new Group(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "setting", calGroup);
 		layout = new GridLayout(1, true);
 		layout.marginWidth = 5;
 		layout.marginHeight = 5;
 		layout.numColumns = 15;
-		groupCal.setLayout(layout);
+		calGroup.setLayout(layout);
 		gridData = new GridData();
 		gridData.horizontalSpan = 15;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
-		groupCal.setLayoutData(gridData);
-		groupCal.setText(Messages.getString("calendar.create"));
+		calGroup.setLayoutData(gridData);
+		calGroup.setText(Messages.getString("calendar.create"));
+
+		/*
+		 * マネージャ
+		 */
+		Label labelManager = new Label(calGroup, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "manager", labelManager);
+		gridData = new GridData();
+		gridData.horizontalAlignment = GridData.FILL;
+		gridData.grabExcessHorizontalSpace = true;
+		gridData.horizontalSpan = 4;
+		labelManager.setLayoutData(gridData);
+		labelManager.setText(Messages.getString("facility.manager") + " : ");
+		if(this.mode == PropertyDefineConstant.MODE_MODIFY){
+			this.m_managerComposite = new ManagerListComposite(calGroup, SWT.NONE, false);
+		} else {
+			this.m_managerComposite = new ManagerListComposite(calGroup, SWT.NONE, true);
+			this.m_managerComposite.getComboManagerName().addSelectionListener(new SelectionAdapter() {
+				@Override
+				public void widgetSelected(SelectionEvent e) {
+					String managerName = m_managerComposite.getText();
+					calRoleIdListComposite.createRoleIdList(managerName);
+				}
+			});
+		}
+		WidgetTestUtil.setTestId(this, "managerComposite", this.m_managerComposite);
+		gridData = new GridData();
+		gridData.horizontalAlignment = GridData.FILL;
+		gridData.horizontalSpan = 8;
+		gridData.grabExcessHorizontalSpace = true;
+		this.m_managerComposite.setLayoutData(gridData);
+
+		if(this.managerName != null) {
+			this.m_managerComposite.setText(this.managerName);
+		}
+
 		/*
 		 * カレンダID
 		 */
 		//ラベル
-		Label lblCalID = new Label(groupCal, SWT.LEFT);
+		Label lblCalID = new Label(calGroup, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "calid", lblCalID);
 		gridData = new GridData();
 		gridData.horizontalSpan = 4;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -157,13 +200,14 @@ public class CalendarDialog extends CommonDialog{
 		lblCalID.setLayoutData(gridData);
 		lblCalID.setText(Messages.getString("calendar.id") + " : ");
 		//テキスト
-		txtCalID = new Text(groupCal, SWT.BORDER | SWT.LEFT);
+		calIdText = new Text(calGroup, SWT.BORDER | SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "calid", calIdText);
 		gridData = new GridData();
 		gridData.horizontalSpan = 8;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
-		txtCalID.setLayoutData(gridData);
-		txtCalID.addModifyListener(new ModifyListener(){
+		calIdText.setLayoutData(gridData);
+		calIdText.addModifyListener(new ModifyListener(){
 			@Override
 			public void modifyText(ModifyEvent arg0) {
 				update();
@@ -173,7 +217,8 @@ public class CalendarDialog extends CommonDialog{
 		 * カレンダ名
 		 */
 		//ラベル
-		Label lblCalName = new Label(groupCal, SWT.LEFT);
+		Label lblCalName = new Label(calGroup, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "calendarname", lblCalName);
 		gridData = new GridData();
 		gridData.horizontalSpan = 4;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -181,13 +226,14 @@ public class CalendarDialog extends CommonDialog{
 		lblCalName.setLayoutData(gridData);
 		lblCalName.setText(Messages.getString("calendar.name") + " : ");
 		//テキスト
-		txtCalName = new Text(groupCal, SWT.BORDER | SWT.LEFT);
+		calNameText = new Text(calGroup, SWT.BORDER | SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "calName", calNameText);
 		gridData = new GridData();
 		gridData.horizontalSpan = 8;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
-		txtCalName.setLayoutData(gridData);
-		txtCalName.addModifyListener(new ModifyListener(){
+		calNameText.setLayoutData(gridData);
+		calNameText.addModifyListener(new ModifyListener(){
 			@Override
 			public void modifyText(ModifyEvent arg0) {
 				update();
@@ -197,7 +243,8 @@ public class CalendarDialog extends CommonDialog{
 		 * 説明
 		 */
 		//ラベル
-		Label lblCalDescription = new Label(groupCal, SWT.LEFT);
+		Label lblCalDescription = new Label(calGroup, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "description", lblCalDescription);
 		gridData = new GridData();
 		gridData.horizontalSpan = 4;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -205,13 +252,14 @@ public class CalendarDialog extends CommonDialog{
 		lblCalDescription.setLayoutData(gridData);
 		lblCalDescription.setText(Messages.getString("description") + " : ");
 		//テキスト
-		txtCalDescription = new Text(groupCal, SWT.BORDER | SWT.LEFT);
+		calDescription = new Text(calGroup, SWT.BORDER | SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "caldescription", calDescription);
 		gridData = new GridData();
 		gridData.horizontalSpan = 8;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
-		txtCalDescription.setLayoutData(gridData);
-		txtCalDescription.addModifyListener(new ModifyListener(){
+		calDescription.setLayoutData(gridData);
+		calDescription.addModifyListener(new ModifyListener(){
 			@Override
 			public void modifyText(ModifyEvent arg0) {
 				update();
@@ -221,7 +269,8 @@ public class CalendarDialog extends CommonDialog{
 		/*
 		 * オーナーロールID
 		 */
-		Label labelRoleId = new Label(groupCal, SWT.LEFT);
+		Label labelRoleId = new Label(calGroup, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "ownerroleid", labelRoleId);
 		gridData = new GridData();
 		gridData.horizontalSpan = 4;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -230,44 +279,41 @@ public class CalendarDialog extends CommonDialog{
 		labelRoleId.setText(Messages.getString("owner.role.id") + " : ");
 		if (this.mode == PropertyDefineConstant.MODE_ADD
 				|| this.mode == PropertyDefineConstant.MODE_COPY) {
-			this.m_ownerRoleId = new RoleIdListComposite(groupCal, SWT.NONE, true, Mode.OWNER_ROLE);
-			this.m_ownerRoleId.getComboRoleId().addSelectionListener(new SelectionAdapter() {
+			this.calRoleIdListComposite = new RoleIdListComposite(calGroup,
+					SWT.NONE, this.managerName, true, Mode.OWNER_ROLE);
+			this.calRoleIdListComposite.getComboRoleId().addSelectionListener(new SelectionAdapter() {
 				@Override
 				public void widgetSelected(SelectionEvent e) {
-					/* FIXME
-					CalendarInfo calInfo = m_calendarDetailComposite.getCalendarInfo();
-					if (calInfo != null
-							&& calInfo.getCalendarDetailList() != null
-							&& calInfo.getCalendarDetailList().size() > 0) {
-					 */
-					if (m_calendarDetailComposite.getDetailList() != null
-							&& m_calendarDetailComposite.getDetailList().size() > 0) {
+					if (calDetailComposite.getDetailList() != null
+							&& calDetailComposite.getDetailList().size() > 0) {
 						if (!MessageDialog.openConfirm(
 								null,
 								Messages.getString("confirmed"),
 								Messages.getString("message.calendar.50"))) {
-							m_ownerRoleId.setText(ownerRoleId);
+							calRoleIdListComposite.setText(ownerRoleId);
 							return;
 						}
 					}
-					m_calendarDetailComposite.changeOwnerRoleId(m_ownerRoleId.getText());
-					ownerRoleId = m_ownerRoleId.getText();
+					calDetailComposite.changeOwnerRoleId(calRoleIdListComposite.getText());
+					ownerRoleId = calRoleIdListComposite.getText();
 				}
 			});
 		} else {
-			this.m_ownerRoleId = new RoleIdListComposite(groupCal, SWT.NONE, false, Mode.OWNER_ROLE);
+			this.calRoleIdListComposite = new RoleIdListComposite(calGroup, SWT.NONE, this.managerName, false, Mode.OWNER_ROLE);
 		}
+		WidgetTestUtil.setTestId(this, "calroleidlist", calRoleIdListComposite);
 		gridData = new GridData();
 		gridData.horizontalSpan = 8;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
-		m_ownerRoleId.setLayoutData(gridData);
+		calRoleIdListComposite.setLayoutData(gridData);
 
 		/*
 		 * 有効期間（開始）
 		 */
 		//ラベル
-		Label lblCalTimeFrom = new Label(groupCal, SWT.LEFT);
+		Label lblCalTimeFrom = new Label(calGroup, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "caltimefrom", lblCalTimeFrom);
 		gridData = new GridData();
 		gridData.horizontalSpan = 4;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -276,33 +322,35 @@ public class CalendarDialog extends CommonDialog{
 		lblCalTimeFrom.setText(Messages.getString("valid.time") + "(" +
 				Messages.getString("start") + ")" + " : ");
 		//テキスト
-		txtCalTimeFrom = new Text(groupCal, SWT.BORDER | SWT.LEFT);
+		calTimeFromText = new Text(calGroup, SWT.BORDER | SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "timefrom", calTimeFromText);
 		gridData = new GridData();
 		gridData.horizontalSpan = 8;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
-		txtCalTimeFrom.setLayoutData(gridData);
+		calTimeFromText.setLayoutData(gridData);
 		//日時ダイアログからの入力しか受け付けません
-		txtCalTimeFrom.setEnabled(false);
-		txtCalTimeFrom.addModifyListener(new ModifyListener(){
+		calTimeFromText.setEnabled(false);
+		calTimeFromText.addModifyListener(new ModifyListener(){
 			@Override
 			public void modifyText(ModifyEvent arg0) {
 				update();
 			}
 		});
 		// 追加ボタン
-		btnTimeFrom = new Button(groupCal, SWT.NONE);
+		calTimeFromButton = new Button(calGroup, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "timefrom", calTimeFromButton);
 		gridData = new GridData();
 		gridData.horizontalSpan = 1;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
-		btnTimeFrom.setLayoutData(gridData);
-		btnTimeFrom.setText(Messages.getString("calendar.button"));
-		btnTimeFrom.addSelectionListener(new SelectionAdapter() {
+		calTimeFromButton.setLayoutData(gridData);
+		calTimeFromButton.setText(Messages.getString("calendar.button"));
+		calTimeFromButton.addSelectionListener(new SelectionAdapter() {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
 				DateTimeDialog dialog = new DateTimeDialog(shell);
-				if (txtCalTimeFrom.getText().length() > 0) {
+				if (calTimeFromText.getText().length() > 0) {
 					Date date = new Date(calTimeFrom);
 					dialog.setDate(date);
 				}
@@ -312,7 +360,7 @@ public class CalendarDialog extends CommonDialog{
 					//ダイアログより取得した日時を"yyyy/MM/dd HH:mm:ss"の形式に変換
 					SimpleDateFormat sdf = new SimpleDateFormat("yyyy/MM/dd HH:mm:ss");
 					String tmp = sdf.format(dialog.getDate());
-					txtCalTimeFrom.setText(tmp);
+					calTimeFromText.setText(tmp);
 					update();
 				}
 			}
@@ -321,7 +369,8 @@ public class CalendarDialog extends CommonDialog{
 		 * 有効期間（終了）
 		 */
 		//ラベル
-		Label lblCalTimeTo = new Label(groupCal, SWT.LEFT);
+		Label lblCalTimeTo = new Label(calGroup, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "caltimeto", lblCalTimeTo);
 		gridData = new GridData();
 		gridData.horizontalSpan = 4;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -330,33 +379,35 @@ public class CalendarDialog extends CommonDialog{
 		lblCalTimeTo.setText(Messages.getString("valid.time") + "(" +
 				Messages.getString("end") + ")" + " : ");
 		//テキスト
-		txtCalTimeTo = new Text(groupCal, SWT.BORDER | SWT.LEFT);
+		calTimeToText = new Text(calGroup, SWT.BORDER | SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "timeto", calTimeToText);
 		gridData = new GridData();
 		gridData.horizontalSpan = 8;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
-		txtCalTimeTo.setLayoutData(gridData);
+		calTimeToText.setLayoutData(gridData);
 		//日時ダイアログからの入力しか受け付けません
-		txtCalTimeTo.setEnabled(false);
-		txtCalTimeTo.addModifyListener(new ModifyListener(){
+		calTimeToText.setEnabled(false);
+		calTimeToText.addModifyListener(new ModifyListener(){
 			@Override
 			public void modifyText(ModifyEvent arg0) {
 				update();
 			}
 		});
 		// 追加ボタン
-		btnTimeTo = new Button(groupCal, SWT.NONE);
+		calTimeToButton = new Button(calGroup, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "timeto", calTimeToButton);
 		gridData = new GridData();
 		gridData.horizontalSpan = 1;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
-		btnTimeTo.setLayoutData(gridData);
-		btnTimeTo.setText(Messages.getString("calendar.button"));
-		btnTimeTo.addSelectionListener(new SelectionAdapter() {
+		calTimeToButton.setLayoutData(gridData);
+		calTimeToButton.setText(Messages.getString("calendar.button"));
+		calTimeToButton.addSelectionListener(new SelectionAdapter() {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
 				DateTimeDialog dialog = new DateTimeDialog(shell);
-				if (txtCalTimeTo.getText().length() > 0) {
+				if (calTimeToText.getText().length() > 0) {
 					Date date = new Date(calTimeTo);
 					dialog.setDate(date);
 				}
@@ -369,44 +420,47 @@ public class CalendarDialog extends CommonDialog{
 					m_log.trace("CalendarDialog getTime：" + dialog.getDate());
 
 					String tmp = sdf.format(dialog.getDate());
-					txtCalTimeTo.setText(tmp);
+					calTimeToText.setText(tmp);
 				}
 			}
 		});
 
 		/*
 		 * カレンダ詳細グループ
-		 * 
+		 *
 		 */
-		groupCalDetail = new Group(parent, SWT.NONE);
+		calDetailGroup = new Group(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "detail", calDetailGroup);
 		layout = new GridLayout(1, true);
 		layout.marginWidth = 5;
 		layout.marginHeight = 5;
 		layout.numColumns = 1;
-		groupCalDetail.setLayout(layout);
+		calDetailGroup.setLayout(layout);
 		gridData = new GridData();
 		gridData.horizontalSpan = 15;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
-		groupCalDetail.setLayoutData(gridData);
-		groupCalDetail.setText(Messages.getString("calendar.detail"));
+		calDetailGroup.setLayoutData(gridData);
+		calDetailGroup.setText(Messages.getString("calendar.detail"));
 
 		/**
 		 *  カレンダ詳細定義情報
 		 */
 		//詳細情報テーブルカラム取得
 		GetCalendarDetailTableDefine.get();
-		this.m_calendarDetailComposite = new CalendarDetailInfoComposite(groupCalDetail, SWT.NONE);
+		this.calDetailComposite = new CalendarDetailInfoComposite(calDetailGroup, SWT.NONE, this.managerName);
+		WidgetTestUtil.setTestId(this, "detail", calDetailComposite);
 		gridData = new GridData();
 		gridData.horizontalSpan = 1;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		gridData.heightHint = 220;
-		m_calendarDetailComposite.setLayoutData(gridData);
+		calDetailComposite.setLayoutData(gridData);
+
+		Display calDisplay = shell.getDisplay();
+		shell.setLocation((calDisplay.getBounds().width - shell.getSize().x) / 2,
+				(calDisplay.getBounds().height - shell.getSize().y) / 2);
 
-		Display display = shell.getDisplay();
-		shell.setLocation((display.getBounds().width - shell.getSize().x) / 2,
-				(display.getBounds().height - shell.getSize().y) / 2);
 
 		// ダイアログを調整
 		this.adjustDialog();
@@ -416,12 +470,13 @@ public class CalendarDialog extends CommonDialog{
 		//this.createCalendarInfo();
 		// 必須入力項目を可視化
 		this.update();
+
 	}
 
 
 	/**
 	 * ダイアログエリアを調整します。
-	 * 
+	 *
 	 */
 	private void adjustDialog(){
 		// サイズを最適化
@@ -430,48 +485,48 @@ public class CalendarDialog extends CommonDialog{
 		shell.setSize(new Point(600, shell.getSize().y));
 
 		// 画面中央に配置
-		Display display = shell.getDisplay();
-		shell.setLocation((display.getBounds().width - shell.getSize().x) / 2,
-				(display.getBounds().height - shell.getSize().y) / 2);
+		Display calAdjustDisplay = shell.getDisplay();
+		shell.setLocation((calAdjustDisplay.getBounds().width - shell.getSize().x) / 2,
+				(calAdjustDisplay.getBounds().height - shell.getSize().y) / 2);
 	}
 
 	/**
 	 * 更新処理
-	 * 
+	 *
 	 */
 	public void update(){
 		// 必須項目を明示
 
 		// カレンダIDのインデックス：9
-		if("".equals(this.txtCalID.getText())){
-			this.txtCalID.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
+		if("".equals(this.calIdText.getText())){
+			this.calIdText.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
 		}else{
-			this.txtCalID.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+			this.calIdText.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
 		}
 		// カレンダ名のインデックス：9
-		if("".equals(this.txtCalName.getText())){
-			this.txtCalName.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
+		if("".equals(this.calNameText.getText())){
+			this.calNameText.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
 		}else{
-			this.txtCalName.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+			this.calNameText.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
 		}
 		// 有効期間（開始）のインデックス：9
-		if("".equals(this.txtCalTimeFrom.getText())){
-			this.txtCalTimeFrom.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
+		if("".equals(this.calTimeFromText.getText())){
+			this.calTimeFromText.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
 		}else{
-			this.txtCalTimeFrom.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+			this.calTimeFromText.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
 		}
 		// 有効期間（終了）のインデックス：9
-		if("".equals(this.txtCalTimeTo.getText())){
-			this.txtCalTimeTo.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
+		if("".equals(this.calTimeToText.getText())){
+			this.calTimeToText.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
 		}else{
-			this.txtCalTimeTo.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+			this.calTimeToText.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
 		}
 	}
 	/**
 	 * ダイアログの情報からカレンダ情報を作成します。
-	 * 
+	 *
 	 * @return 入力値の検証結果
-	 * 
+	 *
 	 * @see
 	 */
 	private ValidateResult createCalendarInfo() {
@@ -480,8 +535,8 @@ public class CalendarDialog extends CommonDialog{
 		this.inputData = new CalendarInfo();
 
 		//カレンダID取得
-		if(txtCalID.getText().length() > 0){
-			inputData.setId(txtCalID.getText());
+		if(calIdText.getText().length() > 0){
+			inputData.setId(calIdText.getText());
 		} else {
 			result = new ValidateResult();
 			result.setValid(false);
@@ -489,11 +544,11 @@ public class CalendarDialog extends CommonDialog{
 			result.setMessage(Messages.getString("calendar.id"));
 			return result;
 		}
-		m_log.trace("createCalendarInfo cal name = " + txtCalName.getText());
+		m_log.trace("createCalendarInfo cal name = " + calNameText.getText());
 		//カレンダ名取得
-		if(txtCalName.getText().length() > 0 && !txtCalName.equals("")) {
-			m_log.trace("createCalendarInfo22 cal name = " + txtCalName.getText());
-			inputData.setName(txtCalName.getText());
+		if(calNameText.getText().length() > 0 && !"".equals(calNameText.getText())) {
+			m_log.trace("createCalendarInfo22 cal name = " + calNameText.getText());
+			inputData.setName(calNameText.getText());
 			m_log.trace("input cal name = " + inputData.getName());
 		} else {
 			result = new ValidateResult();
@@ -503,16 +558,16 @@ public class CalendarDialog extends CommonDialog{
 			return result;
 		}
 		//カレンダ説明取得
-		if(txtCalDescription.getText().length() > 0){
-			inputData.setDescription(txtCalDescription.getText());
+		if(calDescription.getText().length() > 0){
+			inputData.setDescription(calDescription.getText());
 		} else {
 			inputData.setDescription("");
 		}
 		//有効期間（開始）取得
-		if(txtCalTimeFrom.getText().length() > 0){
+		if(calTimeFromText.getText().length() > 0){
 			Date dateTimeFrom;
 			try {
-				dateTimeFrom = (new SimpleDateFormat("yyyy/MM/dd HH:mm:ss")).parse(txtCalTimeFrom.getText());
+				dateTimeFrom = (new SimpleDateFormat("yyyy/MM/dd HH:mm:ss")).parse(calTimeFromText.getText());
 				calTimeFrom = dateTimeFrom.getTime();
 				inputData.setValidTimeFrom(calTimeFrom);
 			} catch (ParseException e) {
@@ -527,10 +582,10 @@ public class CalendarDialog extends CommonDialog{
 			return result;
 		}
 		//有効期間（終了）取得
-		if(txtCalTimeTo.getText().length() > 0){
+		if(calTimeToText.getText().length() > 0){
 			Date dateTimeTo;
 			try {
-				dateTimeTo = (new SimpleDateFormat("yyyy/MM/dd HH:mm:ss")).parse(txtCalTimeTo.getText());
+				dateTimeTo = (new SimpleDateFormat("yyyy/MM/dd HH:mm:ss")).parse(calTimeToText.getText());
 				calTimeTo = dateTimeTo.getTime();
 				inputData.setValidTimeTo(calTimeTo);
 			} catch (ParseException e) {
@@ -545,18 +600,18 @@ public class CalendarDialog extends CommonDialog{
 			return result;
 		}
 		//カレンダ詳細情報取得
-		if (this.m_calendarDetailComposite.getDetailList() != null) {
+		if (this.calDetailComposite.getDetailList() != null) {
 
 			m_log.debug("Add CalendarDetailInfo : " +
-					this.m_calendarDetailComposite.getDetailList().size());
+					this.calDetailComposite.getDetailList().size());
 
-			for (CalendarDetailInfo detailInfo : this.m_calendarDetailComposite.getDetailList()) {
+			for (CalendarDetailInfo detailInfo : this.calDetailComposite.getDetailList()) {
 				this.inputData.getCalendarDetailList().add(detailInfo);
 			}
 		}
 		//オーナーロールID
-		if (m_ownerRoleId.getText().length() > 0) {
-			inputData.setOwnerRoleId(m_ownerRoleId.getText());
+		if (calRoleIdListComposite.getText().length() > 0) {
+			inputData.setOwnerRoleId(calRoleIdListComposite.getText());
 		} else {
 			result = new ValidateResult();
 			result.setValid(false);
@@ -569,7 +624,7 @@ public class CalendarDialog extends CommonDialog{
 
 	/**
 	 * ダイアログにカレンダ情報を反映します。
-	 * 
+	 *
 	 * @param detailList
 	 */
 	private void reflectCalendar() {
@@ -578,7 +633,7 @@ public class CalendarDialog extends CommonDialog{
 		if(mode == PropertyDefineConstant.MODE_MODIFY
 				|| mode == PropertyDefineConstant.MODE_COPY){
 			// 変更、コピーの場合、情報取得
-			calInfo = new GetCalendar().getCalendar(this.calendarId);
+			calInfo = new GetCalendar().getCalendar(this.m_managerComposite.getText(), this.calendarId);
 		}else{
 			// 作成の場合
 			calInfo = new CalendarInfo();
@@ -588,49 +643,49 @@ public class CalendarDialog extends CommonDialog{
 		if(calInfo != null){
 			if (calInfo.getId() != null) {
 				this.calendarId = calInfo.getId();
-				this.txtCalID.setText(calInfo.getId());
+				this.calIdText.setText(calInfo.getId());
 				//カレンダ定義変更の際にはカレンダIDは変更不可
 				if (this.mode == PropertyDefineConstant.MODE_MODIFY) {
-					this.txtCalID.setEnabled(false);
+					this.calIdText.setEnabled(false);
 				}
 			}
 			if(calInfo.getName() != null){
-				this.txtCalName.setText(calInfo.getName());
+				this.calNameText.setText(calInfo.getName());
 			}
 			if(calInfo.getDescription() != null){
-				this.txtCalDescription.setText(calInfo.getDescription());
+				this.calDescription.setText(calInfo.getDescription());
 			}
 			if(calInfo.getValidTimeFrom() != null){
 				SimpleDateFormat sdf = new SimpleDateFormat("yyyy/MM/dd HH:mm:ss");
 				String tmp = sdf.format(calInfo.getValidTimeFrom());
-				this.txtCalTimeFrom.setText(tmp);
+				this.calTimeFromText.setText(tmp);
 				this.calTimeFrom = calInfo.getValidTimeFrom();
 			}
 			if(calInfo.getValidTimeTo() != null){
 				SimpleDateFormat sdf = new SimpleDateFormat("yyyy/MM/dd HH:mm:ss");
 				String tmp = sdf.format(calInfo.getValidTimeTo());
-				this.txtCalTimeTo.setText(tmp);
+				this.calTimeToText.setText(tmp);
 				this.calTimeTo = calInfo.getValidTimeTo();
 			}
 		}
 		// カレンダ詳細情報取得
-		m_calendarDetailComposite.setDetailList(
+		calDetailComposite.setDetailList(
 				(ArrayList<CalendarDetailInfo>) calInfo.getCalendarDetailList());
 
 		// オーナーロールID取得
 		if (calInfo.getOwnerRoleId() != null) {
-			this.m_ownerRoleId.setText(calInfo.getOwnerRoleId());
+			this.calRoleIdListComposite.setText(calInfo.getOwnerRoleId());
 		}
-		ownerRoleId = this.m_ownerRoleId.getText();
-		this.m_calendarDetailComposite.setOwnerRoleId(this.m_ownerRoleId.getText());
+		ownerRoleId = this.calRoleIdListComposite.getText();
+		this.calDetailComposite.setOwnerRoleId(this.calRoleIdListComposite.getText());
 
 		this.update();
 	}
 	/**
 	 * 入力値をマネージャに登録します。
-	 * 
+	 *
 	 * @return true：正常、false：異常
-	 * 
+	 *
 	 * @see com.clustercontrol.dialog.CommonDialog#action()
 	 */
 
@@ -639,18 +694,19 @@ public class CalendarDialog extends CommonDialog{
 		boolean result = false;
 		createCalendarInfo();
 		CalendarInfo info = this.inputData;
+		String managerName = this.m_managerComposite.getText();
 		if(info != null){
 			if(mode == PropertyDefineConstant.MODE_ADD){
 				// 作成の場合+
-				result = new AddCalendar().add(info);
+				result = new AddCalendar().add(managerName, info);
 			} else if (mode == PropertyDefineConstant.MODE_MODIFY){
 				// 変更の場合
-				info.setId(txtCalID.getText());
-				result = new ModifyCalendar().modify(info);
+				info.setId(calIdText.getText());
+				result = new ModifyCalendar().modify(managerName, info);
 			} else if (mode == PropertyDefineConstant.MODE_COPY){
 				// コピーの場合
-				info.setId(txtCalID.getText());
-				result = new AddCalendar().add(info);
+				info.setId(calIdText.getText());
+				result = new AddCalendar().add(managerName, info);
 			}
 		} else {
 			m_log.error("action() Calendarinfo is null");
