@@ -25,6 +25,8 @@ import java.util.Date;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.events.ModifyEvent;
 import org.eclipse.swt.events.ModifyListener;
+import org.eclipse.swt.events.SelectionAdapter;
+import org.eclipse.swt.events.SelectionEvent;
 import org.eclipse.swt.graphics.Point;
 import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
@@ -44,6 +46,7 @@ import com.clustercontrol.bean.RequiredFieldColorConstant;
 import com.clustercontrol.calendar.action.AddCalendar;
 import com.clustercontrol.calendar.action.GetCalendar;
 import com.clustercontrol.calendar.action.ModifyCalendar;
+import com.clustercontrol.composite.ManagerListComposite;
 import com.clustercontrol.composite.RoleIdListComposite;
 import com.clustercontrol.composite.RoleIdListComposite.Mode;
 import com.clustercontrol.dialog.CommonDialog;
@@ -51,10 +54,11 @@ import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.ws.calendar.CalendarPatternInfo;
 import com.clustercontrol.ws.calendar.Ymd;
+import com.clustercontrol.util.WidgetTestUtil;
 
 /**
  * カレンダ[カレンダパターンの作成・変更]ダイアログクラス<BR>
- * 
+ *
  * @version 4.1.0
  * @since 4.1.0
  */
@@ -62,13 +66,13 @@ public class CalendarPatternDialog extends CommonDialog {
 	/** */
 	private Shell shell = null;
 	/** カレンダコンポジット*/
-	private SWTCalendar swtcal = null;
+	private SWTCalendar calPatternCalendar = null;
 	/** ID*/
-	private Text txtID = null;
+	private Text calPatternIdText = null;
 	/** 名*/
-	private Text txtName = null;
+	private Text calPatternNameText = null;
 	/** 選択した日付を表示するSWTリスト*/
-	private List dateViewSWTList = null;
+	private List calPatternList = null;
 
 	/** 選択した日付を保持するリスト*/
 	private ArrayList<Ymd> m_ymdList;
@@ -84,39 +88,36 @@ public class CalendarPatternDialog extends CommonDialog {
 	/** */
 	private Date date;
 	/** オーナーロールID用テキスト */
-	private RoleIdListComposite m_ownerRoleId = null;
+	private RoleIdListComposite calPatternRoleIdListComposite = null;
+	/** マネージャ名 */
+	private String managerName = null;
+	/** マネージャ名コンボボックス用コンポジット */
+	private ManagerListComposite m_managerComposite = null;
 
 	/**
 	 * コンストラクタ
-	 * 
+	 *
 	 * @param parent
 	 * @since 1.0.0
 	 */
-	public CalendarPatternDialog(Shell parent) {
-		super(parent);
-	}
-	/**
-	 * コンストラクタ
-	 * 
-	 * @param parent
-	 * @since 1.0.0
-	 */
-	public CalendarPatternDialog(Shell parent,String id,int mode) {
+	public CalendarPatternDialog(Shell parent, String managerName, String id,int mode) {
 		super(parent);
+
+		this.managerName = managerName;
 		this.id = id;
 		this.mode = mode;
 	}
 
 	/**
 	 * ダイアログ作成
-	 * 
+	 *
 	 * @see com.clustercontrol.dialog.CommonDialog#customizeDialog(org.eclipse.swt.widgets.Composite)
 	 * @since 1.0.0
 	 */
 	@Override
 	protected void customizeDialog(Composite parent) {
-
 		shell = this.getShell();
+
 		// タイトル
 		shell.setText(Messages.getString("dialog.calendar.pattern.create.modify"));
 
@@ -127,11 +128,56 @@ public class CalendarPatternDialog extends CommonDialog {
 		layout.marginHeight = 10;
 		layout.numColumns = 12;
 		parent.setLayout(layout);
+
+		/*
+		 * マネージャ
+		 */
+		Label labelManager = new Label(parent, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "manager", labelManager);
+		gridData = new GridData();
+		gridData.horizontalSpan = 1;
+		gridData.horizontalAlignment = GridData.FILL;
+		gridData.grabExcessHorizontalSpace = true;
+		labelManager.setLayoutData(gridData);
+		labelManager.setText(Messages.getString("facility.manager") + " : ");
+		if(this.mode == PropertyDefineConstant.MODE_MODIFY){
+			this.m_managerComposite = new ManagerListComposite(parent, SWT.NONE, false);
+		} else {
+			this.m_managerComposite = new ManagerListComposite(parent, SWT.NONE, true);
+			this.m_managerComposite.getComboManagerName().addSelectionListener(new SelectionAdapter() {
+				@Override
+				public void widgetSelected(SelectionEvent e) {
+					String managerName = m_managerComposite.getText();
+					calPatternRoleIdListComposite.createRoleIdList(managerName);
+				}
+			});
+		}
+		WidgetTestUtil.setTestId(this, "managerComposite", this.m_managerComposite);
+		gridData = new GridData();
+		gridData.horizontalSpan = 8;
+		gridData.horizontalAlignment = GridData.FILL;
+		gridData.grabExcessHorizontalSpace = true;
+		this.m_managerComposite.setLayoutData(gridData);
+
+		if(this.managerName != null) {
+			this.m_managerComposite.setText(this.managerName);
+		}
+
+		Label label = new Label(parent, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, null, label);
+		gridData = new GridData();
+		gridData.horizontalSpan = 3;
+		gridData.horizontalAlignment = GridData.FILL;
+		gridData.grabExcessHorizontalSpace = true;
+		label.setLayoutData(gridData);
+		label.setText("");
+
 		/*
 		 * カレンダパターンID
 		 */
 		//ラベル
 		Label lblId = new Label(parent, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "id", lblId);
 		gridData = new GridData();
 		gridData.horizontalSpan = 1;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -139,20 +185,22 @@ public class CalendarPatternDialog extends CommonDialog {
 		lblId.setLayoutData(gridData);
 		lblId.setText(Messages.getString("calendar.pattern.id") + " : ");
 		//テキスト
-		txtID = new Text(parent, SWT.BORDER);
+		calPatternIdText = new Text(parent, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, "id", calPatternIdText);
 		gridData = new GridData();
 		gridData.horizontalSpan = 8;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
-		txtID.setLayoutData(gridData);
-		txtID.addModifyListener(new ModifyListener(){
+		calPatternIdText.setLayoutData(gridData);
+		calPatternIdText.addModifyListener(new ModifyListener(){
 			@Override
 			public void modifyText(ModifyEvent arg0) {
 				update();
 			}
 		});
 
-		Label label = new Label(parent, SWT.LEFT);
+		label = new Label(parent, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, null, label);
 		gridData = new GridData();
 		gridData.horizontalSpan = 3;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -165,6 +213,7 @@ public class CalendarPatternDialog extends CommonDialog {
 		 */
 		//ラベル
 		Label lblName = new Label(parent, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "name", lblName);
 		gridData = new GridData();
 		gridData.horizontalSpan = 1;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -172,13 +221,14 @@ public class CalendarPatternDialog extends CommonDialog {
 		lblName.setLayoutData(gridData);
 		lblName.setText(Messages.getString("calendar.pattern.name") + " : ");
 		//テキスト
-		txtName = new Text(parent, SWT.BORDER);
+		calPatternNameText = new Text(parent, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, "name", calPatternNameText);
 		gridData = new GridData();
 		gridData.horizontalSpan = 8;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
-		txtName.setLayoutData(gridData);
-		txtName.addModifyListener(new ModifyListener(){
+		calPatternNameText.setLayoutData(gridData);
+		calPatternNameText.addModifyListener(new ModifyListener(){
 			@Override
 			public void modifyText(ModifyEvent arg0) {
 				update();
@@ -186,6 +236,7 @@ public class CalendarPatternDialog extends CommonDialog {
 		});
 
 		label = new Label(parent, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, null, label);
 		gridData = new GridData();
 		gridData.horizontalSpan = 3;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -197,6 +248,7 @@ public class CalendarPatternDialog extends CommonDialog {
 		 * オーナーロールID
 		 */
 		Label labelRoleId = new Label(parent, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "roleid", labelRoleId);
 		gridData = new GridData();
 		gridData.horizontalSpan = 1;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -205,21 +257,25 @@ public class CalendarPatternDialog extends CommonDialog {
 		labelRoleId.setText(Messages.getString("owner.role.id") + " : ");
 		if (this.mode == PropertyDefineConstant.MODE_ADD
 				|| this.mode == PropertyDefineConstant.MODE_COPY) {
-			this.m_ownerRoleId = new RoleIdListComposite(parent, SWT.NONE, true, Mode.OWNER_ROLE);
+			this.calPatternRoleIdListComposite = new RoleIdListComposite(
+					parent, SWT.NONE, this.managerName, true, Mode.OWNER_ROLE);
 		} else {
-			this.m_ownerRoleId = new RoleIdListComposite(parent, SWT.NONE, false, Mode.OWNER_ROLE);
+			this.calPatternRoleIdListComposite = new RoleIdListComposite(
+					parent, SWT.NONE, this.managerName, false, Mode.OWNER_ROLE);
 		}
+		WidgetTestUtil.setTestId(this, "roleidlist", calPatternRoleIdListComposite);
 		gridData = new GridData();
 		gridData.horizontalSpan = 8;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
-		m_ownerRoleId.setLayoutData(gridData);
+		calPatternRoleIdListComposite.setLayoutData(gridData);
 
 		/*
 		 * 例外日設定グループ
 		 */
 		//
-		Group groupEtc = new Group(parent, SWT.CENTER);
+		Group calPatternEtcGroup = new Group(parent, SWT.CENTER);
+		WidgetTestUtil.setTestId(this, "etc", calPatternEtcGroup);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.verticalAlignment = GridData.FILL;
@@ -230,10 +286,11 @@ public class CalendarPatternDialog extends CommonDialog {
 		layout.marginWidth = 5;
 		layout.marginHeight = 5;
 
-		groupEtc.setLayout(layout);
-		groupEtc.setLayoutData(gridData);
-		groupEtc.setText(Messages.getString("calendar.pattern.setting"));
-		swtcal = new SWTCalendar(groupEtc);
+		calPatternEtcGroup.setLayout(layout);
+		calPatternEtcGroup.setLayoutData(gridData);
+		calPatternEtcGroup.setText(Messages.getString("calendar.pattern.setting"));
+		calPatternCalendar = new SWTCalendar(calPatternEtcGroup);
+		WidgetTestUtil.setTestId(this, null, calPatternCalendar);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.verticalAlignment = GridData.FILL;
@@ -242,9 +299,9 @@ public class CalendarPatternDialog extends CommonDialog {
 		gridData.horizontalSpan = 5;
 		gridData.verticalSpan = 2;
 
-		swtcal.setLayoutData(gridData);
+		calPatternCalendar.setLayoutData(gridData);
 		//カレンダー日付変更時リスナー
-		swtcal.addSWTCalendarListener(new SWTCalendarListener(){
+		calPatternCalendar.addSWTCalendarListener(new SWTCalendarListener(){
 
 			@Override
 			public void dateChanged(SWTCalendarEvent event) {
@@ -293,23 +350,25 @@ public class CalendarPatternDialog extends CommonDialog {
 					}
 				});
 				//表示用SWTリストリセット
-				dateViewSWTList.removeAll();
+				calPatternList.removeAll();
 				for(Ymd ymd : m_ymdList){
 					//表示用リストに格納
-					dateViewSWTList.add(yyyyMMdd(ymd));
+					calPatternList.add(yyyyMMdd(ymd));
 				}
 				update();
 			}
 		});
-		swtcal.updateCalendar(m_ymdList);
+		calPatternCalendar.updateCalendar(m_ymdList);
 		//ラベル
-		Label lbl = new Label(groupEtc, SWT.CENTER);
+		Label lbl = new Label(calPatternEtcGroup, SWT.CENTER);
+		WidgetTestUtil.setTestId(this, null, lbl);
 		gridData = new GridData();
 		gridData.horizontalSpan = 5;
 		gridData.verticalSpan = 1;
 		lbl.setLayoutData(gridData);
 		lbl.setText(" " + Messages.getString("calendar.pattern.record.date"));
-		dateViewSWTList = new List(groupEtc,SWT.MULTI|SWT.BORDER|SWT.V_SCROLL);
+		calPatternList = new List(calPatternEtcGroup,SWT.MULTI|SWT.BORDER|SWT.V_SCROLL);
+		WidgetTestUtil.setTestId(this, null, calPatternList);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.verticalAlignment = GridData.FILL;
@@ -317,7 +376,7 @@ public class CalendarPatternDialog extends CommonDialog {
 		gridData.grabExcessVerticalSpace = true;
 		gridData.horizontalSpan = 5;
 		gridData.verticalSpan = 1;
-		dateViewSWTList.setLayoutData(gridData);
+		calPatternList.setLayoutData(gridData);
 		// ダイアログを調整
 		this.adjustDialog();
 		//ダイアログに情報反映
@@ -328,18 +387,18 @@ public class CalendarPatternDialog extends CommonDialog {
 	}
 	/**
 	 * ダイアログエリアを調整します。
-	 * 
+	 *
 	 */
 	private void adjustDialog(){
 		// サイズを最適化
 		// グリッドレイアウトを用いた場合、こうしないと横幅が画面いっぱいになります。
 		shell.pack();
-		shell.setSize(new Point(420, shell.getSize().y));
+		shell.setSize(new Point(480, shell.getSize().y));
 
 		// 画面中央に配置
-		Display display = shell.getDisplay();
-		shell.setLocation((display.getBounds().width - shell.getSize().x) / 2,
-				(display.getBounds().height - shell.getSize().y) / 2);
+		Display calPatternAdjustDisplay = shell.getDisplay();
+		shell.setLocation((calPatternAdjustDisplay.getBounds().width - shell.getSize().x) / 2,
+				(calPatternAdjustDisplay.getBounds().height - shell.getSize().y) / 2);
 	}
 	/**
 	 * ２つのYmd型が等しいか判定
@@ -372,24 +431,24 @@ public class CalendarPatternDialog extends CommonDialog {
 
 	/**
 	 * 更新処理
-	 * 
+	 *
 	 */
 	private void update(){
 		// 必須項目を明示
 		// IDのインデックス：9
-		if("".equals(this.txtID.getText())){
-			this.txtID.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
+		if("".equals(this.calPatternIdText.getText())){
+			this.calPatternIdText.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
 		}else{
-			this.txtID.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+			this.calPatternIdText.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
 		}
 		// 名のインデックス：9
-		if("".equals(this.txtName.getText())){
-			this.txtName.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
+		if("".equals(this.calPatternNameText.getText())){
+			this.calPatternNameText.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
 		}else{
-			this.txtName.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+			this.calPatternNameText.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
 		}
 		//SWTカレンダ更新
-		swtcal.updateCalendar(m_ymdList);
+		calPatternCalendar.updateCalendar(m_ymdList);
 	}
 	/**
 	 * ダイアログにカレンダパターン情報を反映します。
@@ -400,7 +459,7 @@ public class CalendarPatternDialog extends CommonDialog {
 		if(mode == PropertyDefineConstant.MODE_MODIFY
 				|| mode == PropertyDefineConstant.MODE_COPY){
 			// 変更、コピーの場合、情報取得
-			info = new GetCalendar().getCalendarPattern(this.id);
+			info = new GetCalendar().getCalendarPattern(this.managerName, this.id);
 		}else{
 			// 作成の場合
 			info = new CalendarPatternInfo();
@@ -411,19 +470,19 @@ public class CalendarPatternDialog extends CommonDialog {
 		if(info != null){
 			if (info.getId() != null) {
 				this.id = info.getId();
-				this.txtID.setText(info.getId());
+				this.calPatternIdText.setText(info.getId());
 				//カレンダパターン定義変更の際にはカレンダパターンIDは変更不可
 				if (this.mode == PropertyDefineConstant.MODE_MODIFY) {
-					this.txtID.setEnabled(false);
+					this.calPatternIdText.setEnabled(false);
 				}
 			}
 			if(info.getName() != null){
-				this.txtName.setText(info.getName());
+				this.calPatternNameText.setText(info.getName());
 			}
 			if(info.getYmd() != null){
 				for(Ymd ymd : info.getYmd()){
 					m_ymdList = (ArrayList<Ymd>) info.getYmd();
-					dateViewSWTList.add(yyyyMMdd(ymd));
+					calPatternList.add(yyyyMMdd(ymd));
 				}
 			}
 			else {
@@ -433,7 +492,7 @@ public class CalendarPatternDialog extends CommonDialog {
 
 		// オーナーロールID取得
 		if (inputData.getOwnerRoleId() != null) {
-			this.m_ownerRoleId.setText(inputData.getOwnerRoleId());
+			this.calPatternRoleIdListComposite.setText(inputData.getOwnerRoleId());
 		}
 
 		this.update();
@@ -450,8 +509,8 @@ public class CalendarPatternDialog extends CommonDialog {
 
 		inputData = new CalendarPatternInfo();
 		//カレンダパターンID取得
-		if(txtID.getText().length() > 0){
-			inputData.setId(txtID.getText());
+		if(calPatternIdText.getText().length() > 0){
+			inputData.setId(calPatternIdText.getText());
 		} else {
 			result = new ValidateResult();
 			result.setValid(false);
@@ -460,8 +519,8 @@ public class CalendarPatternDialog extends CommonDialog {
 			return result;
 		}
 		//カレンダパターン名取得
-		if(txtName.getText().length() > 0){
-			inputData.setName(txtName.getText());
+		if(calPatternNameText.getText().length() > 0){
+			inputData.setName(calPatternNameText.getText());
 		} else {
 			result = new ValidateResult();
 			result.setValid(false);
@@ -481,8 +540,8 @@ public class CalendarPatternDialog extends CommonDialog {
 
 
 		//オーナーロールID
-		if (m_ownerRoleId.getText().length() > 0) {
-			inputData.setOwnerRoleId(m_ownerRoleId.getText());
+		if (calPatternRoleIdListComposite.getText().length() > 0) {
+			inputData.setOwnerRoleId(calPatternRoleIdListComposite.getText());
 		} else {
 			result = new ValidateResult();
 			result.setValid(false);
@@ -495,7 +554,7 @@ public class CalendarPatternDialog extends CommonDialog {
 
 	/**
 	 * キャンセルボタンクリック時の処理
-	 * 
+	 *
 	 * @see org.eclipse.jface.dialogs.Dialog#cancelPressed()
 	 * @since 1.0.0
 	 */
@@ -507,13 +566,13 @@ public class CalendarPatternDialog extends CommonDialog {
 	}
 	/**
 	 * OKボタンクリック時の処理
-	 * 
+	 *
 	 * @see org.eclipse.jface.dialogs.Dialog#okPressed()
 	 * @since 1.0.0
 	 */
 	@Override
 	protected void okPressed() {
-		date = swtcal.getCalendar().getTime();
+		date = calPatternCalendar.getCalendar().getTime();
 		Calendar work = Calendar.getInstance();
 		work.setTime(date);
 		work.set(Calendar.MILLISECOND, 0);
@@ -530,19 +589,20 @@ public class CalendarPatternDialog extends CommonDialog {
 		boolean result = false;
 		createCalendarIrregularInfo();
 		CalendarPatternInfo info = this.inputData;
+		String managerName = this.m_managerComposite.getText();
 		if(info != null){
 			if(mode == PropertyDefineConstant.MODE_ADD){
 				// 作成の場合+
 				info = this.inputData;
-				result = new AddCalendar().addCalendarPatternInfo(info);
+				result = new AddCalendar().addCalendarPatternInfo(managerName, info);
 			} else if (mode == PropertyDefineConstant.MODE_MODIFY){
 				// 変更の場合
-				info.setId(txtID.getText());
-				result = new ModifyCalendar().modifyPatternInfo(info);
+				info.setId(calPatternIdText.getText());
+				result = new ModifyCalendar().modifyPatternInfo(managerName, info);
 			} else if(mode == PropertyDefineConstant.MODE_COPY){
 				// コピーの場合
-				info.setId(txtID.getText());
-				result = new AddCalendar().addCalendarPatternInfo(info);
+				info.setId(calPatternIdText.getText());
+				result = new AddCalendar().addCalendarPatternInfo(managerName, info);
 			}
 		} else {
 			//m_log.error("info is null");
