@@ -29,9 +29,10 @@ import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.bean.PriorityConstant;
-import com.clustercontrol.commons.util.HinemosProperties;
+import com.clustercontrol.commons.util.JpaTransactionManager;
 import com.clustercontrol.fault.HinemosUnknown;
 import com.clustercontrol.fault.InvalidRole;
+import com.clustercontrol.maintenance.util.HinemosPropertyUtil;
 import com.clustercontrol.monitor.bean.EventConfirmConstant;
 import com.clustercontrol.notify.bean.OutputBasicInfo;
 import com.clustercontrol.notify.session.NotifyControllerBean;
@@ -44,12 +45,12 @@ import com.clustercontrol.util.CommandExecutor.CommandResult;
 import com.clustercontrol.util.StringBinder;
 
 /**
- * 
+ *
  * Hinemosの内部ログ（HinemosApp.log）の出力を行うクラス<BR>
- * 
+ *
  * Hinemos内部で発生する事象をログやHinemosのイベントとして
  * 処理します。
- * 
+ *
  */
 public class AplLogger {
 
@@ -59,158 +60,19 @@ public class AplLogger {
 	private static final String INTERNAL_SCOPE="INTERNAL";
 	private static final String INTERNAL_SCOPE_TEXT="Hinemos_Internal";
 
-	private static final String PRIORITY_UNKNOWN = "unknown";
 	private static final String PRIORITY_INFO = "info";
 	private static final String PRIORITY_WARNING = "warning";
 	private static final String PRIORITY_CRITICAL = "critical";
 	private String m_pluginID;
 	private String m_aplName;
 
-	private static ConcurrentHashMap<String, String> m_priorityMap = null;
-	
 	private static ConcurrentHashMap<Long, Boolean> m_isInternalMode = new ConcurrentHashMap<Long, Boolean>();
-
-
-	// Syslog
-	private static boolean isSyslog = false;
-	private static int syslogLevel = PriorityConstant.TYPE_INFO;
-	private static String[] syslogHostList = {"127.0.0.1"};
-	private static int syslogPort = 514;
-	private static String syslogFacility = "daemon";
-	private static String syslogSeverity = "alert";
-
-	// event
-	private static boolean isEvent = true;
-	private static int eventLevel = PriorityConstant.TYPE_INFO;
-
-	// file
-	private static boolean isFile = true;
-	private static int fileLevel = PriorityConstant.TYPE_INFO;
-
-	// mail
-	private static boolean isMail = true;
-	private static int mailLevel = PriorityConstant.TYPE_INFO;
-	private static String[] mailAddress = {""};
-
-	// command
-	private static boolean isCommand = true;
-	private static int commandLevel = PriorityConstant.TYPE_INFO;
-	private static String commandUser = "root";
-	private static String commandLine = "";
-	private static int commandTimeout = 15000;
-
 	private static Log FILE_LOGGER = LogFactory.getLog("HinemosInternal");
 	private static Log log = LogFactory.getLog(AplLogger.class);
 
-	static {
-		// hinemos.propertiesから設定値の取得
-		initialParameter();
-	}
-
-	/**
-	 * hinemos.propertiesから設定値の取得
-	 */
-	private static void initialParameter(){
-
-		try {
-			/////
-			// 設定値取得(common.internal.syslog)
-			////
-			String syslog = HinemosProperties.getProperty("common.internal.syslog");
-			if(syslog != null && syslog.equals("true")){
-				isSyslog = true;
-			}
-			String hosts = HinemosProperties.getProperty("common.internal.syslog.host");
-			syslogHostList = hosts.split(",");
-			syslogPort = Integer.parseInt(HinemosProperties.getProperty("common.internal.syslog.port"));
-			syslogFacility = HinemosProperties.getProperty("common.internal.syslog.facility");
-			syslogSeverity = HinemosProperties.getProperty("common.internal.syslog.severity");
-			syslogLevel = getPriority(HinemosProperties.getProperty("common.internal.syslog.priority"));
-
-			/////
-			// 設定値取得(common.internal.event)
-			////
-			String event = HinemosProperties.getProperty("common.internal.event");
-			if(event != null && event.equals("false")){
-				isEvent = false;
-			}
-			eventLevel = getPriority(HinemosProperties.getProperty("common.internal.event.priority"));
-
-			/////
-			// 設定値取得(common.internal.file)
-			////
-			String file = HinemosProperties.getProperty("common.internal.file");
-			if(file != null && file.equals("false")){
-				isFile = false;
-			}
-			fileLevel = getPriority(HinemosProperties.getProperty("common.internal.file.priority"));
-
-			/////
-			// 設定値取得(common.internal.mail)
-			////
-			String mail = HinemosProperties.getProperty("common.internal.mail");
-			if(mail != null && mail.equals("false")){
-				isMail = false;
-			}
-			mailLevel = getPriority(HinemosProperties.getProperty("common.internal.mail.priority"));
-			String addr = HinemosProperties.getProperty("common.internal.mail.address");
-			try {
-				mailAddress = addr.split(",");
-			} catch (Exception e) {}
-
-			/////
-			// 設定値取得(common.internal.command)
-			////
-			String command = HinemosProperties.getProperty("common.internal.command");
-			if(command != null && command.equals("false")){
-				isCommand = false;
-			}
-			commandLevel = getPriority(HinemosProperties.getProperty("common.internal.command.priority"));
-			commandUser = HinemosProperties.getProperty("common.internal.command.user");
-			commandLine = HinemosProperties.getProperty("common.internal.command.commandline");
-			try {
-				commandTimeout = Integer.parseInt(HinemosProperties.getProperty("common.internal.command.timeout"));
-			} catch (Exception e) {}
-
-		} catch (Exception e) {
-			log.error("initialParameter()",e);
-		}
-
-		//重要度文字列取得
-		m_priorityMap = new ConcurrentHashMap<String, String>();
-		m_priorityMap.put(PRIORITY_CRITICAL, getString("priority.critical"));
-		m_priorityMap.put(PRIORITY_WARNING, getString("priority.warning"));
-		m_priorityMap.put(PRIORITY_INFO, getString("priority.info"));
-		m_priorityMap.put(PRIORITY_UNKNOWN, getString("priority.unknown"));
-
-		// debug用出力
-		if(log.isDebugEnabled()){
-			log.debug("initialParameter() isEvent=" + isEvent + ", eventLevel=" + eventLevel);
-			log.debug("initialParameter() isFile=" + isFile + ", fileLevel=" + fileLevel);
-			log.debug("initialParameter() isMail=" + isMail + ", mailLevel=" + mailLevel);
-			log.debug("initialParameter() isCommand=" + isCommand + ", commandLevel=" + commandLevel);
-			log.debug("initialParameter() isSyslog=" + isSyslog + ", syslogLevel=" + syslogLevel);
-			if (isSyslog) {
-				String syslogHostStr = "";
-				if(syslogHostList != null){
-					for (int i = 0; i < syslogHostList.length; i++) {
-						if (i != 0) {
-							syslogHostStr += ",";
-						}
-						syslogHostStr += syslogHostList[i];
-					}
-				}
-				log.debug("initialParameter() syslogPort=" + syslogPort +
-						", syslogFacility=" + syslogFacility +
-						", syslogSeverity=" + syslogSeverity +
-						", syslogHost=" + syslogHostStr);
-			}
-		}
-	}
-
 	/**
 	 * コンストラクタ<BR>
-	 * 
+	 *
 	 * @param pluginID	プラグインID
 	 * @param aplId		アプリケーションID
 	 */
@@ -235,31 +97,31 @@ public class AplLogger {
 
 	/**
 	 * ログを出力します。<BR>
-	 * 
-	 * @param moniterID		監視項目ID
+	 *
+	 * @param monitorID		監視項目ID
 	 * @param msgID			メッセージID
 	 * @since
 	 */
-	public void put(String moniterID, String msgID) {
-		put(moniterID, msgID,null,null);
+	public void put(String monitorID, String msgID) {
+		put(monitorID, msgID,null,null);
 	}
 
 	/**
-	 * 
+	 *
 	 * ログを出力します。<BR>
-	 * @param moniterID		監視項目ID
+	 * @param monitorID		監視項目ID
 	 * @param msgID			メッセージID
 	 * @param msgArgs		メッセージ置換項目
 	 * @since
 	 */
-	public void put(String moniterID, String msgID, Object[] msgArgs) {
-		put(moniterID, msgID,msgArgs,null);
+	public void put(String monitorID, String msgID, Object[] msgArgs) {
+		put(monitorID, msgID,msgArgs,null);
 	}
 
 	/**
-	 * 
+	 *
 	 * ログを出力します。<BR>
-	 * 
+	 *
 	 * @param monitorId		監視項目ID
 	 * @param msgID			メッセージID
 	 * @param msgArgs		メッセージ置換項目
@@ -267,6 +129,20 @@ public class AplLogger {
 	 * @since
 	 */
 	public void put(String monitorId, String msgID, Object[] msgArgs, String detailMsg) {
+		put(monitorId, msgID, msgArgs, detailMsg, null);
+	}
+
+	/**
+	 *
+	 * ログを出力します。<BR>
+	 *
+	 * @param monitorId		監視項目ID
+	 * @param msgID			メッセージID
+	 * @param msgArgs		メッセージ置換項目
+	 * @param detailMsg		詳細メッセージ
+	 * @since
+	 */
+	public void put(String monitorId, String msgID, Object[] msgArgs, String detailMsg, Integer priority) {
 		// 既にINTERNALモードに入っている場合はこれ以上出力しない
 		Boolean isInternalMode = m_isInternalMode.get(Thread.currentThread().getId());
 		if(isInternalMode != null && isInternalMode){
@@ -277,21 +153,23 @@ public class AplLogger {
 			// INTERNALモードに入る
 			log.debug("AplLogger INTERNAL mode start");
 			m_isInternalMode.put(Thread.currentThread().getId(), true);
-			
+
 			//現在日時取得
 			Date nowDate = new Date();
-	
+
 			//監視項目IDとプラグインIDでイベントメッセージ（リソースファイル）から
 			String keyBase = m_pluginID + "." + monitorId + "." + msgID;
-	
+
 			//重要度を取得
 			String keyPriority = keyBase + "." + "priority";
-	
-			String priority = getString(keyPriority);
-	
+
+			if (priority == null) {
+				priority = getPriority(getString(keyPriority));
+			}
+
 			//メッセージを取得する。
 			String keyMsg = keyBase + "." + "message";
-	
+
 			//メッセージ項目値が指定されている場合、メッセージの項目を置換
 			String msg = null;
 			if(msgArgs != null && msgArgs.length != 0){
@@ -299,10 +177,10 @@ public class AplLogger {
 			}else{
 				msg = getString(keyMsg);
 			}
-	
+
 			//    	・発生日時				:現在日時※メソッド呼び出し時に取得したもの
 			//    	・出力日時				:現在日時※イベント出力直前に取得したもの
-	
+
 			//メッセージ情報作成
 			OutputBasicInfo output = new OutputBasicInfo();
 			output.setPluginId(m_pluginID);
@@ -313,24 +191,57 @@ public class AplLogger {
 			output.setMessageId(msgID);
 			output.setMessage(msg);
 			output.setMessageOrg(detailMsg == null ? "":detailMsg);
-			output.setPriority(getPriority(priority));
+			output.setPriority(priority);
 			if (nowDate != null) {
 				output.setGenerationDate(nowDate.getTime());
 			}
-	
-			if(isEvent && isOutput(eventLevel, getPriority(priority))){
+
+			/////
+			// 設定値取得(internal.event)
+			////
+			boolean isEvent = HinemosPropertyUtil.getHinemosPropertyBool("internal.event", true);
+			int eventLevel = getPriority(HinemosPropertyUtil.getHinemosPropertyStr("internal.event.priority", PRIORITY_INFO));
+
+			if(isEvent && isOutput(eventLevel, priority)){
 				putEvent(output);
 			}
-			if(isFile && isOutput(fileLevel, getPriority(priority))){
+
+			/////
+			// 設定値取得(internal.file)
+			////
+			boolean isFile = HinemosPropertyUtil.getHinemosPropertyBool("internal.file", true);
+			int fileLevel = getPriority(HinemosPropertyUtil.getHinemosPropertyStr("internal.file.priority", PRIORITY_INFO));
+
+			if(isFile && isOutput(fileLevel, priority)){
 				putFile(output);
 			}
-			if (isSyslog && isOutput(syslogLevel, getPriority(priority))){
+
+			/////
+			// 設定値取得(internal.syslog)
+			////
+			boolean isSyslog = HinemosPropertyUtil.getHinemosPropertyBool("internal.syslog", false);
+			int syslogLevel = getPriority(HinemosPropertyUtil.getHinemosPropertyStr("internal.syslog.priority", PRIORITY_INFO));
+			if (isSyslog && isOutput(syslogLevel, priority)){
 				putSyslog(output);
 			}
-			if (isMail && isOutput(mailLevel, getPriority(priority))) {
+
+			/////
+			// 設定値取得(internal.mail)
+			////
+			boolean isMail = HinemosPropertyUtil.getHinemosPropertyBool("internal.mail", false);
+			int mailLevel = getPriority(HinemosPropertyUtil.getHinemosPropertyStr(
+					"internal.mail.priority", PRIORITY_INFO));
+			if (isMail && isOutput(mailLevel, priority)) {
 				putMail(output);
 			}
-			if (isCommand && isOutput(commandLevel, getPriority(priority))) {
+
+			/////
+			// 設定値取得(internal.command)
+			////
+			boolean isCommand = HinemosPropertyUtil.getHinemosPropertyBool("internal.command", true);
+			int commandLevel = getPriority(HinemosPropertyUtil.getHinemosPropertyStr("internal.command.priority", PRIORITY_INFO));
+
+			if (isCommand && isOutput(commandLevel, priority)) {
 				putCommand(output);
 			}
 		}finally{
@@ -367,7 +278,16 @@ public class AplLogger {
 		// 送信時刻をセット
 		SimpleDateFormat sdf = new SimpleDateFormat(SendSyslog.HEADER_DATE_FORMAT, Locale.US);
 		String timeStamp = sdf.format(new Date());
-		
+
+		/////
+		// 設定値取得(internal.syslog)
+		////
+		String hosts = HinemosPropertyUtil.getHinemosPropertyStr("internal.syslog.host", "192.168.1.1,192.168.1.2");
+		String[] syslogHostList = hosts.split(",");
+		int syslogPort = HinemosPropertyUtil.getHinemosPropertyNum("internal.syslog.port", 514);
+		String syslogFacility = HinemosPropertyUtil.getHinemosPropertyStr("internal.syslog.facility", "daemon");
+		String syslogSeverity = HinemosPropertyUtil.getHinemosPropertyStr("internal.syslog.severity", "alert");
+
 		if(syslogHostList == null){
 			return;
 		}
@@ -388,7 +308,17 @@ public class AplLogger {
 	}
 
 	private boolean putEvent(OutputBasicInfo notifyInfo) {
+		JpaTransactionManager jtm = null;
+		
 		try {
+			// rollbackするとイベントが出力されなくなるため、rollback用のコールバックメソッドを登録する 
+			jtm = new JpaTransactionManager(); 
+			jtm.begin(); 
+			
+			jtm.addCallback(new AplLoggerPutEventAfterRollbackCallback(notifyInfo)); 
+			
+			jtm.commit(); 
+			
 			new NotifyControllerBean().insertEventLog(notifyInfo, EventConfirmConstant.TYPE_UNCONFIRMED);
 			return true;
 		} catch (HinemosUnknown e) {
@@ -397,12 +327,16 @@ public class AplLogger {
 		} catch (InvalidRole e) {
 			log.warn("fail putEvent monitorId=" + notifyInfo.getMonitorId() + ", message=" + notifyInfo.getMessage());
 			return false;
+		} finally {
+			jtm.close();
 		}
 	}
 
 	private void putMail(OutputBasicInfo notifyInfo) {
 		// メール通知（デフォルトテンプレート）
 		try {
+			String addr = HinemosPropertyUtil.getHinemosPropertyStr("internal.mail.address", "user1@host.domain,user2@host.domain");
+			String[] mailAddress = addr.split(",");
 			new NotifyControllerBean().sendMail(mailAddress, notifyInfo);
 		} catch (Exception e) {
 			log.warn("fail putMail monitorId=" + notifyInfo.getMonitorId() + ", message=" + notifyInfo.getMessage());
@@ -412,6 +346,15 @@ public class AplLogger {
 	private void putCommand(OutputBasicInfo notifyInfo) {
 		// コマンド通知
 		try {
+			String commandUser = HinemosPropertyUtil.getHinemosPropertyStr("internal.command.user", "root");
+			String commandLine = HinemosPropertyUtil.getHinemosPropertyStr(
+					"internal.command.commandline",
+					"echo #[GENERATION_DATE] #[MESSAGE] >> /tmp/test.txt");
+			int commandTimeout = 0;
+			try {
+				commandTimeout = HinemosPropertyUtil.getHinemosPropertyNum("internal.command.timeout", 15000);
+			} catch (Exception e) {}
+
 			Map<String, String> param = NotifyUtil.createParameter(notifyInfo, null);
 			StringBinder binder = new StringBinder(param);
 			String command = binder.bindParam(commandLine);
@@ -434,13 +377,13 @@ public class AplLogger {
 
 
 	/**
-	 * 
+	 *
 	 * 文字列から、Priority区分を取得します。<BR>
-	 * 
+	 *
 	 * @param priority
 	 * @since
 	 */
-	private static int getPriority(String priority) {
+	private int getPriority(String priority) {
 		int ret = PriorityConstant.TYPE_UNKNOWN;
 		if(priority.equals(PRIORITY_CRITICAL)){
 			ret = PriorityConstant.TYPE_CRITICAL;
@@ -496,7 +439,7 @@ public class AplLogger {
 
 	/**
 	 * メッセージを置換します<BR>
-	 * 
+	 *
 	 * @param key リソース名
 	 * @param args メッセージの引数
 	 * @return the メッセージ
@@ -508,7 +451,7 @@ public class AplLogger {
 
 	/**
 	 * メッセージを置換します<BR>
-	 * 
+	 *
 	 * @param key リソース名
 	 * @return the メッセージ
 	 */
