@@ -15,28 +15,22 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.custom.factory;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
-
-import com.clustercontrol.custom.bean.CustomConstant;
 import com.clustercontrol.custom.bean.CustomCheckInfo;
+import com.clustercontrol.custom.bean.CustomConstant;
 import com.clustercontrol.custom.model.MonitorCustomInfoEntity;
+import com.clustercontrol.custom.util.QueryUtil;
 import com.clustercontrol.fault.InvalidRole;
 import com.clustercontrol.fault.MonitorNotFound;
 import com.clustercontrol.monitor.run.factory.ModifyMonitorNumericValueType;
 import com.clustercontrol.monitor.run.model.MonitorInfoEntity;
-import com.clustercontrol.custom.util.QueryUtil;
 import com.clustercontrol.plugin.impl.SchedulerPlugin.TriggerType;
 
 /**
  * コマンド監視の特有設定に対する変更処理実装クラス<br/>
  * @since 4.0
- * @author Tomoya Takahata
  */
 public class ModifyCustom extends ModifyMonitorNumericValueType {
 
-	private static Log m_log = LogFactory.getLog( ModifyCustom.class );
-
 	/**
 	 * コマンド監視特有の設定情報を更新する。<br/>
 	 * また、コマンド監視設定が変更されたことを影響するエージェントに通知する。<br/>
