@@ -29,6 +29,7 @@ import com.clustercontrol.calendar.bean.CalendarInfo;
 import com.clustercontrol.calendar.session.CalendarControllerBean;
 import com.clustercontrol.commons.util.AbstractCacheManager;
 import com.clustercontrol.commons.util.CacheManagerFactory;
+import com.clustercontrol.commons.util.HinemosSessionContext;
 import com.clustercontrol.commons.util.ICacheManager;
 import com.clustercontrol.commons.util.ILock;
 import com.clustercontrol.commons.util.ILockManager;
@@ -74,6 +75,7 @@ public class SelectCustom extends SelectMonitor {
 			}
 		} finally {
 			_lock.writeUnlock();
+			m_log.info("Static Initialization [Thread : " + Thread.currentThread() + ", User : " + (String)HinemosSessionContext.instance().getProperty(HinemosSessionContext.LOGIN_USER_ID) + "]");
 		}
 	}
 	
@@ -123,11 +125,14 @@ public class SelectCustom extends SelectMonitor {
 	public static void refreshCache() {
 		m_log.info("refresh cache");
 		
+		long startTime = System.currentTimeMillis();
 		try {
 			_lock.writeLock();
 			
-			ArrayList<MonitorInfo> customCache = new SelectCustom().getMonitorList(HinemosModuleConstant.MONITOR_CUSTOM);
+			ArrayList<MonitorInfo> customCache = new SelectCustom().getMonitorListObjectPrivilegeModeNONE(HinemosModuleConstant.MONITOR_CUSTOM);
 			storeCache(customCache);
+			m_log.info("refresh customCache " + (System.currentTimeMillis() - startTime) +
+					"ms. size=" + customCache.size());
 		} catch (Exception e) {
 			m_log.warn("failed refreshing cache.", e);
 		} finally {
