@@ -15,13 +15,15 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.hinemosagent.action;
 
+import java.util.List;
+
 import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.monitor.action.DeleteInterface;
 import com.clustercontrol.monitor.util.MonitorSettingEndpointWrapper;
 
 /**
  * Hinemos Agent監視情報をマネージャから削除するクラス<BR>
- * 
+ *
  * @version 4.0.0
  * @since 2.0.0
  */
@@ -29,12 +31,14 @@ public class DeleteAgent implements DeleteInterface{
 
 	/**
 	 * Hinemos Agent監視情報を削除します。<BR>
-	 * 
-	 * @param monitorId 状態監視ID
+	 *
+	 * @param managerName マネージャ名
+	 * @param monitorIdList 状態監視IDリスト
 	 * @return 削除に成功した場合、true
 	 */
 	@Override
-	public boolean delete(String monitorId) throws Exception {
-		return MonitorSettingEndpointWrapper.deleteMonitor(monitorId, HinemosModuleConstant.MONITOR_AGENT);
+	public boolean delete(String managerName, List<String> monitorIdList) throws Exception {
+		MonitorSettingEndpointWrapper wrapper = MonitorSettingEndpointWrapper.getWrapper(managerName);
+		return wrapper.deleteMonitor(monitorIdList, HinemosModuleConstant.MONITOR_AGENT);
 	}
-}
\ No newline at end of file
+}
