@@ -477,8 +477,13 @@ public class AgentConnectUtil {
 			Set<AgentInfo> removedSet = new HashSet<AgentInfo>();
 			for (Entry<String, AgentInfo> entry : new HashSet<Entry<String, AgentInfo>>(agentMap.entrySet())) {
 				if (! entry.getValue().isValid()) {
-					removedSet.add(agentMap.remove(entry));
-					m_log.info("remove " + entry.getValue());
+					AgentInfo agentInfo = agentMap.remove(entry.getKey()); 
+					removedSet.add(agentInfo);
+					if (agentInfo != null) {
+						m_log.info("remove " + agentInfo);
+					} else {
+						m_log.warn("agentInfo is null");
+					}
 				}
 			}
 			if (removedSet.size() > 0) {
