@@ -20,6 +20,7 @@ import org.apache.commons.logging.LogFactory;
 import org.eclipse.jface.dialogs.MessageDialog;
 
 import com.clustercontrol.bean.HinemosModuleConstant;
+import com.clustercontrol.monitor.bean.MonitorTypeMstConstant;
 import com.clustercontrol.monitor.util.MonitorSettingEndpointWrapper;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.ws.monitor.InvalidRole_Exception;
@@ -27,7 +28,7 @@ import com.clustercontrol.ws.monitor.MonitorInfo;
 
 /**
  * HTTP監視設定情報を取得するクライアント側アクションクラス<BR>
- * 
+ *
  * @version 2.1.0
  * @since 2.1.0
  */
@@ -38,16 +39,24 @@ public class GetHttp {
 
 	/**
 	 * HTTP監視情報をマネージャから取得します。<BR>
-	 * 
+	 *
 	 * @param monitorId 監視項目ID
+	 * @param monitorType 監視判定タイプ
 	 * @return HTTP監視情報
 	 */
-	public MonitorInfo getHttp(String monitorId) {
+	public MonitorInfo getHttp(String managerName, String monitorId, int monitorType) {
 
 		MonitorInfo info = null;
 
 		try {
-			info = MonitorSettingEndpointWrapper.getMonitor(monitorId, HinemosModuleConstant.MONITOR_HTTP);
+			MonitorSettingEndpointWrapper wrapper = MonitorSettingEndpointWrapper.getWrapper(managerName);
+			if (monitorType == MonitorTypeMstConstant.MONITOR_TYPE_NUMERIC) {
+				info = wrapper.getMonitor(monitorId, HinemosModuleConstant.MONITOR_HTTP_N);
+			} else if (monitorType == MonitorTypeMstConstant.MONITOR_TYPE_STRING) {
+				info = wrapper.getMonitor(monitorId, HinemosModuleConstant.MONITOR_HTTP_S);
+			} else {
+				info = wrapper.getMonitor(monitorId, HinemosModuleConstant.MONITOR_HTTP_SCENARIO);
+			}
 
 		} catch (InvalidRole_Exception e) {
 			// アクセス権なしの場合、エラーダイアログを表示する
@@ -67,4 +76,4 @@ public class GetHttp {
 
 		return info;
 	}
-}
\ No newline at end of file
+}
