@@ -259,13 +259,13 @@ public class GetHttpResponse implements Closeable {
 				while (es.hasMoreElements()) {
 					Object n = es.nextElement();
 					Object v = a.getAttribute(n);
-					map.put(n.toString(), v.toString());
+					map.put(n.toString().toUpperCase(), v.toString().toUpperCase());
 				}
 
-				String he = map.get("http-equiv");
+				String he = map.get("HTTP-EQUIV");
 				if (he != null) {
-					if ("Content-Type".equals(he)) {
-						String c = map.get("content");
+					if ("CONTENT-TYPE".equals(he)) {
+						String c = map.get("CONTENT");
 						if (c != null) {
 							Matcher m = chasetPattern.matcher(c);
 							if (m.matches())
@@ -275,7 +275,7 @@ public class GetHttpResponse implements Closeable {
 				}
 				else {
 					if (a.getAttributeCount() == 1) {
-						String cs = map.get("charset");
+						String cs = map.get("CHARSET");
 						if (cs != null)
 							charset = cs;
 					}
@@ -295,7 +295,7 @@ public class GetHttpResponse implements Closeable {
 
 	private static final Log m_log = LogFactory.getLog( GetHttpResponse.class );
 
-	private static final Pattern chasetPattern = Pattern.compile("^\\s*.+\\s*;\\s*charset\\s*=\\s*(.*)\\s*$");
+	private static final Pattern chasetPattern = Pattern.compile("^\\s*.+\\s*;\\s*charset\\s*=\\s*(.*)\\s*$", Pattern.CASE_INSENSITIVE);
 
 	/** ボディ取得対象のContent-Type */
 	private static final String TARGET_CONTENT_TYPE = "text";
