@@ -154,6 +154,7 @@ public class FileTransferModuleInfo extends InfraModuleInfo<FileTransferModuleIn
 			return send(
 					node.getFacilityId(),
 					node.getAvailableIpAddress(),
+					node.getWinrmProtocol(),
 					access,
 					srcDir,
 					srcFile,
@@ -232,6 +233,7 @@ public class FileTransferModuleInfo extends InfraModuleInfo<FileTransferModuleIn
 			return isSameMd5(
 							node.getFacilityId(),
 							node.getAvailableIpAddress(),
+							node.getWinrmProtocol(),
 							access,
 							srcDir,
 							srcFile,
@@ -245,6 +247,7 @@ public class FileTransferModuleInfo extends InfraModuleInfo<FileTransferModuleIn
 			ModuleNodeResult ret2 = recv(
 				node.getFacilityId(),
 				node.getAvailableIpAddress(),
+				node.getWinrmProtocol(),
 				access,
 				getDestPath(),
 				fileName,
@@ -335,6 +338,7 @@ public class FileTransferModuleInfo extends InfraModuleInfo<FileTransferModuleIn
 			fis = new FileInputStream(orgFile);
 			os = Files.newOutputStream(Paths.get(dstFilepath));
 			ByteArrayOutputStream bos = new ByteArrayOutputStream();
+			ByteArrayOutputStream bos1 = new ByteArrayOutputStream();
 			byte[] buf = new byte[1024*1024];
 			while (true) {
 				int read = fis.read(buf);
@@ -352,25 +356,27 @@ public class FileTransferModuleInfo extends InfraModuleInfo<FileTransferModuleIn
 							for (FileTransferVariableInfo info : list) {
 								byteArray = replace(byteArray, info.getName(), info.getValue());
 							}
-							os.write(byteArray);
+							bos1.write(byteArray);
 						}
 	
 						//write \r or \n
-						os.write(b);
+						bos1.write(b);
 					} else {
 						bos.write(b);
 					}
 				}
-			}
-			
-			if (bos.size() > 0) {
-				byte[] byteArray = bos.toByteArray();
-
-				//replace
-				for (FileTransferVariableInfo info : list) {
-					byteArray = replace(byteArray, info.getName(), info.getValue());
+				if(bos1.size() > 0) {
+					os.write(bos1.toByteArray());
+					bos1.reset();
+				}
+				if(bos.size() > 0) {
+					byte[] byteArray = bos.toByteArray();
+					for (FileTransferVariableInfo info : list) {
+						byteArray = replace(byteArray, info.getName(), info.getValue());
+					}
+					os.write(byteArray);
+					bos.reset();
 				}
-				os.write(byteArray);
 			}
 		} catch (IOException e) {
 			HinemosUnknown exception = new HinemosUnknown("createFile " + e.getClass().getName() + ", " + e.getMessage(), e);
@@ -393,23 +399,30 @@ public class FileTransferModuleInfo extends InfraModuleInfo<FileTransferModuleIn
 	}
 	
 	private static byte[] replace(byte[] byteArray, String name, String value) throws IOException {
-		ByteArrayOutputStream bos = new ByteArrayOutputStream();
-		byte[] nameByteArray = name.getBytes();
-		int i= 0;
-		while (i <= byteArray.length - nameByteArray.length) {
-			if (compareByteArray(byteArray, i, nameByteArray)) {
-				bos.write(value.getBytes());
-				i += nameByteArray.length;
-			} else {
-				bos.write(byteArray[i]);
-				i++;
+		ByteArrayOutputStream bos = null;
+		try {
+			bos = new ByteArrayOutputStream();
+			byte[] nameByteArray = name.getBytes();
+			int i= 0;
+			while (i <= byteArray.length - nameByteArray.length) {
+				if (compareByteArray(byteArray, i, nameByteArray)) {
+					bos.write(value.getBytes());
+					i += nameByteArray.length;
+				} else {
+					bos.write(byteArray[i]);
+					i++;
+				}
+			}
+			if (i < byteArray.length) {
+				bos.write(byteArray, i, byteArray.length - i);
 			}
-		}
-		if (i < byteArray.length) {
-			bos.write(byteArray, i, byteArray.length - i);
-		}
 		
-		return bos.toByteArray();
+			return bos.toByteArray();
+		} catch (IOException e) {
+			throw e;
+		} finally {
+			bos.close();
+		}
 	}
 
 	private static boolean compareByteArray(byte[] byteArray1, int byteArray1Offset, byte[] byteArray2) {
@@ -426,7 +439,7 @@ public class FileTransferModuleInfo extends InfraModuleInfo<FileTransferModuleIn
 		return true;
 	}
 	
-	private ModuleNodeResult send(String facilityId, String host, AccessInfo access,
+	private ModuleNodeResult send(String facilityId, String host, String protocol, AccessInfo access,
 			String srcDir, String srcFile, String dstDir, String dstFile, String owner, String perm, String account) {
 		ModuleNodeResult ret = null;
 		
@@ -438,7 +451,7 @@ public class FileTransferModuleInfo extends InfraModuleInfo<FileTransferModuleIn
 					owner, perm, isBackupIfExistFlg(), access.getSshPrivateKeyFilepath(), access.getSshPrivateKeyPassphrase());
 			break;
 		case SendMethodConstant.TYPE_WINRM:
-			ret = WinRMUtil.sendFile(access.getWinRmUser(), access.getWinRmPassword(), host, access.getWinRmPort(),
+			ret = WinRMUtil.sendFile(access.getWinRmUser(), access.getWinRmPassword(), host, access.getWinRmPort(), protocol,
 					srcDir, srcFile, dstDir, dstFile,
 					owner, perm, isBackupIfExistFlg(), account);
 			break;
@@ -455,7 +468,7 @@ public class FileTransferModuleInfo extends InfraModuleInfo<FileTransferModuleIn
 		return ret;
 	}
 	
-	private ModuleNodeResult isSameMd5(String facilityId, String host, AccessInfo access,
+	private ModuleNodeResult isSameMd5(String facilityId, String host, String protocol, AccessInfo access,
 			String srcDir, String srcFile, String dstDir, String dstFile) {
 		ModuleNodeResult ret = null;
 		switch (getSendMethodType()) {
@@ -464,7 +477,7 @@ public class FileTransferModuleInfo extends InfraModuleInfo<FileTransferModuleIn
 					srcDir, srcFile, dstDir, dstFile, access.getSshPrivateKeyFilepath() , access.getSshPrivateKeyPassphrase());
 			break;
 		case SendMethodConstant.TYPE_WINRM:
-			ret = WinRMUtil.isSameMd5(access.getWinRmUser(), access.getWinRmPassword(), host, access.getWinRmPort(),
+			ret = WinRMUtil.isSameMd5(access.getWinRmUser(), access.getWinRmPassword(), host, access.getWinRmPort(), protocol,
 					srcDir, srcFile, dstDir, dstFile);
 			break;
 		default:
@@ -476,7 +489,7 @@ public class FileTransferModuleInfo extends InfraModuleInfo<FileTransferModuleIn
 		return ret;
 	}
 
-	private ModuleNodeResult recv(String facilityId, String host, AccessInfo access, 
+	private ModuleNodeResult recv(String facilityId, String host, String protocol, AccessInfo access, 
 			String srcDir, String srcFile, String dstDir, String dstFile, String owner, String perm) {
 		ModuleNodeResult ret = null;
 		long start = System.currentTimeMillis();
@@ -486,7 +499,7 @@ public class FileTransferModuleInfo extends InfraModuleInfo<FileTransferModuleIn
 					srcDir, srcFile, dstDir, dstFile, owner, perm, access.getSshPrivateKeyFilepath(), access.getSshPrivateKeyPassphrase());
 			break;
 		case SendMethodConstant.TYPE_WINRM:
-			ret = WinRMUtil.recvFile(access.getWinRmUser(), access.getWinRmPassword(), host, access.getWinRmPort(), srcDir, srcFile, dstDir, dstFile, owner, perm);
+			ret = WinRMUtil.recvFile(access.getWinRmUser(), access.getWinRmPassword(), host, access.getWinRmPort(), protocol, srcDir, srcFile, dstDir, dstFile, owner, perm);
 			break;
 		default:
 			String msg = String.format("AccessMethodType is invalid. value = %d", getSendMethodType());
