@@ -35,6 +35,7 @@ import com.clustercontrol.infra.bean.FileTransferModuleInfo;
 import com.clustercontrol.infra.bean.ModuleNodeResult;
 import com.clustercontrol.infra.bean.OkNgConstant;
 import com.clustercontrol.maintenance.util.HinemosPropertyUtil;
+import com.clustercontrol.util.XMLUtil;
 import com.jcraft.jsch.ChannelExec;
 import com.jcraft.jsch.JSch;
 import com.jcraft.jsch.JSchException;
@@ -119,7 +120,7 @@ public class JschUtil {
 			msg = msg + std.substring(0, Math.min(std.length(), (maxSize - msg.length() - 1) - Math.min((maxSize - msg.length() - 1) / 2, err.length()))) + "\n";
 			msg = msg + err.substring(0, Math.min(err.length(), (maxSize - msg.length() - 1) / 2));
 
-			return new ModuleNodeResult(channel.getExitStatus() == 0 ? OkNgConstant.TYPE_OK: OkNgConstant.TYPE_NG, channel.getExitStatus(), msg);
+			return new ModuleNodeResult(channel.getExitStatus() == 0 ? OkNgConstant.TYPE_OK: OkNgConstant.TYPE_NG, channel.getExitStatus(), XMLUtil.ignoreInvalidString(msg));
 		}
 		finally {
 			channel.disconnect();
