@@ -24,7 +24,7 @@ import org.apache.commons.logging.LogFactory;
 
 /**
  * ジョブのコマンドに関する情報を保持するクラス
- * 
+ *
  * @version 2.0.0
  * @since 1.0.0
  */
@@ -63,43 +63,50 @@ public class JobCommandInfo implements Serializable {
 	private Integer m_messageRetry;
 
 	/** コマンド実行失敗時終了フラグ */
-	private Integer m_errorEndFlg = new Integer(0);
+	private Integer m_messageRetryEndFlg = new Integer(0);
 
 	/** コマンド実行失敗時終了値 */
-	private Integer m_errorEndValue = new Integer(0);
+	private Integer m_messageRetryEndValue = new Integer(0);
+
+	/** 正常終了するまでリトライフラグ */
+	private Integer m_commandRetryFlg = new Integer(0);
+
+	/** 正常終了するまでリトライ回数 */
+	private Integer m_commandRetry;
+
 
 	/**
 	 * コマンド実行失敗時終了フラグを返す。<BR>
 	 * @return コマンド実行失敗時終了フラグ
 	 * @see com.clustercontrol.bean.YesNoConstant
 	 */
-	public Integer getErrorEndFlg() {
-		return m_errorEndFlg;
+	public Integer getMessageRetryEndFlg() {
+		return m_messageRetryEndFlg;
 	}
 
 	/**
 	 * コマンド実行失敗時終了フラグを設定する。<BR>
-	 * @param errorEndFlg コマンド実行失敗時終了フラグ
+	 * @param messageRetryEndFlg コマンド実行失敗時終了フラグ
 	 * @see com.clustercontrol.bean.YesNoConstant
 	 */
-	public void setErrorEndFlg(Integer errorEndFlg) {
-		this.m_errorEndFlg = errorEndFlg;
+	public void setMessageRetryEndFlg(Integer messageRetryEndFlg) {
+		this.m_messageRetryEndFlg = messageRetryEndFlg;
 	}
 
 	/**
 	 * コマンド実行失敗時終了値を返す。<BR>
 	 * @return コマンド実行失敗時終了値
 	 */
-	public Integer getErrorEndValue() {
-		return m_errorEndValue;
+	public Integer getMessageRetryEndValue() {
+		return m_messageRetryEndValue;
 	}
 
 	/**
 	 * コマンド実行失敗時終了値を設定する。<BR>
-	 * @param errorEndValue コマンド実行失敗時終了値
+	 * @param messageRetryEndValue コマンド実行失敗時終了値
 	 */
-	public void setErrorEndValue(Integer errorEndValue) {
-		this.m_errorEndValue = errorEndValue;
+	public void setMessageRetryEndValue(Integer messageRetryEndValue) {
+		this.m_messageRetryEndValue = messageRetryEndValue;
 	}
 
 	/**
@@ -249,6 +256,40 @@ public class JobCommandInfo implements Serializable {
 		this.m_messageRetry = messageRetry;
 	}
 
+
+	/**
+	 * 正常終了するまでリトライフラグを返す。<BR>
+	 * @return 正常終了するまでリトライフラグ
+	 */
+	public Integer getCommandRetryFlg() {
+		return m_commandRetryFlg;
+	}
+
+	/**
+	 * 正常終了するまでリトライフラグを設定する。<BR>
+	 * @param errorRetryFlg 正常終了するまでリトライフラグ
+	 */
+	public void setCommandRetryFlg(Integer commandRetryFlg) {
+		this.m_commandRetryFlg = commandRetryFlg;
+	}
+
+
+	/**
+	 * 正常終了するまでリトライ回数を返す。<BR>
+	 * @return 正常終了するまでリトライ回数
+	 */
+	public Integer getCommandRetry() {
+		return m_commandRetry;
+	}
+
+	/**
+	 * 正常終了するまでリトライ回数を設定する。<BR>
+	 * @param commandRetry 正常終了するまでリトライ回数
+	 */
+	public void setCommandRetry(Integer commandRetry) {
+		this.m_commandRetry = commandRetry;
+	}
+
 	@Override
 	public boolean equals(Object o) {
 		if (!(o instanceof JobCommandInfo)) {
@@ -258,12 +299,13 @@ public class JobCommandInfo implements Serializable {
 		JobCommandInfo o2 = (JobCommandInfo)o;
 
 		boolean ret = false;
-		ret = 	equalsSub(o1.getErrorEndFlg(), o2.getErrorEndFlg()) &&
-				equalsSub(o1.getErrorEndValue(), o2.getErrorEndValue()) &&
+		ret = 	equalsSub(o1.getMessageRetryEndFlg(), o2.getMessageRetryEndFlg()) &&
+				equalsSub(o1.getMessageRetryEndValue(), o2.getMessageRetryEndValue()) &&
 				equalsSub(o1.getFacilityID(), o2.getFacilityID()) &&
 				equalsSub(o1.getMessageRetry(), o2.getMessageRetry()) &&
+				equalsSub(o1.getCommandRetryFlg(), o2.getCommandRetryFlg()) &&
+				equalsSub(o1.getCommandRetry(), o2.getCommandRetry()) &&
 				equalsSub(o1.getProcessingMethod(), o2.getProcessingMethod()) &&
-				equalsSub(o1.getScope(), o2.getScope()) &&
 				equalsSub(o1.getSpecifyUser(), o2.getSpecifyUser()) &&
 				equalsSub(o1.getStartCommand(), o2.getStartCommand()) &&
 				equalsSub(o1.getStopCommand(), o2.getStopCommand()) &&
@@ -327,10 +369,10 @@ public class JobCommandInfo implements Serializable {
 			info2 = createSampleInfo();
 			switch (i) {
 			case 0 :
-				info2.setErrorEndFlg(1);
+				info2.setMessageRetryEndFlg(1);
 				break;
 			case 1 :
-				info2.setErrorEndValue(1);
+				info2.setMessageRetryEndValue(1);
 				break;
 			case 2 :
 				info2.setFacilityID("facility_ID");
@@ -371,8 +413,8 @@ public class JobCommandInfo implements Serializable {
 	 */
 	public static JobCommandInfo createSampleInfo() {
 		JobCommandInfo info = new JobCommandInfo();
-		info.setErrorEndFlg(0);
-		info.setErrorEndValue(0);
+		info.setMessageRetryEndFlg(0);
+		info.setMessageRetryEndValue(0);
 		info.setFacilityID("facilityID");
 		info.setMessageRetry(0);
 		info.setProcessingMethod(0);
