@@ -36,7 +36,7 @@ import com.clustercontrol.jobmanagement.view.JobMapViewIF;
 
 /**
  * ジョブ[履歴]ビューのテーブルビューア用のSelectionChangedListenerです。
- * 
+ *
  * @version 1.0.0
  * @since 1.0.0
  */
@@ -50,7 +50,7 @@ public class HistorySelectionChangedListener implements ISelectionChangedListene
 
 	/**
 	 * コンストラクタ
-	 * 
+	 *
 	 * @param composite ジョブ[履歴]ビュー用のコンポジット
 	 */
 	public HistorySelectionChangedListener(HistoryComposite composite) {
@@ -67,24 +67,28 @@ public class HistorySelectionChangedListener implements ISelectionChangedListene
 	 * <li>セッションIDとジョブIDをジョブ[履歴]ビュー用のコンポジットに設定します。</li>
 	 * <li>ジョブ[ジョブ詳細]ビューを更新します。</li>
 	 * </ol>
-	 * 
+	 *
 	 * @param event 選択変更イベント
-	 * 
+	 *
 	 * @see org.eclipse.jface.viewers.ISelectionChangedListener#selectionChanged(org.eclipse.jface.viewers.SelectionChangedEvent)
 	 */
 	@Override
 	public void selectionChanged(SelectionChangedEvent event) {
+		String managerName = null;
 		String sessionId = null;
 		String jobunitId = null;
 		String jobId = null;
 
 		//セッションIDを取得
 		if (((StructuredSelection) event.getSelection()).getFirstElement() != null) {
-			ArrayList info = (ArrayList) ((StructuredSelection) event
+			ArrayList<?> info = (ArrayList<?>) ((StructuredSelection) event
 					.getSelection()).getFirstElement();
+			managerName = (String) info.get(GetHistoryTableDefine.MANAGER_NAME);
 			sessionId = (String) info.get(GetHistoryTableDefine.SESSION_ID);
 			jobunitId = (String) info.get(GetHistoryTableDefine.JOBUNIT_ID);
 			jobId = (String) info.get(GetHistoryTableDefine.JOB_ID);
+			//マネージャ名を設定
+			m_composite.setManagerName(managerName);
 			//セッションIDを設定
 			m_composite.setSessionId(sessionId);
 			//ジョブIDを設定
@@ -104,7 +108,7 @@ public class HistorySelectionChangedListener implements ISelectionChangedListene
 			if (viewPartDetail != null) {
 				JobDetailView view = (JobDetailView) viewPartDetail
 						.getAdapter(JobDetailView.class);
-				view.update(sessionId, jobunitId);
+				view.update(managerName, sessionId, jobunitId);
 			}
 		} else {
 			//ジョブマップ[履歴]ビューを更新する
@@ -113,11 +117,11 @@ public class HistorySelectionChangedListener implements ISelectionChangedListene
 			if (viewReference == null){
 				return;
 			}
-			IViewPart viewPart = viewReference.getView(false); 
+			IViewPart viewPart = viewReference.getView(false);
 			if (viewPart != null && !(viewPart instanceof ErrorViewPart)) {
 				m_log.debug("viewPart " + viewPart.getClass().getName());
 				JobMapViewIF view = (JobMapViewIF) viewPart;
-				view.update(sessionId, null);
+				view.update(managerName, sessionId, null);
 			}
 		}
 	}
