@@ -39,6 +39,7 @@ import org.eclipse.swt.widgets.Text;
 
 import com.clustercontrol.accesscontrol.bean.RoleIdConstant;
 import com.clustercontrol.bean.DataRangeConstant;
+import com.clustercontrol.bean.PatternConstant;
 import com.clustercontrol.bean.RequiredFieldColorConstant;
 import com.clustercontrol.bean.SizeConstant;
 import com.clustercontrol.composite.RoleIdListComposite;
@@ -1126,7 +1127,7 @@ public class JobDialog extends CommonDialog {
 				info.setJobunitId(oldJobunitId);
 			}
 			// ジョブユニットIDの文字制約のチェック
-			if(!m_jobIdText.getText().matches("^[A-Za-z0-9-_]+$")){
+			if(!m_jobIdText.getText().matches(PatternConstant.HINEMOS_ID_PATTERN)){
 				result = new ValidateResult();
 				result.setValid(false);
 				result.setID(Messages.getString("message.hinemos.1"));
@@ -1229,7 +1230,7 @@ public class JobDialog extends CommonDialog {
 				return result;
 			}
 			// ジョブIDの文字制約のチェック
-			if(!m_jobIdText.getText().matches("^[A-Za-z0-9-_]+$")){
+			if(!m_jobIdText.getText().matches(PatternConstant.HINEMOS_ID_PATTERN)){
 				result = new ValidateResult();
 				result.setValid(false);
 				result.setID(Messages.getString("message.hinemos.1"));
