@@ -24,7 +24,6 @@ import java.util.Comparator;
 import java.util.Date;
 import java.util.HashMap;
 import java.util.List;
-import java.util.Map;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
@@ -53,7 +52,6 @@ import com.clustercontrol.jobmanagement.bean.ProcessingMethodConstant;
 import com.clustercontrol.jobmanagement.bean.RunInstructionInfo;
 import com.clustercontrol.jobmanagement.bean.RunResultInfo;
 import com.clustercontrol.jobmanagement.bean.RunStatusConstant;
-import com.clustercontrol.jobmanagement.bean.SystemParameterConstant;
 import com.clustercontrol.jobmanagement.model.JobEndInfoEntity;
 import com.clustercontrol.jobmanagement.model.JobInfoEntity;
 import com.clustercontrol.jobmanagement.model.JobSessionJobEntity;
@@ -64,10 +62,7 @@ import com.clustercontrol.jobmanagement.util.ParameterUtil;
 import com.clustercontrol.jobmanagement.util.QueryUtil;
 import com.clustercontrol.jobmanagement.util.SendTopic;
 import com.clustercontrol.maintenance.util.HinemosPropertyUtil;
-import com.clustercontrol.repository.bean.NodeInfo;
 import com.clustercontrol.repository.factory.NodeProperty;
-import com.clustercontrol.repository.session.RepositoryControllerBean;
-import com.clustercontrol.repository.util.RepositoryUtil;
 import com.clustercontrol.util.Messages;
 
 public class JobSessionNodeImpl {
@@ -114,7 +109,9 @@ public class JobSessionNodeImpl {
 			//実行中のノードが存在するかチェック
 			for (JobSessionNodeEntity sessionNode : jobSessionNodeList) {
 				//実行状態が実行中の場合
-				if(sessionNode.getStatus() == StatusConstant.TYPE_RUNNING){
+				//停止処理中(終了遅延等)は後続のノードを実行させないため、「実行された」状態とする
+				if (sessionNode.getStatus() == StatusConstant.TYPE_RUNNING
+						|| sessionNode.getStatus() == StatusConstant.TYPE_STOPPING) {
 					return false;
 				}
 			}
@@ -233,11 +230,11 @@ public class JobSessionNodeImpl {
 	 * @param jobunitId
 	 * @param jobId
 	 * @param facilityId
-	 * @return
+	 * @return 0:実行、1:ジョブ詳細が実行中ではない、-1:実行しない
 	 * @throws JobInfoNotFound
 	 */
-	public boolean wait2running(JobSessionNodeEntityPK pk) {
-		boolean startCommand = false;
+	public int wait2running(JobSessionNodeEntityPK pk) {
+		int startCommand = -1;
 
 		String sessionId = pk.getSessionId();
 		String jobunitId = pk.getJobunitId();
@@ -249,14 +246,35 @@ public class JobSessionNodeImpl {
 			sessionNode = QueryUtil.getJobSessionNodePK(sessionId, jobunitId, jobId, facilityId);
 		} catch (JobInfoNotFound e) {
 			m_log.warn("wait2running " + e.getMessage());
-			return false;
+			return -1;
 		}
 
-		//実行状態が待機でない場合
+		//ノード詳細の実行状態が待機でない場合
 		if(sessionNode.getStatus() != StatusConstant.TYPE_WAIT){
-			return startCommand;
+			return -1;
 		}
 
+		JobSessionJobEntity sessionJobEntity = null;
+		try {
+			sessionJobEntity = QueryUtil.getJobSessionJobPK(sessionId, jobunitId, jobId);
+		} catch (JobInfoNotFound e) {
+			m_log.warn("wait2running " + e.getMessage());
+			return -1;
+		} catch (InvalidRole e) {
+			m_log.warn("wait2running " + e.getMessage());
+			return -1;
+		}
+
+		//ジョブ詳細の実行状態が実行中でない場合、
+		//waitQueueから削除し、false を返す
+		if(sessionJobEntity.getStatus() != StatusConstant.TYPE_RUNNING){
+			m_log.info("wait2running job detail is not running " + sessionNode.getId().getFacilityId() +
+					"," + sessionNode.getId().getSessionId() +
+					", status is " + StatusConstant.typeToString(sessionJobEntity.getStatus()));
+			
+			return 1;
+		}
+		
 		//実行状態を実行中にする
 		m_log.info("wait2running " + sessionNode.getId().getFacilityId() +
 				"," + sessionNode.getId().getSessionId());
@@ -268,7 +286,7 @@ public class JobSessionNodeImpl {
 			m_log.debug("startNode() : send RunInstructionInfo() : " +
 					"sessionId=" + sessionId + ", jobId=" + jobId + ", facilityId=" + sessionNode.getId().getFacilityId());
 			runJobSessionNode(sessionId, jobunitId, jobId, sessionNode.getId().getFacilityId());
-			startCommand = true;
+			startCommand = 0;
 		} catch (Exception e) {
 			m_log.warn("startNode() RunInstructionInfo() send error : " +
 					"sessionId=" + sessionId + ", jobId=" + jobId + ", facilityId=" + sessionNode.getId().getFacilityId() + " : "
