@@ -16,6 +16,7 @@ PURPOSE.  See the GNU General Public License for more details.
 package com.clustercontrol.jobmanagement.factory;
 
 import java.util.Collection;
+import java.util.Collections;
 import java.util.List;
 
 import org.apache.commons.logging.Log;
@@ -160,37 +161,40 @@ public class OperateStartOfJob {
 
 		if(job.getJobType() == JobConstant.TYPE_JOB){
 			//ジョブの場合
+			List<JobSessionNodeEntity> nodeEntityList;
 			if(facilityId != null && facilityId.length() > 0){
-				//ノードの場合
-				JobSessionNodeEntity sessionNode = QueryUtil.getJobSessionNodePK(sessionId, jobunitId, jobId, facilityId);
-
-				//セッションノードの実行状態に待機を設定
-				sessionNode.setStatus(StatusConstant.TYPE_WAIT);
-
-				//終了値、終了・中断日時、開始・再実行日時をクリア
-				sessionNode.setEndValue(null);
-				sessionNode.setEndDate(null);
-				sessionNode.setStartDate(null);
-				sessionNode.setRetryCount(0);
-				sessionNode.setResult(null);
-				sessionNode.setMessage(null);
-			}else{
-				Collection<JobSessionNodeEntity> collection = sessionJob.getJobSessionNodeEntities();
-				if(collection != null) {
-					for (JobSessionNodeEntity sessionNode : collection) {
-
-						//セッションノードの実行状態に待機を設定
-						sessionNode.setStatus(StatusConstant.TYPE_WAIT);
-
-						//終了値、終了・中断日時、開始・再実行日時をクリア
-						sessionNode.setEndValue(null);
-						sessionNode.setEndDate(null);
-						sessionNode.setStartDate(null);
-						sessionNode.setRetryCount(0);
-						sessionNode.setErrorRetryCount(0);
-						sessionNode.setResult(null);
-						sessionNode.setMessage(null);
+				// ノード詳細の場合
+				nodeEntityList = Collections.<JobSessionNodeEntity>singletonList(QueryUtil.getJobSessionNodePK(sessionId, jobunitId, jobId, facilityId));
+			} else {
+				// ジョブ詳細の場合
+				nodeEntityList = sessionJob.getJobSessionNodeEntities();
+			}
+			
+			if(nodeEntityList != null) {
+				for (JobSessionNodeEntity sessionNode : nodeEntityList) {
+					// ジョブを中断から開始即時に遷移する場合、実行中のノード詳細は現在実行中のプロセスを
+					// そのまま実行し続け、新規にプロセスを起こすことはないため、ノードが実行中の場合にはステータスクリアは行わない
+					if (sessionNode.getStatus() == StatusConstant.TYPE_RUNNING) {
+						try {
+							m_log.info("clearStatus() : skip clearStatus because running job is not completed. "
+									+ "sessionId=" + sessionId + ", jobunitId=" + jobunitId
+									+ ", jobId=" + jobId + ", facilityId=" + sessionNode.getId().getFacilityId());
+						} catch (RuntimeException e) {
+						}
+						continue;
 					}
+					
+					//セッションノードの実行状態に待機を設定
+					sessionNode.setStatus(StatusConstant.TYPE_WAIT);
+
+					//終了値、終了・中断日時、開始・再実行日時をクリア
+					sessionNode.setEndValue(null);
+					sessionNode.setEndDate(null);
+					sessionNode.setStartDate(null);
+					sessionNode.setRetryCount(0);
+					sessionNode.setErrorRetryCount(0);
+					sessionNode.setResult(null);
+					sessionNode.setMessage(null);
 				}
 			}
 		}else if(job.getJobType() == JobConstant.TYPE_FILEJOB && !CreateHulftJob.isHulftMode()){
