@@ -348,12 +348,20 @@ public class JobMultiplicityCache {
 					jtm.begin();
 					JobSessionNodeEntityPK pk = waitingQueue.peek(); //// waitQueueから取得(まだ削除はしない)
 					m_log.debug("kick remove waitQueue : " + pk);
-					if (new JobSessionNodeImpl().wait2running(pk)) {
+					int status = new JobSessionNodeImpl().wait2running(pk);
+					 // ジョブノードを実行済み
+					if (status == 0) {
 						m_log.debug("kick add runningQueue : " + pk);
 						waitingQueue.poll(); //// waitQueueから削除
 						runningQueue.offer(pk); //// runningQueueに追加
 						kickFlag = true;
 					}
+					// ジョブノードを実行しない（ジョブ詳細の実行状態が「実行中」ではない）
+					else if (status == 1) {
+						m_log.debug("kick not add runningQueue : " + pk);
+						waitingQueue.poll(); //// waitQueueから削除
+						kickFlag = true;
+					}
 					jtm.commit();
 				} catch (Exception e) {
 					m_log.warn("kick : " + e.getClass().getSimpleName() + ", " + e.getMessage(), e);
@@ -413,6 +421,7 @@ public class JobMultiplicityCache {
 			_lock.writeLock();
 			
 			HashMap<String, Queue<JobSessionNodeEntityPK>> runningCache = new HashMap<String, Queue<JobSessionNodeEntityPK>>();
+			storeWaitingCache(new HashMap<String, Queue<JobSessionNodeEntityPK>>());
 			
 			// runningQueueの再構築
 			{
