@@ -17,10 +17,6 @@ package com.clustercontrol.jobmanagement.view;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-import org.eclipse.jface.action.ActionContributionItem;
-import org.eclipse.jface.action.IMenuListener;
-import org.eclipse.jface.action.IMenuManager;
-import org.eclipse.jface.action.IToolBarManager;
 import org.eclipse.jface.action.MenuManager;
 import org.eclipse.jface.preference.IPreferenceStore;
 import org.eclipse.jface.viewers.ISelection;
@@ -29,20 +25,25 @@ import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Menu;
+import org.eclipse.ui.PlatformUI;
+import org.eclipse.ui.commands.ICommandService;
 
 import com.clustercontrol.ClusterControlPlugin;
+import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.bean.Property;
 import com.clustercontrol.jobmanagement.composite.HistoryComposite;
 import com.clustercontrol.jobmanagement.composite.action.JobHistorySelectionChangedListener;
 import com.clustercontrol.jobmanagement.preference.JobManagementPreferencePage;
-import com.clustercontrol.jobmanagement.view.action.StartJobAction;
-import com.clustercontrol.jobmanagement.view.action.StopJobAction;
+import com.clustercontrol.jobmanagement.view.action.HistoryFilterAction;
+import com.clustercontrol.jobmanagement.view.action.HistoryRefreshAction;
+import com.clustercontrol.jobmanagement.view.action.StartJobHistoryAction;
+import com.clustercontrol.jobmanagement.view.action.StopJobHistoryAction;
 import com.clustercontrol.view.AutoUpdateView;
 
 /**
  * ジョブ[履歴]ビュークラスです。
- * 
- * @version 1.0.0
+ *
+ * @version 5.0.0
  * @since 1.0.0
  */
 public class JobHistoryView extends AutoUpdateView {
@@ -51,12 +52,17 @@ public class JobHistoryView extends AutoUpdateView {
 	private static Log m_log = LogFactory.getLog( JobHistoryView.class );
 
 	/** ビューID */
-	public static final String ID = "com.clustercontrol.jobmanagement.view.JobHistoryView";
+	public static final String ID = JobHistoryView.class.getName();
 	/** ジョブ[履歴]ビュー用のコンポジット */
 	private HistoryComposite m_history = null;
 	/** フィルタ条件 */
 	private Property m_condition = null;
 
+	/**
+	 * Number of selected items
+	 */
+	private int selectedNum;
+
 	/**
 	 * コンストラクタ
 	 */
@@ -66,9 +72,9 @@ public class JobHistoryView extends AutoUpdateView {
 
 	/**
 	 * ビューを構築します。
-	 * 
+	 *
 	 * @param parent 親コンポジット
-	 * 
+	 *
 	 * @see org.eclipse.ui.IWorkbenchPart#createPartControl(org.eclipse.swt.widgets.Composite)
 	 * @see com.clustercontrol.view.AutoUpdateView#setInterval(int)
 	 * @see com.clustercontrol.view.AutoUpdateView#startAutoReload()
@@ -83,6 +89,7 @@ public class JobHistoryView extends AutoUpdateView {
 		layout.marginWidth = 0;
 
 		m_history = new HistoryComposite(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, null, m_history);
 		GridData gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.verticalAlignment = GridData.FILL;
@@ -115,53 +122,23 @@ public class JobHistoryView extends AutoUpdateView {
 
 	/**
 	 * コンテキストメニューを作成します。
-	 * 
+	 *
 	 * @see org.eclipse.jface.action.MenuManager
 	 * @see org.eclipse.swt.widgets.Menu
 	 */
 	private void createContextMenu() {
 		MenuManager menuManager = new MenuManager();
 		menuManager.setRemoveAllWhenShown(true);
-		menuManager.addMenuListener(new IMenuListener() {
-			/* (non-Javadoc)
-			 * @see org.eclipse.jface.action.IMenuListener#menuAboutToShow(org.eclipse.jface.action.IMenuManager)
-			 */
-			@Override
-			public void menuAboutToShow(IMenuManager manager) {
-				//メニュー項目設定
-				fillContextMenu(manager);
-			}
-		});
 
 		Menu menu = menuManager.createContextMenu(m_history.getTable());
+		WidgetTestUtil.setTestId(this, null, menu);
 		m_history.getTable().setMenu(menu);
-	}
-
-	/**
-	 * コンテキストメニューに項目を追加します。
-	 * 
-	 * @param manager メニューマネージャ
-	 * 
-	 * @see org.eclipse.jface.action.IToolBarManager
-	 * @see org.eclipse.jface.action.IMenuManager
-	 */
-	private void fillContextMenu(IMenuManager manager) {
-		//ビューのアクションのインスタンスを取得
-		IToolBarManager toolbar = this.getViewSite().getActionBars()
-				.getToolBarManager();
-		ActionContributionItem startJobAction = (ActionContributionItem) toolbar
-				.find(StartJobAction.ID);
-		ActionContributionItem stopJobAction = (ActionContributionItem) toolbar
-				.find(StopJobAction.ID);
-
-		//ポップアップメニューにアクションを追加
-		manager.add(startJobAction.getAction());
-		manager.add(stopJobAction.getAction());
+		getSite().registerContextMenu( menuManager, this.m_history.getTableViewer() );
 	}
 
 	/**
 	 * フィルタ条件を返します。
-	 * 
+	 *
 	 * @return フィルタ条件
 	 */
 	public Property getFilterCondition() {
@@ -170,7 +147,7 @@ public class JobHistoryView extends AutoUpdateView {
 
 	/**
 	 * フィルタ条件を設定します。
-	 * 
+	 *
 	 * @param condition フィルタ条件
 	 */
 	public void setFilterCondition(Property condition) {
@@ -179,7 +156,7 @@ public class JobHistoryView extends AutoUpdateView {
 
 	/**
 	 * ビューを更新します。
-	 * 
+	 *
 	 * @see com.clustercontrol.jobmanagement.composite.HistoryComposite#update()
 	 * @see com.clustercontrol.jobmanagement.composite.HistoryComposite#update(Property)
 	 */
@@ -198,30 +175,42 @@ public class JobHistoryView extends AutoUpdateView {
 
 	/**
 	 * ジョブ[履歴]ビュー用のコンポジットを返します。
-	 * 
+	 *
 	 * @return ジョブ[履歴]ビュー用のコンポジット
 	 */
 	public HistoryComposite getComposite() {
 		return m_history;
 	}
 
+	/**
+	 * Get the number of selected items
+	 * @return
+	 */
+	public int getSelectedNum(){
+		return this.selectedNum;
+	}
+
 	/**
 	 * ビューのアクションの有効/無効を設定します。
-	 * 
+	 *
 	 * @param num 選択イベント数
 	 * @param selection ボタン（アクション）を有効にするための情報
 	 */
 	public void setEnabledAction(int num, ISelection selection) {
-		//ビューアクションの使用可/不可を設定
-		super.setEnabledAction(StartJobAction.ID, selection);
-		super.setEnabledAction(StopJobAction.ID, selection);
+		this.selectedNum = num;
 
-		if (num > 0){
-			super.setEnabledAction(StartJobAction.ID, true);
-			super.setEnabledAction(StopJobAction.ID, true);
-		} else {
-			super.setEnabledAction(StartJobAction.ID, false);
-			super.setEnabledAction(StopJobAction.ID, false);
+		//ビューアクションの使用可/不可を設定
+		ICommandService service = (ICommandService) PlatformUI.getWorkbench().getService( ICommandService.class );
+		if( null != service ){
+			service.refreshElements(StartJobHistoryAction.ID, null);
+			service.refreshElements(StopJobHistoryAction.ID, null);
+			service.refreshElements(HistoryFilterAction.ID, null);
+			service.refreshElements(HistoryRefreshAction.ID, null);
+
+			// Update ToolBar after elements refreshed
+			// WARN : Both ToolBarManager must be updated after updateActionBars(), otherwise icon won't change.
+			getViewSite().getActionBars().updateActionBars();
+			getViewSite().getActionBars().getToolBarManager().update(false);
 		}
 	}
-}
\ No newline at end of file
+}
