@@ -37,15 +37,15 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
 
-import com.clustercontrol.accesscontrol.bean.RoleIdConstant;
+import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.bean.DayOfWeekConstant;
-import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.bean.Property;
 import com.clustercontrol.bean.PropertyDefineConstant;
 import com.clustercontrol.bean.RequiredFieldColorConstant;
 import com.clustercontrol.bean.ScheduleConstant;
 import com.clustercontrol.bean.ValidConstant;
 import com.clustercontrol.calendar.composite.CalendarIdListComposite;
+import com.clustercontrol.composite.ManagerListComposite;
 import com.clustercontrol.composite.RoleIdListComposite;
 import com.clustercontrol.composite.RoleIdListComposite.Mode;
 import com.clustercontrol.composite.action.ComboModifyListener;
@@ -67,7 +67,7 @@ import com.clustercontrol.ws.notify.NotifyRelationInfo;
 
 /**
  * メンテナンス[メンテナンスの作成・変更]ダイアログクラスです。
- * 
+ *
  * @version 4.0.0
  * @since 2.2.0
  */
@@ -111,33 +111,28 @@ public class MaintenanceDialog extends CommonDialog {
 	/** 通知情報 */
 	private NotifyInfoComposite notifyInfo = null;
 	/** オーナーロールID用テキスト */
-	// TODO: メンテナンス設定にオブジェクト権限を指定できるようななったら修正する
-//	private RoleIdListComposite m_ownerRoleId = null;
-	private String m_ownerRoleId = RoleIdConstant.ADMINISTRATORS;
+	private RoleIdListComposite m_ownerRoleId = null;
 	/** この設定を有効にする */
 	private Button confirmValid = null;
 
 	private MaintenanceInfo maintenanceInfo = null;
 
-	/**
-	 * コンストラクタ
-	 * 
-	 * @param parent 親シェル
-	 */
-	public MaintenanceDialog(Shell parent) {
-		super(parent);
-		this.mode = PropertyDefineConstant.MODE_ADD;
-	}
+	/** マネージャ名コンボボックス用コンポジット */
+	private ManagerListComposite m_managerComposite = null;
 
-	public MaintenanceDialog(Shell parent, String maintenanceId, int mode) {
+	/** マネージャ名 */
+	private String managerName = null;
+
+	public MaintenanceDialog(Shell parent, String managerName, String maintenanceId, int mode) {
 		super(parent);
+		this.managerName = managerName;
 		this.maintenanceId = maintenanceId;
 		this.mode = mode;
 	}
 
 	/**
 	 * ダイアログエリアを生成します。
-	 * 
+	 *
 	 * @param parent 親コンポジット
 	 */
 	@Override
@@ -159,11 +154,52 @@ public class MaintenanceDialog extends CommonDialog {
 		layout.numColumns = 15;
 		parent.setLayout(layout);
 
+		/*
+		 * マネージャ
+		 */
+		Label labelManager = new Label(parent, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "manager", labelManager);
+		gridData = new GridData();
+		gridData.horizontalSpan = WIDTH_TITLE;
+		gridData.horizontalAlignment = GridData.FILL;
+		gridData.grabExcessHorizontalSpace = true;
+		labelManager.setLayoutData(gridData);
+		labelManager.setText(Messages.getString("facility.manager") + " : ");
+		if(this.mode == PropertyDefineConstant.MODE_MODIFY){
+			this.m_managerComposite = new ManagerListComposite(parent, SWT.NONE, false);
+		} else {
+			this.m_managerComposite = new ManagerListComposite(parent, SWT.NONE, true);
+		}
+		WidgetTestUtil.setTestId(this, "managerComposite", this.m_managerComposite);
+		gridData = new GridData();
+		gridData.horizontalSpan = WIDTH_TEXT;
+		gridData.horizontalAlignment = GridData.FILL;
+		gridData.grabExcessHorizontalSpace = true;
+		this.m_managerComposite.setLayoutData(gridData);
+
+		if(this.managerName != null) {
+			this.m_managerComposite.setText(this.managerName);
+		}
+		if(this.mode != PropertyDefineConstant.MODE_MODIFY) {
+			this.m_managerComposite.getComboManagerName().addSelectionListener(new SelectionAdapter() {
+				@Override
+				public void widgetSelected(SelectionEvent e) {
+					String managerName = m_managerComposite.getText();
+					m_ownerRoleId.createRoleIdList(managerName);
+					m_calendarId.createCalIdCombo(managerName, m_ownerRoleId.getText());
+					notifyInfo.setManagerName(m_managerComposite.getText());
+					m_maintenance_type.setManagerName(m_managerComposite.getText());
+					m_maintenance_type.update();
+				}
+			});
+		}
+
 		/*
 		 * メンテナンスID
 		 */
 		// ラベル
 		label = new Label(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "maintenanceid", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_TITLE;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -172,6 +208,7 @@ public class MaintenanceDialog extends CommonDialog {
 		label.setText(Messages.getString("maintenance.id") + " : ");
 		// テキスト
 		this.m_textMaintenanceId = new Text(parent, SWT.BORDER | SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "id", m_textMaintenanceId);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_TEXT;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -190,6 +227,7 @@ public class MaintenanceDialog extends CommonDialog {
 
 		// 空白
 		label = new Label(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space2", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = 2;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -201,6 +239,7 @@ public class MaintenanceDialog extends CommonDialog {
 		 */
 		// ラベル
 		label = new Label(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "description", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_TITLE;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -209,6 +248,7 @@ public class MaintenanceDialog extends CommonDialog {
 		label.setText(Messages.getString("description") + " : ");
 		// テキスト
 		this.m_textDescription = new Text(parent, SWT.BORDER | SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "description", m_textDescription);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_TEXT;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -223,6 +263,7 @@ public class MaintenanceDialog extends CommonDialog {
 
 		// 空白
 		label = new Label(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space3", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = 2;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -232,45 +273,45 @@ public class MaintenanceDialog extends CommonDialog {
 		/*
 		 * オーナーロールID
 		 */
-		// TODO: メンテナンス設定にオブジェクト権限を指定できるようななったら修正する
-//		Label labelRoleId = new Label(parent, SWT.LEFT);
-//		gridData = new GridData();
-//		gridData.horizontalSpan = WIDTH_TITLE;
-//		gridData.horizontalAlignment = GridData.FILL;
-//		gridData.grabExcessHorizontalSpace = true;
-//		labelRoleId.setLayoutData(gridData);
-//		labelRoleId.setText(Messages.getString("owner.role.id") + " : ");
-//		if (this.mode == PropertyDefineConstant.MODE_ADD
-//				|| this.mode == PropertyDefineConstant.MODE_COPY) {
-//			this.m_ownerRoleId = new RoleIdListComposite(parent, SWT.NONE, true, Mode.OWNER_ROLE);
-//			this.m_ownerRoleId.getComboRoleId().addSelectionListener(new SelectionAdapter() {
-//				@Override
-//				public void widgetSelected(SelectionEvent e) {
-//					m_calendarId.setOwnerRoleId(m_ownerRoleId.getText());
-//					notifyInfo.setOwnerRoleId(m_ownerRoleId.getText());
-//				}
-//			});
-//		} else {
-//			this.m_ownerRoleId = new RoleIdListComposite(parent, SWT.NONE, false, Mode.OWNER_ROLE);
-//		}
-//		gridData = new GridData();
-//		gridData.horizontalSpan = WIDTH_TEXT;
-//		gridData.horizontalAlignment = GridData.FILL;
-//		gridData.grabExcessHorizontalSpace = true;
-//		m_ownerRoleId.setLayoutData(gridData);
-//
-//		// 空白
-//		label = new Label(parent, SWT.NONE);
-//		gridData = new GridData();
-//		gridData.horizontalSpan = 2;
-//		gridData.horizontalAlignment = GridData.FILL;
-//		gridData.grabExcessHorizontalSpace = true;
-//		label.setLayoutData(gridData);
+		Label labelRoleId = new Label(parent, SWT.LEFT);
+		gridData = new GridData();
+		gridData.horizontalSpan = WIDTH_TITLE;
+		gridData.horizontalAlignment = GridData.FILL;
+		gridData.grabExcessHorizontalSpace = true;
+		labelRoleId.setLayoutData(gridData);
+		labelRoleId.setText(Messages.getString("owner.role.id") + " : ");
+		if (this.mode == PropertyDefineConstant.MODE_ADD
+				|| this.mode == PropertyDefineConstant.MODE_COPY) {
+			this.m_ownerRoleId = new RoleIdListComposite(parent, SWT.NONE, this.managerName, true, Mode.OWNER_ROLE);
+			this.m_ownerRoleId.getComboRoleId().addSelectionListener(new SelectionAdapter() {
+				@Override
+				public void widgetSelected(SelectionEvent e) {
+					m_calendarId.createCalIdCombo(managerName, m_ownerRoleId.getText());
+					notifyInfo.setOwnerRoleId(m_ownerRoleId.getText(), true);
+				}
+			});
+		} else {
+			this.m_ownerRoleId = new RoleIdListComposite(parent, SWT.NONE, this.managerName, false, Mode.OWNER_ROLE);
+		}
+		gridData = new GridData();
+		gridData.horizontalSpan = WIDTH_TEXT;
+		gridData.horizontalAlignment = GridData.FILL;
+		gridData.grabExcessHorizontalSpace = true;
+		m_ownerRoleId.setLayoutData(gridData);
+
+		// 空白
+		label = new Label(parent, SWT.NONE);
+		gridData = new GridData();
+		gridData.horizontalSpan = 2;
+		gridData.horizontalAlignment = GridData.FILL;
+		gridData.grabExcessHorizontalSpace = true;
+		label.setLayoutData(gridData);
 
 		/*
 		 * 種別
 		 */
-		this.m_maintenance_type = new MaintenanceTypeListComposite(parent, SWT.NONE, true);
+		this.m_maintenance_type = new MaintenanceTypeListComposite(parent, SWT.NONE, this.m_managerComposite.getText(), true);
+		WidgetTestUtil.setTestId(this, "typelist", m_maintenance_type);
 		gridData = new GridData();
 		gridData.horizontalSpan = 15;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -288,6 +329,7 @@ public class MaintenanceDialog extends CommonDialog {
 		 */
 		// ラベル
 		label = new Label(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "retentionperiod", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_TITLE;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -296,6 +338,7 @@ public class MaintenanceDialog extends CommonDialog {
 		label.setText(Messages.getString("maintenance.retention.period") + " : ");
 		// テキスト
 		this.m_textDataRetentionPeriod = new Text(parent, SWT.BORDER | SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "dataretentionperiod", m_textDataRetentionPeriod);
 		this.m_textDataRetentionPeriod.setToolTipText(Messages.getString("message.maintenance.23"));
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_TEXT;
@@ -313,6 +356,7 @@ public class MaintenanceDialog extends CommonDialog {
 		 * カレンダ
 		 */
 		this.m_calendarId = new CalendarIdListComposite(parent, SWT.NONE, true);
+		WidgetTestUtil.setTestId(this, "calendaridlist", m_calendarId);
 		gridData = new GridData();
 		gridData.horizontalSpan = 15;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -320,6 +364,7 @@ public class MaintenanceDialog extends CommonDialog {
 		m_calendarId.setLayoutData(gridData);
 
 		label = new Label(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "schedule", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = 15;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -330,6 +375,7 @@ public class MaintenanceDialog extends CommonDialog {
 		 * スケジュール
 		 */
 		Group group1 = new Group(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "schedule", group1);
 		layout = new GridLayout(1, true);
 		layout.marginWidth = 5;
 		layout.marginHeight = 5;
@@ -351,6 +397,7 @@ public class MaintenanceDialog extends CommonDialog {
 		 */
 		// グループ
 		Group groupNotifyAttribute = new Group(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "notifyattribute", groupNotifyAttribute);
 		layout = new GridLayout(1, true);
 		layout.marginWidth = 5;
 		layout.marginHeight = 5;
@@ -365,16 +412,19 @@ public class MaintenanceDialog extends CommonDialog {
 
 		// 通知情報（通知ID，アプリケーションID）
 		this.notifyInfo = new NotifyInfoComposite(groupNotifyAttribute, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "notifyinfo", notifyInfo);
 		gridData = new GridData();
 		gridData.horizontalSpan = 1;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		notifyInfo.setLayoutData(gridData);
+		notifyInfo.setManagerName(this.m_managerComposite.getText());
 
 		/*
 		 * 有効／無効
 		 */
 		this.confirmValid = new Button(parent, SWT.CHECK);
+		WidgetTestUtil.setTestId(this, "confirmvalid", confirmValid);
 		gridData = new GridData();
 		gridData.horizontalSpan = 15;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -385,6 +435,7 @@ public class MaintenanceDialog extends CommonDialog {
 
 		// ラインを引く
 		Label line = new Label(parent, SWT.SEPARATOR | SWT.HORIZONTAL);
+		WidgetTestUtil.setTestId(this, "line", line);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
@@ -405,7 +456,7 @@ public class MaintenanceDialog extends CommonDialog {
 		//最後に変更であれば情報を表示する
 		MaintenanceInfo info = null;
 		if(this.maintenanceId != null){
-			info = new GetMaintenance().getMaintenanceInfo(this.maintenanceId);
+			info = new GetMaintenance().getMaintenanceInfo(this.m_managerComposite.getText(), this.maintenanceId);
 		}
 		this.setInputData(info);
 		this.reflectMaintenanceSchedule();
@@ -466,11 +517,12 @@ public class MaintenanceDialog extends CommonDialog {
 
 	/**
 	 * スケジュール日時指定を生成します。
-	 * 
+	 *
 	 * @param parent 親グループ
 	 */
 	private void createType1(Group parent) {
 		m_type1 = new Button(parent, SWT.RADIO);
+		WidgetTestUtil.setTestId(this, "type1", m_type1);
 		GridData gridData = new GridData();
 		gridData.horizontalSpan = 2;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -480,6 +532,7 @@ public class MaintenanceDialog extends CommonDialog {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
 				Button check = (Button) e.getSource();
+				WidgetTestUtil.setTestId(this, null, check);
 				if (check.getSelection()) {
 					m_type2.setSelection(false);
 					m_comboMonth.setEnabled(true);
@@ -500,6 +553,7 @@ public class MaintenanceDialog extends CommonDialog {
 		});
 
 		m_comboMonth = new Combo(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "month", m_comboMonth);
 		gridData = new GridData();
 		gridData.horizontalSpan = 2;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -516,6 +570,7 @@ public class MaintenanceDialog extends CommonDialog {
 		}
 
 		Label labelMonth = new Label(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "month", labelMonth);
 		labelMonth.setText(Messages.getString("month"));
 		gridData = new GridData();
 		gridData.horizontalSpan = 2;
@@ -524,6 +579,7 @@ public class MaintenanceDialog extends CommonDialog {
 		labelMonth.setLayoutData(gridData);
 
 		m_comboDay = new Combo(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "day", m_comboDay);
 		gridData = new GridData();
 		gridData.horizontalSpan = 2;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -540,6 +596,7 @@ public class MaintenanceDialog extends CommonDialog {
 		}
 
 		Label labelDay = new Label(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "day", labelDay);
 		labelDay.setText(Messages.getString("monthday"));
 		gridData = new GridData();
 		gridData.horizontalSpan = 2;
@@ -548,6 +605,7 @@ public class MaintenanceDialog extends CommonDialog {
 		labelDay.setLayoutData(gridData);
 
 		m_comboHours1 = new Combo(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "hours1", m_comboHours1);
 		gridData = new GridData();
 		gridData.horizontalSpan = 2;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -570,6 +628,7 @@ public class MaintenanceDialog extends CommonDialog {
 		});
 
 		Label labelHours = new Label(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "hours", labelHours);
 		labelHours.setText(Messages.getString("hour"));
 		gridData = new GridData();
 		gridData.horizontalSpan = 2;
@@ -578,6 +637,7 @@ public class MaintenanceDialog extends CommonDialog {
 		labelHours.setLayoutData(gridData);
 
 		m_comboMinutes1 = new Combo(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "minutes1", m_comboMinutes1);
 		gridData = new GridData();
 		gridData.horizontalSpan = 2;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -600,6 +660,7 @@ public class MaintenanceDialog extends CommonDialog {
 		});
 
 		Label labelMinutes = new Label(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "minutes", labelMinutes);
 		labelMinutes.setText(Messages.getString("minute"));
 		gridData = new GridData();
 		gridData.horizontalSpan = 3;
@@ -609,6 +670,7 @@ public class MaintenanceDialog extends CommonDialog {
 
 		// 空白
 		Label label = new Label(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "blank", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = 1;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -618,11 +680,12 @@ public class MaintenanceDialog extends CommonDialog {
 
 	/**
 	 * スケジュール曜日指定を生成します。
-	 * 
+	 *
 	 * @param parent 親グループ
 	 */
 	private void createType2(Group parent) {
 		m_type2 = new Button(parent, SWT.RADIO);
+		WidgetTestUtil.setTestId(this, "type2", m_type2);
 		GridData gridData = new GridData();
 		gridData.horizontalSpan = 2;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -632,6 +695,7 @@ public class MaintenanceDialog extends CommonDialog {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
 				Button check = (Button) e.getSource();
+				WidgetTestUtil.setTestId(this, null, check);
 				if (check.getSelection()) {
 					m_type1.setSelection(false);
 					m_comboMonth.setEnabled(false);
@@ -650,8 +714,9 @@ public class MaintenanceDialog extends CommonDialog {
 
 			}
 		});
-		
+
 		Label labelDummy = new Label(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "dummy", labelDummy);
 		labelDummy.setText("");
 		gridData = new GridData();
 		gridData.horizontalSpan = 1;
@@ -660,6 +725,7 @@ public class MaintenanceDialog extends CommonDialog {
 		labelDummy.setLayoutData(gridData);
 
 		m_comboDayOfWeek = new Combo(parent, SWT.READ_ONLY);
+		WidgetTestUtil.setTestId(this, "dayofweek", m_comboDayOfWeek);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
@@ -681,7 +747,8 @@ public class MaintenanceDialog extends CommonDialog {
 			}
 		});
 
-		Label labelDummy2 = new Label(parent, SWT.NONE);
+		Label label = new Label(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, null, label);
 		labelDummy.setText("");
 		gridData = new GridData();
 		gridData.horizontalSpan = 2;
@@ -690,6 +757,7 @@ public class MaintenanceDialog extends CommonDialog {
 		labelDummy.setLayoutData(gridData);
 
 		m_comboHours2 = new Combo(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "hours2", m_comboHours2);
 		gridData = new GridData();
 		gridData.horizontalSpan = 2;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -712,6 +780,7 @@ public class MaintenanceDialog extends CommonDialog {
 		});
 
 		Label labelHours = new Label(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "hours", labelHours);
 		labelHours.setText(Messages.getString("hour"));
 		gridData = new GridData();
 		gridData.horizontalSpan = 2;
@@ -720,6 +789,7 @@ public class MaintenanceDialog extends CommonDialog {
 		labelHours.setLayoutData(gridData);
 
 		m_comboMinutes2 = new Combo(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "minutes2", m_comboMinutes2);
 		gridData = new GridData();
 		gridData.horizontalSpan = 2;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -742,6 +812,7 @@ public class MaintenanceDialog extends CommonDialog {
 		});
 
 		Label labelMinutes = new Label(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "minutes", labelMinutes);
 		labelMinutes.setText(Messages.getString("minute"));
 		gridData = new GridData();
 		gridData.horizontalSpan = 3;
@@ -750,17 +821,18 @@ public class MaintenanceDialog extends CommonDialog {
 		labelMinutes.setLayoutData(gridData);
 
 		// 空白
-		Label label = new Label(parent, SWT.NONE);
+		Label labelSpace = new Label(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space", labelSpace);
 		gridData = new GridData();
 		gridData.horizontalSpan = 1;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
-		label.setLayoutData(gridData);
+		labelSpace.setLayoutData(gridData);
 	}
 
 	/**
 	 * ダイアログにスケジュール情報を反映します。
-	 * 
+	 *
 	 * @see com.clustercontrol.jobmanagement.bean.ScheduleTableDefine
 	 */
 	private void reflectMaintenanceSchedule() {
@@ -779,7 +851,7 @@ public class MaintenanceDialog extends CommonDialog {
 			this.update();
 			return;
 		}else{
-			maintenanceInfo = new GetMaintenance().getMaintenanceInfo(maintenanceId);
+			maintenanceInfo = new GetMaintenance().getMaintenanceInfo(this.m_managerComposite.getText(), maintenanceId);
 			//スケジュール設定
 			Schedule schedule = maintenanceInfo.getSchedule();
 
@@ -901,9 +973,9 @@ public class MaintenanceDialog extends CommonDialog {
 
 	/**
 	 * ダイアログの情報からスケジュール情報を作成します。
-	 * 
+	 *
 	 * @return 入力値の検証結果
-	 * 
+	 *
 	 * @see com.clustercontrol.jobmanagement.bean.ScheduleTableDefine
 	 */
 	private ValidateResult createMaintenanceInfo() {
@@ -919,21 +991,16 @@ public class MaintenanceDialog extends CommonDialog {
 		}
 
 		//オーナーロールID
-//		if (m_ownerRoleId.getText().length() > 0) {
-//			maintenanceInfo.setOwnerRoleId(m_ownerRoleId.getText());
-//		}
-		if (m_ownerRoleId.length() > 0) {
-			maintenanceInfo.setOwnerRoleId(m_ownerRoleId);
+		if (m_ownerRoleId.getText().length() > 0) {
+			maintenanceInfo.setOwnerRoleId(m_ownerRoleId.getText());
 		}
 
 		//説明取得
-		if (m_textDescription.getText().length() > 0) {
-			maintenanceInfo.setDescription(m_textDescription.getText());
-		}
+		maintenanceInfo.setDescription(m_textDescription.getText());
 
 		//種別
 		if(m_maintenance_type.getSelectionIndex() >= 0){
-			maintenanceInfo.setTypeId(m_maintenance_type.getSelectionTypeId());
+			maintenanceInfo.setTypeId(m_maintenance_type.getSelectionTypeId(this.m_managerComposite.getText()));
 		}
 		//保存期間(日)となる期間を指定
 		if(m_textDataRetentionPeriod.getText().length() > 0){
@@ -1040,17 +1107,14 @@ public class MaintenanceDialog extends CommonDialog {
 	protected void setInputData(MaintenanceInfo info) {
 
 		// オーナーロールID設定
-		// TODO: メンテナンス設定にオブジェクト権限を指定できるようななったら修正する
-//		if (info != null && info.getOwnerRoleId() != null) {
-//			this.m_ownerRoleId.setText(info.getOwnerRoleId());
-//		}
-		
+		if (info != null && info.getOwnerRoleId() != null) {
+			this.m_ownerRoleId.setText(info.getOwnerRoleId());
+		}
+
 		// 他CompositeへのオーナーロールIDの設定
-//		this.m_calendarId.setOwnerRoleId(m_ownerRoleId.getText());
-//		this.notifyInfo.setOwnerRoleId(m_ownerRoleId.getText());
-		this.m_calendarId.setOwnerRoleId(m_ownerRoleId);
-		this.notifyInfo.setOwnerRoleId(m_ownerRoleId);
-		
+		this.m_calendarId.createCalIdCombo(this.m_managerComposite.getText(), m_ownerRoleId.getText());
+		this.notifyInfo.setOwnerRoleId(m_ownerRoleId.getText(), true);
+
 
 		if(info != null){
 			if (info.getMaintenanceId() != null) {
@@ -1067,15 +1131,14 @@ public class MaintenanceDialog extends CommonDialog {
 			}
 
 			if (info.getCalendarId() != null) {
-				if (!m_calendarId.getEnabled()) {
-					// カレンダー参照権限が無い場合
-					m_calendarId.addText(info.getCalendarId());
-				}
 				this.m_calendarId.setText(info.getCalendarId());
 			}
 
 			if (info.getTypeId() != null) {
-				this.m_maintenance_type.setText(m_maintenance_type.getMaintenanceTypeName(info.getTypeId()));
+				this.m_maintenance_type.setText(m_maintenance_type
+						.getMaintenanceTypeName(
+								this.m_managerComposite.getText(),
+								info.getTypeId()));
 			}
 
 			//通知情報の設定
@@ -1100,7 +1163,7 @@ public class MaintenanceDialog extends CommonDialog {
 
 	/**
 	 * ＯＫボタンテキスト取得
-	 * 
+	 *
 	 * @return ＯＫボタンのテキスト
 	 */
 	@Override
@@ -1110,7 +1173,7 @@ public class MaintenanceDialog extends CommonDialog {
 
 	/**
 	 * キャンセルボタンテキスト取得
-	 * 
+	 *
 	 * @return キャンセルボタンのテキスト
 	 */
 	@Override
@@ -1121,9 +1184,9 @@ public class MaintenanceDialog extends CommonDialog {
 	/**
 	 * 入力値を保持したプロパティを返します。<BR>
 	 * プロパティオブジェクトのコピーを返します。
-	 * 
+	 *
 	 * @return プロパティ
-	 * 
+	 *
 	 * @see com.clustercontrol.util.PropertyUtil#copy(Property)
 	 */
 	@Override
@@ -1140,9 +1203,9 @@ public class MaintenanceDialog extends CommonDialog {
 
 	/**
 	 * 入力値をマネージャに登録します。
-	 * 
+	 *
 	 * @return true：正常、false：異常
-	 * 
+	 *
 	 * @see com.clustercontrol.dialog.CommonDialog#action()
 	 */
 	@Override
@@ -1152,9 +1215,12 @@ public class MaintenanceDialog extends CommonDialog {
 		if(this.maintenanceInfo != null){
 			if(this.mode == PropertyDefineConstant.MODE_ADD){
 				// 作成の場合
-				String[] args = { maintenanceInfo.getMaintenanceId() };
+				String managerName = this.m_managerComposite.getText();
+				String[] args = { maintenanceInfo.getMaintenanceId(), managerName };
 				try {
-					MaintenanceEndpointWrapper.addMaintenance(maintenanceInfo);
+					MaintenanceEndpointWrapper wrapper = MaintenanceEndpointWrapper
+							.getWrapper(managerName);
+					wrapper.addMaintenance(maintenanceInfo);
 
 					MessageDialog.openInformation(
 							null,
@@ -1185,10 +1251,10 @@ public class MaintenanceDialog extends CommonDialog {
 
 			} else if (this.mode == PropertyDefineConstant.MODE_MODIFY) {
 				// 変更の場合
-				result = new ModifyMaintenance().modify(maintenanceInfo);
+				result = new ModifyMaintenance().modify(this.m_managerComposite.getText(), maintenanceInfo);
 			}
 		}
 
 		return result;
 	}
-}
\ No newline at end of file
+}
