@@ -28,24 +28,20 @@ import javax.xml.bind.annotation.XmlType;
 public class StatusFilterInfo implements Serializable {
 
 	private static final long serialVersionUID = 526029970791845324L;
-	private Integer priority = null;		//重要度
 	private Long outputDateFrom = null;		//更新日時（自）
 	private Long outputDateTo = null;		//更新日時（至）
 	private Long generationDateFrom = null;	//出力日時（自）
 	private Long generationDateTo = null;	//出力日時（至）
+	private String monitorId = null;		//監視項目ID
+	private String monitorDetailId = null;	//監視詳細
 	private String facilityType = null;		//対象ファシリティ種別
 	private String application = null;		//アプリケーション
 	private String message = null;			//メッセージ
 	private Long outputDate = null;			//更新日時
 	private Long generationDate = null;		//出力日時
 	private String ownerRoleId = null;		//オーナーロールID
-
-	public void setPriority(Integer priority) {
-		this.priority = priority;
-	}
-	public Integer getPriority() {
-		return priority;
-	}
+	private Integer[] priorityList = null;	//重要度リスト 
+	
 	public void setOutputDateFrom(Long outputDateFrom) {
 		this.outputDateFrom = outputDateFrom;
 	}
@@ -70,6 +66,18 @@ public class StatusFilterInfo implements Serializable {
 	public Long getGenerationDateTo() {
 		return generationDateTo;
 	}
+	public String getMonitorId() {
+		return monitorId;
+	}
+	public void setMonitorId(String monitorId) {
+		this.monitorId = monitorId;
+	}
+	public String getMonitorDetailId() {
+		return monitorDetailId;
+	}
+	public void setMonitorDetailId(String monitorDetailId) {
+		this.monitorDetailId = monitorDetailId;
+	}
 	public void setFacilityType(String facilityType) {
 		this.facilityType = facilityType;
 	}
@@ -106,5 +114,11 @@ public class StatusFilterInfo implements Serializable {
 	public void setOwnerRoleId(String ownerRoleId) {
 		this.ownerRoleId = ownerRoleId;
 	}
+	public Integer[] getPriorityList() {
+		return priorityList;
+	}
+	public void setPriorityList(Integer[] priorityList) {
+		this.priorityList = priorityList;
+	}
 
 }
