@@ -36,7 +36,7 @@ public class MonitorTypeListComposite extends Composite {
 
 	//	 ----- instance フィールド ----- //
 	/** 選択アイテム */
-	private ArrayList selectItem = null;
+	private ArrayList<?> selectItem = null;
 
 	/** リストビューア */
 	private ListViewer monitorTypeList = null;
@@ -73,7 +73,7 @@ public class MonitorTypeListComposite extends Composite {
 			@Override
 			public void selectionChanged(SelectionChangedEvent event) {
 				StructuredSelection selection = (StructuredSelection) event.getSelection();
-				selectItem = (ArrayList)selection.getFirstElement();
+				selectItem = (ArrayList<?>)selection.getFirstElement();
 			}
 		});
 	}
@@ -83,7 +83,7 @@ public class MonitorTypeListComposite extends Composite {
 	 * 
 	 * @return ツリーアイテム
 	 */
-	public ArrayList getSelectItem() {
+	public ArrayList<?> getSelectItem() {
 		return this.selectItem;
 	}
 	/**
