@@ -29,11 +29,12 @@ import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Table;
 
-import com.clustercontrol.accesscontrol.util.LocalSession;
+import com.clustercontrol.accesscontrol.util.ClientSession;
 import com.clustercontrol.bean.PriorityConstant;
 import com.clustercontrol.monitor.action.GetScopeListTableDefine;
 import com.clustercontrol.monitor.util.ConvertListUtil;
 import com.clustercontrol.monitor.util.MonitorEndpointWrapper;
+import com.clustercontrol.monitor.util.ScopeSearchRunUtil;
 import com.clustercontrol.monitor.view.action.ScopeSpecifiedShowAction;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.viewer.CommonTableViewer;
@@ -43,12 +44,13 @@ import com.clustercontrol.ws.monitor.InvalidRole_Exception;
 import com.clustercontrol.ws.monitor.MonitorNotFound_Exception;
 import com.clustercontrol.ws.monitor.ScopeDataInfo;
 import com.sun.xml.internal.ws.client.ClientTransportException;
+import com.clustercontrol.util.WidgetTestUtil;
 
 /**
  * スコープ情報一覧のコンポジットクラス<BR>
- * 
+ *
  * スコープ情報一覧部分のテーブルのコンポジット
- * 
+ *
  * @version 1.0.0
  * @since 1.0.0
  */
@@ -77,10 +79,10 @@ public class ScopeListComposite extends Composite {
 
 	/**
 	 * インスタンスを返します。
-	 * 
+	 *
 	 * @param parent 親のコンポジット
 	 * @param style スタイル
-	 * 
+	 *
 	 * @see org.eclipse.swt.SWT
 	 * @see org.eclipse.swt.widgets.Composite#Composite(Composite parent, int style)
 	 * @see #initialize()
@@ -101,6 +103,7 @@ public class ScopeListComposite extends Composite {
 
 		Table table = new Table(this, SWT.H_SCROLL | SWT.V_SCROLL
 				| SWT.FULL_SELECTION | SWT.SINGLE);
+		WidgetTestUtil.setTestId(this, null, table);
 		table.setHeaderVisible(true);
 		table.setLinesVisible(true);
 
@@ -116,6 +119,7 @@ public class ScopeListComposite extends Composite {
 
 		// 危険
 		this.criticalLabel = new Label(this, SWT.CENTER);
+		WidgetTestUtil.setTestId(this, "criticallabel", criticalLabel);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.verticalAlignment = GridData.FILL;
@@ -125,6 +129,7 @@ public class ScopeListComposite extends Composite {
 
 		// 警告
 		this.warningLabel = new Label(this, SWT.CENTER);
+		WidgetTestUtil.setTestId(this, "warninglabel", warningLabel);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.verticalAlignment = GridData.FILL;
@@ -134,6 +139,7 @@ public class ScopeListComposite extends Composite {
 
 		// 通知
 		this.infoLabel = new Label(this, SWT.CENTER);
+		WidgetTestUtil.setTestId(this, "infolabel", infoLabel);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.verticalAlignment = GridData.FILL;
@@ -143,6 +149,7 @@ public class ScopeListComposite extends Composite {
 
 		// 不明
 		this.unknownLabel = new Label(this, SWT.CENTER);
+		WidgetTestUtil.setTestId(this, "unknownlabel", unknownLabel);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.verticalAlignment = GridData.FILL;
@@ -151,6 +158,7 @@ public class ScopeListComposite extends Composite {
 
 		// 合計
 		this.totalLabel = new Label(this, SWT.CENTER);
+		WidgetTestUtil.setTestId(this, "totallabel", totalLabel);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.verticalAlignment = GridData.FILL;
@@ -161,8 +169,8 @@ public class ScopeListComposite extends Composite {
 		this.tableViewer.createTableColumn(
 				//        				GetScopeListTableDefine.get(),
 				GetScopeListTableDefine.getScopeListTableDefine(),
-				GetScopeListTableDefine.SORT_COLUMN_INDEX,
-				GetScopeListTableDefine.SORT_COLUMN_INDEX_SECOND ,
+				GetScopeListTableDefine.SORT_COLUMN_INDEX1,
+				GetScopeListTableDefine.SORT_COLUMN_INDEX2,
 				GetScopeListTableDefine.SORT_ORDER);
 		for (int i = 0; i < table.getColumnCount(); i++){
 			table.getColumn(i).setMoveable(true);
@@ -174,13 +182,70 @@ public class ScopeListComposite extends Composite {
 
 	/**
 	 * このコンポジットが利用する共通テーブルビューアーを返します。
-	 * 
+	 *
 	 * @return 共通テーブルビューアー
 	 */
 	public CommonTableViewer getTableViewer() {
 		return this.tableViewer;
 	}
 
+	public void update(String managerName, String facilityId) {
+		super.update();
+
+		ArrayList<?> infoList = null;
+		try {
+			m_log.debug("managerName=" + managerName + ", faciiltyID=" + facilityId);
+			List<ScopeDataInfo> records = null;
+			MonitorEndpointWrapper wrapper = MonitorEndpointWrapper.getWrapper(managerName);
+			records = wrapper.getScopeList(facilityId, true, true, false);
+			infoList = ConvertListUtil.scopeInfoDataListToArrayList(managerName, records);
+		} catch (InvalidRole_Exception e) {
+			if(ClientSession.isDialogFree()){
+				ClientSession.occupyDialog();
+				// アクセス権なしの場合、エラーダイアログを表示する
+				MessageDialog.openInformation(null, Messages.getString("message"),
+						Messages.getString("message.accesscontrol.16"));
+				ClientSession.freeDialog();
+			}
+		} catch (MonitorNotFound_Exception e) {
+			MessageDialog.openError(null, Messages.getString("message"),
+					Messages.getString("message.monitor.64") + ", " + e.getMessage());
+		} catch (FacilityNotFound_Exception e) {
+			MessageDialog.openError(null, Messages.getString("message"),
+					Messages.getString("message.monitor.64") + ", " + e.getMessage());
+		} catch (HinemosUnknown_Exception e) {
+			MessageDialog.openError(null, Messages.getString("message"),
+					Messages.getString("message.monitor.64") + ", " + e.getMessage());
+		} catch (Exception e) {
+			if (ClientSession.isDialogFree()) {
+				ClientSession.occupyDialog();
+				if (e instanceof ClientTransportException) {
+					m_log.info("update() getEventList, " + e.getMessage());
+					MessageDialog.openError(
+							null,
+							Messages.getString("failed"),
+							Messages.getString("message.hinemos.failure.transfer") + ", " + e.getMessage());
+				} else {
+					m_log.warn("update() getScopeList, " + e.getMessage(), e);
+					MessageDialog.openError(
+							null,
+							Messages.getString("failed"),
+							Messages.getString("message.hinemos.failure.unexpected") + ", " + e.getMessage());
+				}
+				ClientSession.freeDialog();
+			}
+		}
+
+		if (infoList == null) {
+			infoList = new ArrayList<Object>();
+		}
+
+		//危険・警告・通知・不明の件数カウント
+		this.updateStatus(infoList);
+
+		tableViewer.setInput(infoList);
+	}
+
 	/**
 	 * ビューを更新します。<BR>
 	 * 引数で指定されたファシリティの配下全てのファシリティのスコープ情報一覧を取得し、
@@ -190,64 +255,43 @@ public class ScopeListComposite extends Composite {
 	 * <li>引数で指定されたファシリティに属するスコープ情報一覧を取得します。</li>
 	 * <li>共通テーブルビューアーにスコープ情報一覧をセットします。</li>
 	 * </ol>
-	 * 
+	 *
 	 * @param facilityId 表示対象の親ファシリティID
-	 * 
+	 *
 	 * @see #updateStatus(ArrayList)
 	 */
-	public void update(String facilityId) {
+	public void update(List<String> managerList) {
 		super.update();
 
-		ArrayList infoList = null;
-		if(facilityId != null){
-			try {
-				List<ScopeDataInfo> records = null;
-				m_log.debug("faciiltyID=" + facilityId);
-				records = MonitorEndpointWrapper.getScopeList(facilityId, true, true, false);
-				infoList = ConvertListUtil.scopeInfoDataListToArrayList(records);
-			} catch (InvalidRole_Exception e) {
-				if(LocalSession.isDialogFlag()){
-					LocalSession.setDialogFlag(false);
-					// アクセス権なしの場合、エラーダイアログを表示する
-					MessageDialog.openInformation(null, Messages.getString("message"),
-							Messages.getString("message.accesscontrol.16"));
-					LocalSession.setDialogFlag(true);
-				}
-			} catch (MonitorNotFound_Exception e) {
-				MessageDialog.openError(null, Messages.getString("message"),
-						Messages.getString("message.monitor.64") + ", " + e.getMessage());
-			} catch (FacilityNotFound_Exception e) {
-				MessageDialog.openError(null, Messages.getString("message"),
-						Messages.getString("message.monitor.64") + ", " + e.getMessage());
-			} catch (HinemosUnknown_Exception e) {
-				MessageDialog.openError(null, Messages.getString("message"),
-						Messages.getString("message.monitor.64") + ", " + e.getMessage());
-			} catch (Exception e) {
-				if (LocalSession.isDialogFlag()) {
-					LocalSession.setDialogFlag(false);
-					if (e instanceof ClientTransportException) {
-						m_log.info("update() getEventList, " + e.getMessage());
-						MessageDialog.openError(
-								null,
-								Messages.getString("failed"),
-								Messages.getString("message.hinemos.failure.transfer") + ", " + e.getMessage());
-					} else {
-						m_log.warn("update() getScopeList, " + e.getMessage(), e);
-						MessageDialog.openError(
-								null,
-								Messages.getString("failed"),
-								Messages.getString("message.hinemos.failure.unexpected") + ", " + e.getMessage());
-					}
-					LocalSession.setDialogFlag(true);
+		ArrayList<?> infoList = null;
+		try {
+			m_log.debug("Scope selected");
+			ScopeSearchRunUtil util = new ScopeSearchRunUtil();
+			infoList = util.searchInfo(managerList);
+		} catch (Exception e) {
+			if (ClientSession.isDialogFree()) {
+				ClientSession.occupyDialog();
+				if (e instanceof ClientTransportException) {
+					m_log.info("update() getEventList, " + e.getMessage());
+					MessageDialog.openError(
+							null,
+							Messages.getString("failed"),
+							Messages.getString("message.hinemos.failure.transfer") + ", " + e.getMessage());
+				} else {
+					m_log.warn("update() getScopeList, " + e.getMessage(), e);
+					MessageDialog.openError(
+							null,
+							Messages.getString("failed"),
+							Messages.getString("message.hinemos.failure.unexpected") + ", " + e.getMessage());
 				}
+				ClientSession.freeDialog();
 			}
 		}
 
 		if (infoList == null) {
-			infoList = new ArrayList();
+			infoList = new ArrayList<Object>();
 		}
 
-
 		//危険・警告・通知・不明の件数カウント
 		this.updateStatus(infoList);
 
@@ -258,18 +302,18 @@ public class ScopeListComposite extends Composite {
 	 * ステータスラベルを更新します。<BR>
 	 * 引数で指定されたスコープ情報一覧より、重要度ごとの件数，全件数を取得し、
 	 * ステータスラベルを更新します。
-	 * 
+	 *
 	 * @param list スコープ情報一覧
 	 */
-	private void updateStatus(ArrayList list) {
+	private void updateStatus(ArrayList<?> list) {
 		int[] status = new int[4];
 
 		if (list != null) {
 			int count = list.size();
 
 			for (int i = 0; i < count; i++) {
-				ArrayList data = (ArrayList) list.get(i);
-				int value = ((Integer) data.get(0)).intValue();
+				ArrayList<?> data = (ArrayList<?>) list.get(i);
+				int value = ((Integer) data.get(GetScopeListTableDefine.PRIORITY)).intValue();
 
 				switch (value) {
 				case PriorityConstant.TYPE_CRITICAL:
@@ -298,4 +342,4 @@ public class ScopeListComposite extends Composite {
 		this.totalLabel.setText(Messages.getString("records", args));
 	}
 
-}
\ No newline at end of file
+}
