@@ -16,10 +16,13 @@ PURPOSE.  See the GNU General Public License for more details.
 package com.clustercontrol.monitor.dialog;
 
 import java.util.Locale;
+import java.util.Map;
+import java.util.concurrent.ConcurrentHashMap;
 
 import org.eclipse.jface.dialogs.IDialogConstants;
+import org.eclipse.rap.rwt.RWT;
+import org.eclipse.rap.rwt.service.UISession;
 import org.eclipse.swt.SWT;
-import org.eclipse.swt.custom.TableTree;
 import org.eclipse.swt.events.SelectionAdapter;
 import org.eclipse.swt.events.SelectionEvent;
 import org.eclipse.swt.graphics.Point;
@@ -29,6 +32,7 @@ import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Display;
 import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
+import org.eclipse.swt.widgets.Tree;
 
 import com.clustercontrol.bean.Property;
 import com.clustercontrol.dialog.CommonDialog;
@@ -37,10 +41,11 @@ import com.clustercontrol.monitor.util.MonitorFilterPropertyUtil;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.util.PropertyUtil;
 import com.clustercontrol.viewer.PropertySheet;
+import com.clustercontrol.util.WidgetTestUtil;
 
 /**
  * 監視[一覧]のフィルタ処理ダイアログクラス<BR>
- * 
+ *
  * @version 4.0.0
  * @since 4.0.0
  */
@@ -49,16 +54,13 @@ public class MonitorFilterDialog extends CommonDialog {
 	/** プロパティシート。 */
 	private PropertySheet propertySheet = null;
 
-	/**
-	 * プロパティ。
-	 * 前回ダイアログオープン時の情報を保持するために使用します。
-	 */
-	private static Property filterProperty = null;
-
 	// 後でpackするためsizeXはダミーの値。
 	private final int sizeX = 500;
 	private final int sizeY = 600;
 
+	/** Cache map of filter properties for each UI session */
+	private static Map<UISession, Property> filterPropertyCache = new ConcurrentHashMap<>();
+
 	/**
 	 * コンストラクタ
 	 * @param parent 親のシェルオブジェクト
@@ -69,7 +71,7 @@ public class MonitorFilterDialog extends CommonDialog {
 
 	/**
 	 * ダイアログの初期サイズを返します。
-	 * 
+	 *
 	 * @return 初期サイズ
 	 */
 	@Override
@@ -79,7 +81,7 @@ public class MonitorFilterDialog extends CommonDialog {
 
 	/**
 	 * ダイアログエリアを生成します。
-	 * 
+	 *
 	 * @param parent 親のコンポジット
 	 */
 	@Override
@@ -101,6 +103,7 @@ public class MonitorFilterDialog extends CommonDialog {
 
 		// ラベル
 		Label label = new Label(parent, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "attibute", label);
 		GridData gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
@@ -109,8 +112,9 @@ public class MonitorFilterDialog extends CommonDialog {
 		label.setText(Messages.getString("attribute") + " : ");
 
 		// プロパティシート
-		TableTree table = new TableTree(parent, SWT.H_SCROLL | SWT.V_SCROLL
+		Tree table = new Tree(parent, SWT.H_SCROLL | SWT.V_SCROLL
 				| SWT.FULL_SELECTION | SWT.MULTI | SWT.BORDER);
+		WidgetTestUtil.setTestId(this, null, table);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.verticalAlignment = GridData.FILL;
@@ -119,17 +123,11 @@ public class MonitorFilterDialog extends CommonDialog {
 		gridData.horizontalSpan = 1;
 		table.setLayoutData(gridData);
 
-		this.propertySheet = new PropertySheet(table);
-
-		// プロパティ設定
-		if(filterProperty == null){
-			filterProperty = MonitorFilterPropertyUtil.getProperty(Locale.getDefault());
-		}
-		this.propertySheet.setInput(filterProperty);
-		this.propertySheet.expandAll();
+		createPropertySheet(table);
 
 		// ラインを引く
 		Label line = new Label(parent, SWT.SEPARATOR | SWT.HORIZONTAL);
+		WidgetTestUtil.setTestId(this, "line", line);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
@@ -148,7 +146,7 @@ public class MonitorFilterDialog extends CommonDialog {
 
 	/**
 	 * 入力値チェックをします。
-	 * 
+	 *
 	 * @return 検証結果
 	 */
 	@Override
@@ -159,9 +157,9 @@ public class MonitorFilterDialog extends CommonDialog {
 	/**
 	 * 既存のボタンに加え、クリアボタンを追加します。<BR>
 	 * クリアボタンがクリックされた場合、 プロパティを再取得します。
-	 * 
+	 *
 	 * @param parent 親のコンポジット（ボタンバー）
-	 * 
+	 *
 	 */
 	@Override
 	protected void createButtonsForButtonBar(Composite parent) {
@@ -173,8 +171,7 @@ public class MonitorFilterDialog extends CommonDialog {
 					@Override
 					public void widgetSelected(SelectionEvent e) {
 						// プロパティ設定
-						filterProperty = MonitorFilterPropertyUtil.getProperty(Locale.getDefault());
-						propertySheet.setInput(filterProperty);
+						resetPropertySheet();
 					}
 				});
 
@@ -184,16 +181,55 @@ public class MonitorFilterDialog extends CommonDialog {
 	/**
 	 * 入力値を保持したプロパティを返します。<BR>
 	 * プロパティオブジェクトのコピーを返します。
-	 * 
+	 *
 	 * @return プロパティ
 	 */
 	public Property getInputData() {
-		if(filterProperty != null){
-			Property copy = PropertyUtil.copy(filterProperty);
-			return copy;
-		}
-		else{
+		Property property = getOrInitFilterProperty();
+		if( null != property ){
+			return PropertyUtil.copy( property );
+		}else{
 			return null;
 		}
 	}
+	/**
+	 * 検索条件用プロパティ設定
+	 * 前回ダイアログオープン時の情報を保持するために使用します。
+	 */
+	private void createPropertySheet( Tree table ){
+		propertySheet = new PropertySheet(table);
+		Property filterProperty = getOrInitFilterProperty();
+		propertySheet.setInput(filterProperty);
+		propertySheet.expandAll();
+	}
+
+	/**
+	 * Reset property sheet
+	 * The filter properties will be cleared
+	 */
+	private void resetPropertySheet(){
+		Property filterProperty = initFilterProperty();
+		propertySheet.setInput(filterProperty);
+	}
+
+	/**
+	 * Initialize a filter property
+	 */
+	private Property initFilterProperty() {
+		Property property = MonitorFilterPropertyUtil.getProperty(Locale.getDefault());
+		filterPropertyCache.put(RWT.getUISession(), property);
+		return property;
+	}
+
+	/**
+	 * Get the cached filter property if existed,
+	 * or initialize one while not.
+	 */
+	private Property getOrInitFilterProperty() {
+		Property property = filterPropertyCache.get(RWT.getUISession());
+		if( null == property ){
+			property = initFilterProperty();
+		}
+		return property;
+	}
 }
