@@ -17,8 +17,6 @@ package com.clustercontrol.monitor.dialog;
 
 import java.util.ArrayList;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
 import org.eclipse.jface.viewers.DoubleClickEvent;
 import org.eclipse.jface.viewers.IDoubleClickListener;
 import org.eclipse.jface.viewers.LabelProvider;
@@ -30,28 +28,26 @@ import org.eclipse.swt.layout.GridLayout;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Shell;
 
+import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.dialog.CommonDialog;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.monitor.bean.MonitorTypeMstConstant;
 import com.clustercontrol.monitor.composite.MonitorTypeListComposite;
+import com.clustercontrol.monitor.plugin.IMonitorPlugin;
+import com.clustercontrol.monitor.plugin.LoadMonitorPlugin;
 import com.clustercontrol.monitor.run.bean.MonitorTypeConstant;
 import com.clustercontrol.monitor.view.MonitorListView;
 import com.clustercontrol.monitor.view.action.MonitorModifyAction;
-import com.clustercontrol.plugin.monitor.IMonitorPlugin;
-import com.clustercontrol.plugin.monitor.LoadMonitorPlugin;
 import com.clustercontrol.util.Messages;
 /**
  * 監視種別一覧を表示するダイアログクラス<BR>
- * 
+ *
  * @version 4.0.0
  * @since 4.0.0
  */
 public class MonitorTypeDialog extends CommonDialog {
 
-	// ログ
-	private static Log m_log = LogFactory.getLog( MonitorTypeDialog.class );
-
 	// ----- instance フィールド ----- //
 	// 後でpackするためsizeXはダミーの値。
 	private final int sizeX = 300;
@@ -66,11 +62,14 @@ public class MonitorTypeDialog extends CommonDialog {
 	// 呼び出し元ビュー
 	private MonitorListView view = null;
 
+	/** マネージャ名 */
+	private String managerName = null;
+
 	// ----- コンストラクタ ----- //
 
 	/**
 	 * ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent
 	 *            親とするシェル
 	 */
@@ -102,6 +101,7 @@ public class MonitorTypeDialog extends CommonDialog {
 		layout.marginWidth = 0;
 
 		listComposite = new MonitorTypeListComposite(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, null, listComposite);
 		GridData gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.verticalAlignment = GridData.FILL;
@@ -116,13 +116,15 @@ public class MonitorTypeDialog extends CommonDialog {
 			@Override
 			public String getText(Object element) {
 				// 通知種別を数値から文字列に変更する
-				ArrayList<Object> list = (ArrayList<Object>)element;
+				ArrayList<?> list = (ArrayList<?>)element;
 				String pluginName = null;
 
 				String pluginId = (String)list.get(0);
 				if (pluginId.equals(HinemosModuleConstant.MONITOR_AGENT)) {
 					pluginName = Messages.getString("agent.monitor");
-				} else if (pluginId.equals(HinemosModuleConstant.MONITOR_HTTP)) {
+				} else if (pluginId.equals(HinemosModuleConstant.MONITOR_HTTP_N)
+						|| pluginId.equals(HinemosModuleConstant.MONITOR_HTTP_S)
+						|| pluginId.equals(HinemosModuleConstant.MONITOR_HTTP_SCENARIO)) {
 					pluginName = Messages.getString("http.monitor");
 				} else if (pluginId.equals(HinemosModuleConstant.MONITOR_PERFORMANCE)) {
 					pluginName = Messages.getString("performance.monitor");
@@ -132,9 +134,11 @@ public class MonitorTypeDialog extends CommonDialog {
 					pluginName = Messages.getString("port.monitor");
 				} else if (pluginId.equals(HinemosModuleConstant.MONITOR_PROCESS)) {
 					pluginName = Messages.getString("process.monitor");
-				} else if (pluginId.equals(HinemosModuleConstant.MONITOR_SNMP)) {
+				} else if (pluginId.equals(HinemosModuleConstant.MONITOR_SNMP_N)
+						|| pluginId.equals(HinemosModuleConstant.MONITOR_SNMP_S)) {
 					pluginName = Messages.getString("snmp.monitor");
-				} else if (pluginId.equals(HinemosModuleConstant.MONITOR_SQL)) {
+				} else if (pluginId.equals(HinemosModuleConstant.MONITOR_SQL_N)
+						|| pluginId.equals(HinemosModuleConstant.MONITOR_SQL_S)) {
 					pluginName = Messages.getString("sql.monitor");
 				} else if (pluginId.equals(HinemosModuleConstant.MONITOR_SYSTEMLOG)) {
 					pluginName = Messages.getString("systemlog.monitor");
@@ -148,6 +152,8 @@ public class MonitorTypeDialog extends CommonDialog {
 					pluginName = Messages.getString("winservice.monitor");
 				} else if (pluginId.equals(HinemosModuleConstant.MONITOR_WINEVENT)) {
 					pluginName = Messages.getString("winevent.monitor");
+				} else if (pluginId.equals(HinemosModuleConstant.MONITOR_JMX)) {
+					pluginName = Messages.getString("jmx.monitor");
 				} else {
 					for(IMonitorPlugin extensionMonitor: LoadMonitorPlugin.getExtensionMonitorList()){
 						if(pluginId.equals(extensionMonitor.getMonitorPluginId())){
@@ -186,7 +192,7 @@ public class MonitorTypeDialog extends CommonDialog {
 	 * 選択されたアイテム(監視種別マスタの定義)の取得
 	 * @return
 	 */
-	public ArrayList getSelectItem() {
+	public ArrayList<?> getSelectItem() {
 		return this.listComposite.getSelectItem();
 	}
 
@@ -212,6 +218,7 @@ public class MonitorTypeDialog extends CommonDialog {
 			result.setID(Messages.getString("message.hinemos.1"));
 			result.setMessage(Messages.getString("message.monitor.57"));
 			displayError(result);
+			return;
 		}
 
 		// DBに登録されているダイアログのクラス名を取得する
@@ -219,7 +226,7 @@ public class MonitorTypeDialog extends CommonDialog {
 		Integer monitorType = (Integer)((this.getSelectItem())).get(1);
 		// ダイアログの生成
 		MonitorModifyAction action = new MonitorModifyAction();
-		action.dialogOpen(getParentShell(), pluginId, null, monitorType);
+		action.dialogOpen(getParentShell(), this.managerName, pluginId, null, monitorType);
 
 		// 監視設定後に、監視種別一覧は閉じない。
 		// super.okPressed();
