@@ -35,6 +35,7 @@ import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.ws.monitor.MonitorInfo;
 import com.clustercontrol.ws.monitor.MonitorNumericValueInfo;
+import com.clustercontrol.util.WidgetTestUtil;
 
 /**
  * 数値監視の判定情報（重要度）コンポジットクラス<BR>
@@ -49,7 +50,7 @@ import com.clustercontrol.ws.monitor.MonitorNumericValueInfo;
  *  <dd>値取得の失敗時</dd>
  *  <dd>　「重要度」 コンボボックス</dd>
  * </dl>
- * 
+ *
  * @version 4.0.0
  * @since 2.0.0
  */
@@ -70,13 +71,6 @@ public class NumericValueInfoComposite extends Composite {
 	/** 入力値の検証タイプ（正の実数）。 */
 	public static final int INPUT_VERIFICATION_POSITIVE_REAL = 3;
 
-	/**
-	 * 入力値の範囲検証フラグ。<BR>
-	 * 判定項目１と２の入力値に対して範囲の検証を行う場合、<code> true </code>。
-	 * <code> true </code>の場合、判定項目１の入力値 ＞ 判定項目２の入力値の場合、エラーダイアログが表示されます。
-	 */
-	private boolean m_rangeFlg = false;
-
 	/** 項目名（判定項目１）。 */
 	private String m_itemName1 = null;
 
@@ -101,18 +95,6 @@ public class NumericValueInfoComposite extends Composite {
 	/** 入力値の検証タイプ（判定項目２）。 */
 	private int m_inputVerifyType2 = INPUT_VERIFICATION_INTEGER_NUMBER;
 
-	/** 入力値（判定項目１：通知）。 */
-	private Double m_value1Info = null;
-
-	/** 入力値（判定項目２：通知）。 */
-	private Double m_value2Info = null;
-
-	/** 入力値（判定項目１：警告）。 */
-	private Double m_value1Warn = null;
-
-	/** 入力値（判定項目２：警告）。 */
-	private Double m_value2Warn = null;
-
 	/** 判定値（判定項目１：通知） テキストボックス。 */
 	private Text m_textValue1Info = null;
 
@@ -130,13 +112,13 @@ public class NumericValueInfoComposite extends Composite {
 	 * <p>
 	 * 初期処理を呼び出し、コンポジットを配置します。
 	 * 判定基準文字列，入力値の検証タイプ 及び 入力値の初期値はデフォルト値が使用されます。
-	 * 
+	 *
 	 * @param parent 親のコンポジット
 	 * @param style スタイル
 	 * @param rangeFlg 範囲検証フラグ
 	 * @param item1 項目名（判定項目１）
 	 * @param item2 項目名（判定項目２）
-	 * 
+	 *
 	 * @see org.eclipse.swt.SWT
 	 * @see org.eclipse.swt.widgets.Composite#Composite(Composite parent, int style)
 	 * @see #initialize()
@@ -144,7 +126,6 @@ public class NumericValueInfoComposite extends Composite {
 	public NumericValueInfoComposite(Composite parent, int style, boolean rangeFlg, String item1, String item2) {
 		super(parent, style);
 
-		m_rangeFlg = rangeFlg;
 		m_itemName1 = item1;
 		m_itemName2 = item2;
 
@@ -157,14 +138,14 @@ public class NumericValueInfoComposite extends Composite {
 	 * 初期処理を呼び出し、コンポジットを配置します。<BR>
 	 * 引数で指定された入力値の検証タイプで、全ての入力値テキストボックスの入力検証を行います。
 	 * 判定基準文字列 及び 入力値の初期値はデフォルト値が使用されます。
-	 * 
+	 *
 	 * @param parent 親のコンポジット
 	 * @param style スタイル
 	 * @param rangeFlg 範囲検証フラグ
 	 * @param item1 項目名（判定項目１）
 	 * @param item2 項目名（判定項目２）
 	 * @param inputVerifyType 入力値の検証タイプ（判定項目１,２）
-	 * 
+	 *
 	 * @see org.eclipse.swt.SWT
 	 * @see #INPUT_VERIFICATION_INTEGER_NUMBER
 	 * @see #INPUT_VERIFICATION_POSITIVE_INTEGER
@@ -182,7 +163,6 @@ public class NumericValueInfoComposite extends Composite {
 
 		super(parent, style);
 
-		m_rangeFlg = rangeFlg;
 		m_itemName1 = item1;
 		m_itemName2 = item2;
 		m_inputVerifyType1 = inputVerifyType;
@@ -197,7 +177,7 @@ public class NumericValueInfoComposite extends Composite {
 	 * 初期処理を呼び出し、コンポジットを配置します。<BR>
 	 * 各判定項目ごとに引数で指定された入力検証タイプで、各入力値テキストボックスの入力検証を行います。
 	 * 判定基準文字列 及び 入力値の初期値はデフォルト値が使用されます。
-	 * 
+	 *
 	 * @param parent 親のコンポジット
 	 * @param style スタイル
 	 * @param rangeFlg 範囲検証フラグ
@@ -205,7 +185,7 @@ public class NumericValueInfoComposite extends Composite {
 	 * @param item2 項目名（判定項目２）
 	 * @param inputVerifyType1 入力値の検証タイプ（判定項目１）
 	 * @param inputVerifyType2 入力値の検証タイプ（判定項目２）
-	 * 
+	 *
 	 * @see org.eclipse.swt.SWT
 	 * @see #INPUT_VERIFICATION_INTEGER_NUMBER
 	 * @see #INPUT_VERIFICATION_POSITIVE_INTEGER
@@ -224,7 +204,6 @@ public class NumericValueInfoComposite extends Composite {
 
 		super(parent, style);
 
-		m_rangeFlg = rangeFlg;
 		m_itemName1 = item1;
 		m_itemName2 = item2;
 		m_inputVerifyType1 = inputVerifyType1;
@@ -239,7 +218,7 @@ public class NumericValueInfoComposite extends Composite {
 	 * 初期処理を呼び出し、コンポジットを配置します。<BR>
 	 * 引数で指定された入力値の検証タイプで、全ての入力値テキストボックスの入力検証を行います。
 	 * 判定基準文字列 及び 入力値の初期値はデフォルト値が使用されます。
-	 * 
+	 *
 	 * @param parent 親のコンポジット
 	 * @param style スタイル
 	 * @param rangeFlg 範囲検証フラグ
@@ -248,7 +227,7 @@ public class NumericValueInfoComposite extends Composite {
 	 * @param criterion1 判定基準文字列（判定項目１）
 	 * @param criterion2 判定基準文字列（判定項目２）
 	 * @param inputVerifyType 入力値の検証タイプ（判定項目１,２）
-	 * 
+	 *
 	 * @see org.eclipse.swt.SWT
 	 * @see #INPUT_VERIFICATION_INTEGER_NUMBER
 	 * @see #INPUT_VERIFICATION_POSITIVE_INTEGER
@@ -268,7 +247,6 @@ public class NumericValueInfoComposite extends Composite {
 
 		super(parent, style);
 
-		m_rangeFlg = rangeFlg;
 		m_itemName1 = item1;
 		m_itemName2 = item2;
 		m_criterion1 = criterion1;
@@ -285,7 +263,7 @@ public class NumericValueInfoComposite extends Composite {
 	 * 初期処理を呼び出し、コンポジットを配置します。<BR>
 	 * 各判定項目ごとに引数で指定された入力検証タイプで、各入力値テキストボックスの入力検証を行います。
 	 * 入力値の初期値は、デフォルト値が使用されます。
-	 * 
+	 *
 	 * @param parent 親のコンポジット
 	 * @param style スタイル
 	 * @param rangeFlg 範囲検証フラグ
@@ -295,7 +273,7 @@ public class NumericValueInfoComposite extends Composite {
 	 * @param criterion2 判定基準文字列（判定項目２）
 	 * @param inputVerifyType1 入力値の検証タイプ（判定項目１）
 	 * @param inputVerifyType2 入力値の検証タイプ（判定項目２）
-	 * 
+	 *
 	 * @see org.eclipse.swt.SWT
 	 * @see #INPUT_VERIFICATION_INTEGER_NUMBER
 	 * @see #INPUT_VERIFICATION_POSITIVE_INTEGER
@@ -316,7 +294,6 @@ public class NumericValueInfoComposite extends Composite {
 
 		super(parent, style);
 
-		m_rangeFlg = rangeFlg;
 		m_itemName1 = item1;
 		m_itemName2 = item2;
 		m_criterion1 = criterion1;
@@ -333,7 +310,7 @@ public class NumericValueInfoComposite extends Composite {
 	 * 初期処理を呼び出し、コンポジットを配置します。<BR>
 	 * 引数で指定された入力値の検証タイプで、全ての入力値テキストボックスの入力検証を行います。
 	 * 判定基準文字列は、デフォルト値が使用されます。
-	 * 
+	 *
 	 * @param parent 親のコンポジット
 	 * @param style スタイル
 	 * @param rangeFlg 範囲検証フラグ
@@ -342,7 +319,7 @@ public class NumericValueInfoComposite extends Composite {
 	 * @param inputVerifyType 入力値の検証タイプ（判定項目１,２）
 	 * @param inputValue1 入力値の初期値（判定項目１）
 	 * @param inputValue2 入力値の初期値（判定項目２）
-	 * 
+	 *
 	 * @see org.eclipse.swt.SWT
 	 * @see #INPUT_VERIFICATION_INTEGER_NUMBER
 	 * @see #INPUT_VERIFICATION_POSITIVE_INTEGER
@@ -362,15 +339,10 @@ public class NumericValueInfoComposite extends Composite {
 
 		super(parent, style);
 
-		m_rangeFlg = rangeFlg;
 		m_itemName1 = item1;
 		m_itemName2 = item2;
 		m_inputVerifyType1 = inputVerifyType;
 		m_inputVerifyType2 = inputVerifyType;
-		m_value1Info = inputValue1;
-		m_value1Warn = inputValue1;
-		m_value2Info = inputValue2;
-		m_value2Warn = inputValue2;
 
 		this.initialize();
 	}
@@ -381,7 +353,7 @@ public class NumericValueInfoComposite extends Composite {
 	 * 初期処理を呼び出し、コンポジットを配置します。<BR>
 	 * 各判定項目ごとに引数で指定された入力検証タイプで、各入力値テキストボックスの入力検証を行います。
 	 * 判定基準文字列は、デフォルト値が使用されます。
-	 * 
+	 *
 	 * @param parent 親のコンポジット
 	 * @param style スタイル
 	 * @param rangeFlg 範囲検証フラグ
@@ -393,7 +365,7 @@ public class NumericValueInfoComposite extends Composite {
 	 * @param inputValue2Info 入力値の初期値（判定項目２：通知）
 	 * @param inputValue1Warn 入力値の初期値（判定項目１：警告）
 	 * @param inputValue2Warn 入力値の初期値（判定項目２：警告）
-	 * 
+	 *
 	 * @see org.eclipse.swt.SWT
 	 * @see #INPUT_VERIFICATION_INTEGER_NUMBER
 	 * @see #INPUT_VERIFICATION_POSITIVE_INTEGER
@@ -416,15 +388,10 @@ public class NumericValueInfoComposite extends Composite {
 
 		super(parent, style);
 
-		m_rangeFlg = rangeFlg;
 		m_itemName1 = item1;
 		m_itemName2 = item2;
 		m_inputVerifyType1 = inputVerifyType1;
 		m_inputVerifyType2 = inputVerifyType2;
-		m_value1Info = inputValue1Info;
-		m_value1Warn = inputValue1Warn;
-		m_value2Info = inputValue2Info;
-		m_value2Warn = inputValue2Warn;
 
 		this.initialize();
 	}
@@ -434,7 +401,7 @@ public class NumericValueInfoComposite extends Composite {
 	 * <p>
 	 * 初期処理を呼び出し、コンポジットを配置します。<BR>
 	 * 各判定項目ごとに引数で指定された入力検証タイプで、各入力値テキストボックスの入力検証を行います。
-	 * 
+	 *
 	 * @param parent 親のコンポジット
 	 * @param style スタイル
 	 * @param rangeFlg 範囲検証フラグ
@@ -448,7 +415,7 @@ public class NumericValueInfoComposite extends Composite {
 	 * @param inputValue2Info 入力値の初期値（判定項目２：通知）
 	 * @param inputValue1Warn 入力値の初期値（判定項目１：警告）
 	 * @param inputValue2Warn 入力値の初期値（判定項目２：警告）
-	 * 
+	 *
 	 * @see org.eclipse.swt.SWT
 	 * @see #INPUT_VERIFICATION_INTEGER_NUMBER
 	 * @see #INPUT_VERIFICATION_POSITIVE_INTEGER
@@ -473,17 +440,12 @@ public class NumericValueInfoComposite extends Composite {
 
 		super(parent, style);
 
-		m_rangeFlg = rangeFlg;
 		m_itemName1 = item1;
 		m_itemName2 = item2;
 		m_criterion1 = criterion1;
 		m_criterion2 = criterion2;
 		m_inputVerifyType1 = inputVerifyType1;
 		m_inputVerifyType2 = inputVerifyType2;
-		m_value1Info = inputValue1Info;
-		m_value1Warn = inputValue1Warn;
-		m_value2Info = inputValue2Info;
-		m_value2Warn = inputValue2Warn;
 
 		this.initialize();
 	}
@@ -506,6 +468,7 @@ public class NumericValueInfoComposite extends Composite {
 
 		// 空白
 		label = new Label(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space1", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_TITLE;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -514,6 +477,7 @@ public class NumericValueInfoComposite extends Composite {
 
 		// 閾値の下限
 		m_textItemName1 = new Label(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "itemname1", m_textItemName1);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_VALUE*2;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -523,6 +487,7 @@ public class NumericValueInfoComposite extends Composite {
 
 		// 閾値の上限
 		m_textItemName2 = new Label(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "", m_textItemName2);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_VALUE*2;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -532,6 +497,7 @@ public class NumericValueInfoComposite extends Composite {
 
 		// 空白
 		label = new Label(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space2", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = 3;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -543,6 +509,7 @@ public class NumericValueInfoComposite extends Composite {
 
 		// 空白
 		label = new Label(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space3", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = 2;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -551,6 +518,7 @@ public class NumericValueInfoComposite extends Composite {
 
 		// 閾値の下限
 		this.m_textValue1Info = new Text(this, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, "textvalue1", m_textValue1Info);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_VALUE;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -566,6 +534,7 @@ public class NumericValueInfoComposite extends Composite {
 
 		// 以上
 		label = new Label(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "morethan", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_VALUE;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -575,6 +544,7 @@ public class NumericValueInfoComposite extends Composite {
 
 		// 閾値の上限
 		this.m_textValue2Info = new Text(this, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, "textvalue2", m_textValue2Info);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_VALUE;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -590,6 +560,7 @@ public class NumericValueInfoComposite extends Composite {
 
 		// 以下
 		label = new Label(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "lessthan", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_VALUE;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -599,6 +570,7 @@ public class NumericValueInfoComposite extends Composite {
 
 		// 空白
 		label = new Label(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space4", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = 3;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -610,6 +582,7 @@ public class NumericValueInfoComposite extends Composite {
 
 		// 空白
 		label = new Label(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space5", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = 2;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -618,6 +591,7 @@ public class NumericValueInfoComposite extends Composite {
 
 		// 閾値の下限
 		this.m_textValue1Warn = new Text(this, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, "valu1warn", m_textValue1Warn);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_VALUE;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -633,6 +607,7 @@ public class NumericValueInfoComposite extends Composite {
 
 		// 以上
 		label = new Label(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "morethan2", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_VALUE;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -642,6 +617,7 @@ public class NumericValueInfoComposite extends Composite {
 
 		// 閾値の上限
 		this.m_textValue2Warn = new Text(this, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, "valu2warn", m_textValue2Warn);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_VALUE;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -657,6 +633,7 @@ public class NumericValueInfoComposite extends Composite {
 
 		// 以下
 		label = new Label(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "lessthan2", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_VALUE;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -666,6 +643,7 @@ public class NumericValueInfoComposite extends Composite {
 
 		// 空白
 		label = new Label(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space6", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = 3;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -677,6 +655,7 @@ public class NumericValueInfoComposite extends Composite {
 
 		// 空白
 		label = new Label(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space7", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = 2;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -685,6 +664,7 @@ public class NumericValueInfoComposite extends Composite {
 
 		// （通知・警告以外）
 		label = new Label(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "otherpriority", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_VALUE*3;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -694,6 +674,7 @@ public class NumericValueInfoComposite extends Composite {
 
 		// 空白
 		label = new Label(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space8", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = 5;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -704,7 +685,7 @@ public class NumericValueInfoComposite extends Composite {
 
 	/**
 	 * 更新処理
-	 * 
+	 *
 	 */
 	@Override
 	public void update(){
@@ -734,7 +715,7 @@ public class NumericValueInfoComposite extends Composite {
 
 	/**
 	 * 引数で指定された監視情報の値を、各項目に設定します。
-	 * 
+	 *
 	 * @param info 設定値として用いる監視情報
 	 */
 	public void setInputData(MonitorInfo info) {
@@ -800,10 +781,10 @@ public class NumericValueInfoComposite extends Composite {
 	 * <p>
 	 * 入力値チェックを行い、不正な場合は認証結果を返します。
 	 * 不正ではない場合は、<code>null</code>を返します。
-	 * 
+	 *
 	 * @param info 入力値を設定する監視情報
 	 * @return 検証結果
-	 * 
+	 *
 	 * @see #setValidateResult(String, String)
 	 */
 	public ValidateResult createInputData(MonitorInfo info) {
@@ -907,7 +888,7 @@ public class NumericValueInfoComposite extends Composite {
 
 	/**
 	 * 重要度のラベルを返します。
-	 * 
+	 *
 	 * @param parent 親のコンポジット
 	 * @param text ラベルに表示するテキスト
 	 * @param background ラベルの背景色
@@ -920,6 +901,7 @@ public class NumericValueInfoComposite extends Composite {
 
 		// ラベル（重要度）
 		Label label = new Label(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "priority", label);
 		GridData gridData = new GridData();
 		gridData.horizontalSpan = 2;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -933,7 +915,7 @@ public class NumericValueInfoComposite extends Composite {
 
 	/**
 	 * 無効な入力値の情報を設定します。
-	 * 
+	 *
 	 * @param id ID
 	 * @param message メッセージ
 	 * @return 認証結果
@@ -951,7 +933,7 @@ public class NumericValueInfoComposite extends Composite {
 	/**
 	 * 初期値を設定した数値監視の判定情報を返します。<BR>
 	 * 監視対象ID，監視項目ID 及び 重要度をセットした数値監視の判定情報を返します。
-	 * 
+	 *
 	 * @param info 監視情報
 	 * @param priority 重要度
 	 * @return 数値監視の判定情報
@@ -966,20 +948,9 @@ public class NumericValueInfoComposite extends Composite {
 		return value;
 	}
 
-	/**
-	 * 閾値検証フラグを設定します。
-	 * 
-	 * @param rangeFlg 閾値検証フラグ
-	 */
-	public void setRangeFlg(boolean rangeFlg){
-
-		m_rangeFlg = rangeFlg;
-
-	}
-
 	/**
 	 * 判定項目１のラベルを設定します。
-	 * 
+	 *
 	 * @param item1
 	 */
 	public void setTextItem1(String item1){
@@ -988,7 +959,7 @@ public class NumericValueInfoComposite extends Composite {
 
 	/**
 	 * 判定項目２のラベルを設定します。
-	 * 
+	 *
 	 * @param item2
 	 */
 	public void setTextItem2(String item2){
@@ -1003,4 +974,4 @@ public class NumericValueInfoComposite extends Composite {
 
 	}
 
-}
\ No newline at end of file
+}
