@@ -422,6 +422,52 @@ public class SelectMonitor {
 		}
 		return list;
 	}
+	
+	/**
+	 * 監視情報一覧を返します。
+	 * <p>
+	 * <ol>
+	 * <li>引数で指定された監視対象の監視情報を取得します。</li>
+	 * <li>１監視情報をテーブルのカラム順（{@link com.clustercontrol.monitor.run.bean.MonitorTabelDefine}）に、リスト（{@link ArrayList}）にセットします。</li>
+	 * <li>この１監視情報を保持するリストを、監視情報一覧を保持するリスト（{@link ArrayList}）に格納し返します。<BR>
+	 *  <dl>
+	 *  <dt>監視情報一覧（Objectの2次元配列）</dt>
+	 *  <dd>{ 監視情報1 {カラム1の値, カラム2の値, … }, 監視情報2{カラム1の値, カラム2の値, …}, … }</dd>
+	 *  </dl>
+	 * </li>
+	 * </ol>
+	 * 
+	 * @param monitorTypeId 監視対象ID
+	 * @return 監視情報一覧（Objectの2次元配列）
+	 * @throws MonitorNotFound
+	 * @throws InvalidRole
+	 * @throws HinemosUnknown
+	 * @see com.clustercontrol.monitor.run.bean.MonitorTabelDefine
+	 * @see #collectionToArray(Collection)
+	 */
+	public ArrayList<MonitorInfo> getMonitorListObjectPrivilegeModeNONE(String monitorTypeId) throws MonitorNotFound, InvalidRole, HinemosUnknown {
+
+		ArrayList<MonitorInfo> list = new ArrayList<MonitorInfo>();
+		try
+		{
+			// 監視情報一覧を取得
+			List<MonitorInfoEntity> ct = QueryUtil.getMonitorInfoByMonitorTypeId_NONE(monitorTypeId);
+
+			for (MonitorInfoEntity info : ct) {
+				list.add(getMonitorInfoBean(info));
+			}
+		} catch (MonitorNotFound e) {
+			outputLog("011");
+			throw e;
+		} catch (InvalidRole e) {
+			outputLog("011");
+			throw e;
+		} catch (HinemosUnknown e) {
+			outputLog("011");
+			throw e;
+		}
+		return list;
+	}
 
 	/**
 	 * 監視情報一覧を返します。
