@@ -24,7 +24,6 @@ import com.clustercontrol.bean.PriorityConstant;
 import com.clustercontrol.bean.Property;
 import com.clustercontrol.bean.PropertyDefineConstant;
 import com.clustercontrol.monitor.bean.EventBatchConfirmConstant;
-import com.clustercontrol.monitor.bean.EventFilterConstant;
 import com.clustercontrol.monitor.bean.StatusFilterConstant;
 import com.clustercontrol.repository.bean.FacilityTargetConstant;
 import com.clustercontrol.util.Messages;
@@ -42,13 +41,14 @@ public class EventBatchConfirmPropertyUtil {
 	public static EventBatchConfirmInfo property2dto(Property property){
 		EventBatchConfirmInfo info = new EventBatchConfirmInfo();
 
-		ArrayList values = null;
+		ArrayList<?> values = null;
 
-		Integer priority = null;
 		Timestamp outputFromDate = null;
 		Timestamp outputToDate = null;
 		Timestamp generationFromDate = null;
 		Timestamp generationToDate = null;
+		String monitorId = null;
+		String monitorDetailId = null;
 		String facilityType = null;
 		String application = null;
 		String message = null;
@@ -56,17 +56,37 @@ public class EventBatchConfirmPropertyUtil {
 		String commentUser = null;
 
 		//重要度取得
-		values = PropertyUtil.getPropertyValue(property, StatusFilterConstant.PRIORITY);
-		if(!"".equals(values.get(0))){
-			int priorityType = PriorityConstant.stringToType((String)values.get(0));
-			if(priorityType != -1){
-				priority = new Integer(priorityType);
-				info.setPriority(priority);
+		values = PropertyUtil.getPropertyValue(property,
+				EventBatchConfirmConstant.PRIORITY_CRITICAL);
+		if (!"".equals(values.get(0))) {
+			if ((Boolean)values.get(0)) {
+				info.getPriorityList().add(PriorityConstant.TYPE_CRITICAL);
+			}
+		}
+		values = PropertyUtil.getPropertyValue(property,
+				EventBatchConfirmConstant.PRIORITY_WARNING);
+		if (!"".equals(values.get(0))) {
+			if ((Boolean)values.get(0)) {
+				info.getPriorityList().add(PriorityConstant.TYPE_WARNING);
+			}
+		}
+		values = PropertyUtil.getPropertyValue(property,
+				EventBatchConfirmConstant.PRIORITY_INFO);
+		if (!"".equals(values.get(0))) {
+			if ((Boolean)values.get(0)) {
+				info.getPriorityList().add(PriorityConstant.TYPE_INFO);
+			}
+		}
+		values = PropertyUtil.getPropertyValue(property,
+				EventBatchConfirmConstant.PRIORITY_UNKNOWN);
+		if (!"".equals(values.get(0))) {
+			if ((Boolean)values.get(0)) {
+				info.getPriorityList().add(PriorityConstant.TYPE_UNKNOWN);
 			}
 		}
 
 		//更新日時（自）取得
-		values = PropertyUtil.getPropertyValue(property, EventFilterConstant.OUTPUT_FROM_DATE);
+		values = PropertyUtil.getPropertyValue(property, EventBatchConfirmConstant.OUTPUT_FROM_DATE);
 		if(values.get(0) instanceof Date){
 			outputFromDate = new Timestamp(((Date)values.get(0)).getTime());
 			outputFromDate.setNanos(0);
@@ -74,7 +94,7 @@ public class EventBatchConfirmPropertyUtil {
 		}
 
 		//更新日時（至）取得
-		values = PropertyUtil.getPropertyValue(property, EventFilterConstant.OUTPUT_TO_DATE);
+		values = PropertyUtil.getPropertyValue(property, EventBatchConfirmConstant.OUTPUT_TO_DATE);
 		if(values.get(0) instanceof Date){
 			outputToDate = new Timestamp(((Date)values.get(0)).getTime());
 			outputToDate.setNanos(999999999);
@@ -82,7 +102,7 @@ public class EventBatchConfirmPropertyUtil {
 		}
 
 		//出力日時（自）取得
-		values = PropertyUtil.getPropertyValue(property, EventFilterConstant.GENERATION_FROM_DATE);
+		values = PropertyUtil.getPropertyValue(property, EventBatchConfirmConstant.GENERATION_FROM_DATE);
 		if(values.get(0) instanceof Date){
 			generationFromDate = new Timestamp(((Date)values.get(0)).getTime());
 			generationFromDate.setNanos(0);
@@ -90,13 +110,29 @@ public class EventBatchConfirmPropertyUtil {
 		}
 
 		//出力日時（至）取得
-		values = PropertyUtil.getPropertyValue(property, EventFilterConstant.GENERATION_TO_DATE);
+		values = PropertyUtil.getPropertyValue(property, EventBatchConfirmConstant.GENERATION_TO_DATE);
 		if(values.get(0) instanceof Date){
 			generationToDate = new Timestamp(((Date)values.get(0)).getTime());
 			generationToDate.setNanos(999999999);
 			info.setGenerationToDate(generationToDate.getTime());
 		}
 
+		//監視項目ID取得
+		values = PropertyUtil.getPropertyValue(property,
+				EventBatchConfirmConstant.MONITOR_ID);
+		if (!"".equals(values.get(0))) {
+			monitorId = (String) values.get(0);
+			info.setMonitorId(monitorId);
+		}
+
+		//監視詳細取得
+		values = PropertyUtil.getPropertyValue(property,
+				EventBatchConfirmConstant.MONITOR_DETAIL_ID);
+		if (!"".equals(values.get(0))) {
+			monitorDetailId = (String) values.get(0);
+			info.setMonitorDetailId(monitorDetailId);
+		}
+
 		//対象ファシリティ種別取得
 		values = PropertyUtil.getPropertyValue(property, StatusFilterConstant.FACILITY_TYPE);
 		if(!"".equals(values.get(0))){
@@ -119,14 +155,14 @@ public class EventBatchConfirmPropertyUtil {
 		}
 
 		//コメント
-		values = PropertyUtil.getPropertyValue(property, EventFilterConstant.COMMENT);
+		values = PropertyUtil.getPropertyValue(property, EventBatchConfirmConstant.COMMENT);
 		if(!"".equals(values.get(0))){
 			comment = (String)values.get(0);
 			info.setComment(comment);
 		}
 
 		//コメントユーザ
-		values = PropertyUtil.getPropertyValue(property, EventFilterConstant.COMMENT_USER);
+		values = PropertyUtil.getPropertyValue(property, EventBatchConfirmConstant.COMMENT_USER);
 		if(!"".equals(values.get(0))){
 			commentUser = (String)values.get(0);
 			info.setCommentUser(commentUser);
@@ -150,7 +186,13 @@ public class EventBatchConfirmPropertyUtil {
 	 * <ul>
 	 *  <li>プロパティ（親。ダミー）</li>
 	 *  <ul>
-	 *   <li>重要度（子。コンボボックス）</li>
+	 *   <li>重要度（子。テキスト）</li>
+	 *   <ul>
+	 *    <li>危険（孫。チェックボックス）</li>
+	 *    <li>警告（孫。チェックボックス）</li>
+	 *    <li>情報（孫。チェックボックス）</li>
+	 *    <li>不明（孫。チェックボックス）</li>
+	 *   <ul>
 	 *   <li>受信日時（子。テキスト）</li>
 	 *   <ul>
 	 *    <li>開始（孫。日時ダイアログ）</li>
@@ -161,6 +203,8 @@ public class EventBatchConfirmPropertyUtil {
 	 *    <li>開始（孫。日時ダイアログ）</li>
 	 *    <li>終了（孫。日時ダイアログ）</li>
 	 *   </ul>
+	 *   <li>監視項目ID（子。テキスト）</li>
+	 *   <li>監視詳細（子。テキスト）</li>
 	 *   <li>ファシリティのターゲット（子。コンボボックス）</li>
 	 *   <li>アプリケーション（子。テキスト）</li>
 	 *   <li>メッセージ（子。テキスト）</li>
@@ -181,7 +225,19 @@ public class EventBatchConfirmPropertyUtil {
 
 		//重要度
 		Property m_priority =
-				new Property(EventBatchConfirmConstant.PRIORITY, Messages.getString("priority", locale), PropertyDefineConstant.EDITOR_SELECT);
+				new Property(EventBatchConfirmConstant.PRIORITY, Messages.getString("priority", locale), PropertyDefineConstant.EDITOR_TEXT);
+		//重要度（危険）
+		Property m_priorityCritical =
+				new Property(EventBatchConfirmConstant.PRIORITY_CRITICAL, Messages.getString("critical", locale), PropertyDefineConstant.EDITOR_BOOL);
+		//重要度(警告)
+		Property m_priorityWarning =
+				new Property(EventBatchConfirmConstant.PRIORITY_WARNING, Messages.getString("warning", locale), PropertyDefineConstant.EDITOR_BOOL);
+		//重要度(情報)
+		Property m_priorityInfo =
+				new Property(EventBatchConfirmConstant.PRIORITY_INFO, Messages.getString("info", locale), PropertyDefineConstant.EDITOR_BOOL);
+		//重要度(不明)
+		Property m_priorityUnknown =
+				new Property(EventBatchConfirmConstant.PRIORITY_UNKNOWN, Messages.getString("unknown", locale), PropertyDefineConstant.EDITOR_BOOL);
 		//受信日時（自）
 		Property m_outputFromDate =
 				new Property(EventBatchConfirmConstant.OUTPUT_FROM_DATE, Messages.getString("start", locale), PropertyDefineConstant.EDITOR_DATETIME);
@@ -197,6 +253,12 @@ public class EventBatchConfirmPropertyUtil {
 		//対象ファシリティ種別
 		Property m_facilityType =
 				new Property(EventBatchConfirmConstant.FACILITY_TYPE, Messages.getString("facility.target", locale), PropertyDefineConstant.EDITOR_SELECT);
+		//監視項目ID
+		Property m_monitorId =
+				new Property(EventBatchConfirmConstant.MONITOR_ID, Messages.getString("monitor.id", locale), PropertyDefineConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_64);
+		//監視項目詳細
+		Property m_monitorDetailId =
+				new Property(EventBatchConfirmConstant.MONITOR_DETAIL_ID, Messages.getString("monitor.detail.id", locale), PropertyDefineConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_1024);
 		//アプリケーション
 		Property m_application =
 				new Property(EventBatchConfirmConstant.APPLICATION, Messages.getString("application", locale), PropertyDefineConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_64);
@@ -219,18 +281,20 @@ public class EventBatchConfirmPropertyUtil {
 
 		//値を初期化
 
-		Object priorityValues[][] = {
-				{ "", PriorityConstant.STRING_CRITICAL, PriorityConstant.STRING_WARNING, PriorityConstant.STRING_INFO, PriorityConstant.STRING_UNKNOWN},
-				{ "", PriorityConstant.STRING_CRITICAL, PriorityConstant.STRING_WARNING, PriorityConstant.STRING_INFO, PriorityConstant.STRING_UNKNOWN}};
-
-		m_priority.setSelectValues(priorityValues);
-		m_priority.setValue(PriorityConstant.STRING_CRITICAL);
+		m_priority.setValue("");
+		m_priorityCritical.setValue(new Boolean(true));
+		m_priorityWarning.setValue(new Boolean(true));
+		m_priorityInfo.setValue(new Boolean(true));
+		m_priorityUnknown.setValue(new Boolean(true));
 
 		m_outputFromDate.setValue("");
 		m_outputToDate.setValue("");
 		m_generationFromDate.setValue("");
 		m_generationToDate.setValue("");
 
+		m_monitorId.setValue("");
+		m_monitorDetailId.setValue("");
+
 		Object facilityTypeValues[][] = {
 				{ FacilityTargetConstant.STRING_ALL, FacilityTargetConstant.STRING_BENEATH},
 				{ FacilityTargetConstant.STRING_ALL, FacilityTargetConstant.STRING_BENEATH}};
@@ -248,11 +312,17 @@ public class EventBatchConfirmPropertyUtil {
 
 
 		//変更の可/不可を設定
-		m_priority.setModify(PropertyDefineConstant.MODIFY_OK);
+		m_priority.setModify(PropertyDefineConstant.MODIFY_NG);
+		m_priorityCritical.setModify(PropertyDefineConstant.MODIFY_OK);
+		m_priorityWarning.setModify(PropertyDefineConstant.MODIFY_OK);
+		m_priorityInfo.setModify(PropertyDefineConstant.MODIFY_OK);
+		m_priorityUnknown.setModify(PropertyDefineConstant.MODIFY_OK);
 		m_outputFromDate.setModify(PropertyDefineConstant.MODIFY_OK);
 		m_outputToDate.setModify(PropertyDefineConstant.MODIFY_OK);
 		m_generationFromDate.setModify(PropertyDefineConstant.MODIFY_OK);
 		m_generationToDate.setModify(PropertyDefineConstant.MODIFY_OK);
+		m_monitorId.setModify(PropertyDefineConstant.MODIFY_OK);
+		m_monitorDetailId.setModify(PropertyDefineConstant.MODIFY_OK);
 		m_facilityType.setModify(PropertyDefineConstant.MODIFY_OK);
 		m_application.setModify(PropertyDefineConstant.MODIFY_OK);
 		m_message.setModify(PropertyDefineConstant.MODIFY_OK);
@@ -270,12 +340,21 @@ public class EventBatchConfirmPropertyUtil {
 		property.addChildren(m_priority);
 		property.addChildren(m_outputDate);
 		property.addChildren(m_generationDate);
+		property.addChildren(m_monitorId);
+		property.addChildren(m_monitorDetailId);
 		property.addChildren(m_facilityType);
 		property.addChildren(m_application);
 		property.addChildren(m_message);
 		property.addChildren(m_comment);
 		property.addChildren(m_commentUser);
 
+		// 重要度
+		m_priority.removeChildren();
+		m_priority.addChildren(m_priorityCritical);
+		m_priority.addChildren(m_priorityWarning);
+		m_priority.addChildren(m_priorityInfo);
+		m_priority.addChildren(m_priorityUnknown);
+
 		// 受信日時
 		m_outputDate.removeChildren();
 		m_outputDate.addChildren(m_outputFromDate);
