@@ -31,6 +31,7 @@ import com.clustercontrol.bean.PropertyDefineConstant;
 import com.clustercontrol.bean.ValidConstant;
 import com.clustercontrol.calendar.util.CalendarEndpointWrapper;
 import com.clustercontrol.monitor.bean.MonitorFilterConstant;
+import com.clustercontrol.util.EndpointManager;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.util.PropertyUtil;
 import com.clustercontrol.ws.calendar.CalendarInfo;
@@ -43,7 +44,7 @@ import com.clustercontrol.ws.repository.FacilityTreeItem;
 
 /**
  * 監視[一覧]のフィルタダイアログに関するutilityクラス
- * 
+ *
  * @version 4.0.0
  * @since 4.0.0
  */
@@ -54,7 +55,7 @@ public class MonitorFilterPropertyUtil {
 
 	/**
 	 * プロパティを監視設定フィルタDTOに変換するメソッドです。
-	 * 
+	 *
 	 * @param property
 	 * @return
 	 */
@@ -76,7 +77,7 @@ public class MonitorFilterPropertyUtil {
 		int collectorFlg = -1;	// 監視無効フラグ
 		String ownerRoleId = null;	// オーナーロールID
 
-		ArrayList values = null;
+		ArrayList<?> values = null;
 
 		//監視項目ID
 		values = PropertyUtil.getPropertyValue(property,
@@ -201,7 +202,7 @@ public class MonitorFilterPropertyUtil {
 			}
 		}
 		info.setCollectorFlg(collectorFlg);
-		
+
 		//オーナーロールID
 		values = PropertyUtil.getPropertyValue(property,
 				MonitorFilterConstant.OWNER_ROLE_ID);
@@ -215,12 +216,16 @@ public class MonitorFilterPropertyUtil {
 
 	/**
 	 * 監視設定用フィルタプロパティを取得します。<BR>
-	 * 
+	 *
 	 * @param locale
 	 * @return
 	 */
 	public static Property getProperty(Locale locale) {
 
+		//マネージャ
+		Property manager =
+				new Property(MonitorFilterConstant.MANAGER, Messages.getString("facility.manager", locale), PropertyDefineConstant.EDITOR_SELECT);
+
 		//監視項目ID
 		Property monitorId =
 				new Property(MonitorFilterConstant.MONITOR_ID, Messages.getString("monitor.id", locale), PropertyDefineConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_64);
@@ -283,6 +288,18 @@ public class MonitorFilterPropertyUtil {
 		//オーナーロールID
 		Property ownerRoleId =
 				new Property(MonitorFilterConstant.OWNER_ROLE_ID, Messages.getString("owner.role.id", locale), PropertyDefineConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_64);
+
+		Object[] obj = EndpointManager.getActiveManagerSet().toArray();
+		Object[] val = new Object[obj.length + 1];
+		val[0] = "";
+		for(int i = 0; i<obj.length; i++) {
+			val[i + 1] = obj[i];
+		}
+
+		Object[][] managerValues = {val, val};
+		manager.setSelectValues(managerValues);
+		manager.setValue("");
+
 		//値を初期化
 		Object monitorFlgValues[][] = {
 				{ "", ValidConstant.STRING_VALID, ValidConstant.STRING_INVALID},
@@ -314,10 +331,11 @@ public class MonitorFilterPropertyUtil {
 		regToDate.setValue("");
 		updateFromDate.setValue("");
 		updateToDate.setValue("");
-		
+
 		ownerRoleId.setValue("");
 
 		//変更の可/不可を設定
+		manager.setModify(PropertyDefineConstant.MODIFY_OK);
 		monitorId.setModify(PropertyDefineConstant.MODIFY_OK);
 		monitorTypeId.setModify(PropertyDefineConstant.MODIFY_OK);
 		description.setModify(PropertyDefineConstant.MODIFY_OK);
@@ -334,13 +352,14 @@ public class MonitorFilterPropertyUtil {
 		regToDate.setModify(PropertyDefineConstant.MODIFY_OK);
 		updateFromDate.setModify(PropertyDefineConstant.MODIFY_OK);
 		updateToDate.setModify(PropertyDefineConstant.MODIFY_OK);
-		
+
 		ownerRoleId.setModify(PropertyDefineConstant.MODIFY_OK);
 
 		Property property = new Property(null, null, "");
 
 		// 初期表示ツリーを構成。
 		property.removeChildren();
+		property.addChildren(manager);
 		property.addChildren(monitorId);
 		property.addChildren(monitorTypeId);
 		property.addChildren(description);
@@ -373,10 +392,15 @@ public class MonitorFilterPropertyUtil {
 	 */
 	private static Object[][] getCalendarIdList() {
 
-		List<CalendarInfo> calList = null;
+		List<CalendarInfo> calList = new ArrayList<CalendarInfo>();
 		Object retArray[][] = null;
 		try{
-			calList = CalendarEndpointWrapper.getAllCalendarList();
+			for(String managerName : EndpointManager.getActiveManagerSet()) {
+				CalendarEndpointWrapper wrapper = CalendarEndpointWrapper.getWrapper(managerName);
+				for(CalendarInfo info : wrapper.getAllCalendarList()) {
+					calList.add(info);
+				}
+			}
 		} catch (InvalidUserPass_Exception e) {
 			// アクセス権なしの場合、エラーダイアログを表示する
 			MessageDialog.openInformation(
@@ -403,7 +427,7 @@ public class MonitorFilterPropertyUtil {
 					Messages.getString("message.hinemos.failure.unexpected") + ", " + e.getMessage());
 		}
 
-		if(calList != null)
+		if(calList != null && calList.isEmpty() == false)
 		{
 			retArray = new Object[2][calList.size()+1];
 			retArray[0][0] = "";
