@@ -16,7 +16,9 @@ PURPOSE.  See the GNU General Public License for more details.
 package com.clustercontrol.notify.dialog;
 
 import java.util.ArrayList;
-import java.util.List;
+
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 import org.eclipse.jface.dialogs.IDialogConstants;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.events.ModifyEvent;
@@ -33,8 +35,8 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
 
+import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.bean.PriorityColorConstant;
-import com.clustercontrol.bean.PriorityConstant;
 import com.clustercontrol.bean.RequiredFieldColorConstant;
 import com.clustercontrol.bean.ValidConstant;
 import com.clustercontrol.dialog.ValidateResult;
@@ -48,20 +50,22 @@ import com.clustercontrol.ws.notify.NotifyMailInfo;
 
 /**
  * 通知（メール）作成・変更ダイアログクラス<BR>
- * 
+ *
  * @version 4.0.0
  * @since 3.0.0
  */
 public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 
+	private static Log m_log = LogFactory.getLog( NotifyMailCreateDialog.class );
+
 	/** カラム数（重要度）。 */
-	private static final int WIDTH_PRIORITY 		= 2;
+	private static final int WIDTH_PRIORITY = 2;
 
 	/** カラム数（チェックボックス）。 */
-	private static final int WIDTH_CHECK 			= 2;
+	private static final int WIDTH_CHECK = 2;
 
 	/** カラム数（メッセールアドレス）。 */
-	private static final int WIDTH_MAIL_ADDRESS		= 11;
+	private static final int WIDTH_MAIL_ADDRESS = 11;
 
 	// ----- instance フィールド ----- //
 
@@ -70,9 +74,6 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 	 */
 	private final int TYPE_MAIL = 2;
 
-	/** 入力値を保持するオブジェクト。 */
-	private NotifyInfo inputData = null;
-
 	/** 入力値の正当性を保持するオブジェクト。 */
 	protected ValidateResult validateResult = null;
 
@@ -97,55 +98,70 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 	/** メールアドレス（重要度：不明） テキスト。 */
 	private Text m_textMailAddressUnknown = null;
 
-	/** オーナーロールID */
-	private String ownerRoleId = null;
-
 	// ----- コンストラクタ ----- //
 
 	/**
 	 * 作成用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent 親のシェルオブジェクト
 	 */
 	public NotifyMailCreateDialog(Shell parent) {
 		super(parent);
 	}
 
-	public NotifyMailCreateDialog(Shell parent, int notifyIdType) {
-		super(parent, notifyIdType);
-	}
-
 	/**
 	 * 変更用ダイアログのインスタンスを返します。
-	 * 
+	 *
+	 * @param managerName マネージャ名
 	 * @param parent 親のシェルオブジェクト
 	 * @param notifyId 変更する通知情報の通知ID
 	 * @param updateFlg 更新フラグ（true:更新する）
 	 */
-	public NotifyMailCreateDialog(Shell parent, String notifyId, boolean updateFlg) {
-		super(parent, notifyId, updateFlg);
+	public NotifyMailCreateDialog(Shell parent, String managerName, String notifyId, boolean updateFlg) {
+		super(parent, managerName, notifyId, updateFlg);
 	}
 
 	// ----- instance メソッド ----- //
 
 	/**
 	 * ダイアログエリアを生成します。
-	 * 
+	 *
 	 * @param parent 親のコンポジット
-	 * 
+	 *
 	 * @see com.clustercontrol.notify.dialog.NotifyBasicCreateDialog#customizeDialog(Composite)
 	 * @see com.clustercontrol.notify.action.GetNotify#getNotify(String)
 	 * @see #setInputData(NotifyInfo)
 	 */
 	@Override
 	protected void customizeDialog(Composite parent) {
-
 		super.customizeDialog(parent);
 
+		m_log.debug("addSelectionListener");
+		if (this.m_notifyBasic.m_managerComposite.getComboManagerName() != null) {
+			this.m_notifyBasic.m_managerComposite.getComboManagerName().addSelectionListener(new SelectionAdapter() {	
+				@Override
+				public void widgetSelected(SelectionEvent e) {
+					m_log.debug("widgetSelected(managerComposite)");
+								String managerName = m_notifyBasic.m_managerComposite.getText();
+					m_compositeMailTemplateIdList.setManagerName(managerName);
+					m_compositeMailTemplateIdList.update(m_notifyBasic.m_ownerRoleId.getText());
+				}
+			});
+		}
+		if (this.m_notifyBasic.m_ownerRoleId.getComboRoleId() != null) {
+			this.m_notifyBasic.m_ownerRoleId.getComboRoleId().addSelectionListener(new SelectionAdapter() {
+				@Override
+				public void widgetSelected(SelectionEvent e) {
+					m_log.debug("widgetSelected(ownerRoleId)");
+					m_compositeMailTemplateIdList.update(m_notifyBasic.m_ownerRoleId.getText());
+				}
+			});
+		}
+
 		// 通知IDが指定されている場合、その情報を初期表示する。
 		NotifyInfo info = null;
 		if(this.notifyId != null){
-			info = new GetNotify().getNotify(this.notifyId);
+			info = new GetNotify().getNotify(this.managerName, this.notifyId);
 		}
 		else{
 			info = new NotifyInfo();
@@ -155,9 +171,9 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * 親のクラスから呼ばれ、各通知用のダイアログエリアを生成します。
-	 * 
+	 *
 	 * @param parent 親のコンポジット
-	 * 
+	 *
 	 * @see com.clustercontrol.notify.dialog.NotifyBasicCreateDialog#customizeDialog(Composite)
 	 */
 	@Override
@@ -184,6 +200,7 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 		 */
 		// メールグループ
 		Group groupMail = new Group(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "goupmail", groupMail);
 		layout = new GridLayout(1, true);
 		layout.marginWidth = 5;
 		layout.marginHeight = 5;
@@ -199,7 +216,9 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 		/*
 		 * メールテンプレートIDの設定
 		 */
-		this.m_compositeMailTemplateIdList = new MailTemplateIdListComposite(groupMail, SWT.NONE, true);
+		this.m_compositeMailTemplateIdList = new MailTemplateIdListComposite(
+				groupMail, SWT.NONE, this.m_notifyBasic.getManagerListComposite().getText(), true);
+		WidgetTestUtil.setTestId(this, "templateidlist", m_compositeMailTemplateIdList);
 		gridData = new GridData();
 		gridData.horizontalSpan = 15;
 		gridData.horizontalAlignment = GridData.BEGINNING;
@@ -208,6 +227,7 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 
 		// 空行
 		label = new Label(groupMail, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space1", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = 15;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -219,6 +239,7 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 		 */
 		// ラベル（重要度）
 		label = new Label(groupMail, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "priority", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_PRIORITY;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -228,6 +249,7 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 
 		// ラベル（メール）
 		label = new Label(groupMail, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "mail", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_CHECK;
 		gridData.horizontalAlignment = GridData.CENTER;
@@ -237,6 +259,7 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 
 		// ラベル（メールアドレス）
 		label = new Label(groupMail, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "mailaddress", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_MAIL_ADDRESS;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -247,6 +270,7 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 		//　メール　重要度：情報
 		label = this.getLabelPriority(groupMail, Messages.getString("info"),PriorityColorConstant.COLOR_INFO);
 		this.m_checkMailNormalInfo = this.getCheckMailNormal(groupMail);
+		WidgetTestUtil.setTestId(this, "mailnormalinfo", m_checkMailNormalInfo);
 		this.m_checkMailNormalInfo.addSelectionListener(new SelectionAdapter() {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
@@ -255,6 +279,8 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 			}
 		});
 		this.m_textMailAddressInfo = this.getTextMailAddress(groupMail);
+		WidgetTestUtil.setTestId(this, "mailaddressinfo", m_textMailAddressInfo);
+		this.m_textMailAddressInfo.setToolTipText(Messages.getString("notify.parameter.tooltip"));
 		this.m_textMailAddressInfo.addModifyListener(new ModifyListener(){
 			@Override
 			public void modifyText(ModifyEvent arg0) {
@@ -265,6 +291,7 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 		//　メール　重要度：警告
 		label = this.getLabelPriority(groupMail, Messages.getString("warning"),PriorityColorConstant.COLOR_WARNING);
 		this.m_checkMailNormalWarning = this.getCheckMailNormal(groupMail);
+		WidgetTestUtil.setTestId(this, "mailnormalwarning", m_checkMailNormalWarning);
 		this.m_checkMailNormalWarning.addSelectionListener(new SelectionAdapter() {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
@@ -273,6 +300,8 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 			}
 		});
 		this.m_textMailAddressWarning = this.getTextMailAddress(groupMail);
+		WidgetTestUtil.setTestId(this, "mailaddresswarning", m_textMailAddressWarning);
+		this.m_textMailAddressWarning.setToolTipText(Messages.getString("notify.parameter.tooltip"));
 		this.m_textMailAddressWarning.addModifyListener(new ModifyListener(){
 			@Override
 			public void modifyText(ModifyEvent arg0) {
@@ -283,6 +312,7 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 		//　メール　重要度：危険
 		label = this.getLabelPriority(groupMail, Messages.getString("critical"),PriorityColorConstant.COLOR_CRITICAL);
 		this.m_checkMailNormalCritical = this.getCheckMailNormal(groupMail);
+		WidgetTestUtil.setTestId(this, "mailnormalcritical", m_checkMailNormalCritical);
 		this.m_checkMailNormalCritical.addSelectionListener(new SelectionAdapter() {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
@@ -291,6 +321,8 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 			}
 		});
 		this.m_textMailAddressCritical = this.getTextMailAddress(groupMail);
+		WidgetTestUtil.setTestId(this, "mailaddresscritical", m_textMailAddressCritical);
+		this.m_textMailAddressCritical.setToolTipText(Messages.getString("notify.parameter.tooltip"));
 		this.m_textMailAddressCritical.addModifyListener(new ModifyListener(){
 			@Override
 			public void modifyText(ModifyEvent arg0) {
@@ -301,6 +333,7 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 		//　メール　重要度：不明
 		label = this.getLabelPriority(groupMail, Messages.getString("unknown"),PriorityColorConstant.COLOR_UNKNOWN);
 		this.m_checkMailNormalUnknown = this.getCheckMailNormal(groupMail);
+		WidgetTestUtil.setTestId(this, "mailnormalunknown", m_checkMailNormalUnknown);
 		this.m_checkMailNormalUnknown.addSelectionListener(new SelectionAdapter() {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
@@ -309,6 +342,8 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 			}
 		});
 		this.m_textMailAddressUnknown = this.getTextMailAddress(groupMail);
+		WidgetTestUtil.setTestId(this, "mailaddressunknown", m_textMailAddressUnknown);
+		this.m_textMailAddressUnknown.setToolTipText(Messages.getString("notify.parameter.tooltip"));
 		this.m_textMailAddressUnknown.addModifyListener(new ModifyListener(){
 			@Override
 			public void modifyText(ModifyEvent arg0) {
@@ -319,7 +354,7 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * 更新処理
-	 * 
+	 *
 	 */
 	public void update(){
 		// テキストボックスの有効/無効を初期化
@@ -358,7 +393,7 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * 入力値を保持した通知情報を返します。
-	 * 
+	 *
 	 * @return 通知情報
 	 */
 	@Override
@@ -368,193 +403,126 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * 引数で指定された通知情報の値を、各項目に設定します。
-	 * 
+	 *
 	 * @param notify 設定値として用いる通知情報
 	 */
 	@Override
 	protected void setInputData(NotifyInfo notify) {
+		// Add listener at first
+		this.setInputListeners();
+		super.setInputData(notify);
 
-		this.inputData = notify;
+		// List mail template ID
+		m_compositeMailTemplateIdList.update(m_notifyBasic.getOwnerRoleId());
 
-		// 通知基本情報
-		super.m_notifyBasic.setInputData(notify, this.updateFlg);
-
-		// 初回通知情報
-		super.m_notifyInitial.setInputData(notify);
-
-		// 抑制情報
-		super.m_notifyInhibition.setInputData(notify);
-
-		// メール情報
-		List<NotifyMailInfo> list = notify.getNotifyMailInfo();
-		if (list != null && list.size() > 0) {
-			for(int index=0; index<list.size(); index++){
-				NotifyMailInfo mail = list.get(index);
-				if(mail != null){
-					// 通知の場合
-					if(PriorityConstant.TYPE_INFO ==  mail.getPriority()){
-						this.setInputDataForMail(mail, this.m_checkMailNormalInfo, this.m_textMailAddressInfo, null);
-						//通知のみメール通知の共通部分の設定行う
-						if (mail.getMailTemplateId() != null) {
-							this.m_compositeMailTemplateIdList.setText(mail.getMailTemplateId());
-						}
-					}
-					// 警告の場合
-					else if(PriorityConstant.TYPE_WARNING ==  mail.getPriority()){
-						this.setInputDataForMail(mail, this.m_checkMailNormalWarning, this.m_textMailAddressWarning, null);
-					}
-					// 危険の場合
-					else if(PriorityConstant.TYPE_CRITICAL ==  mail.getPriority()){
-						this.setInputDataForMail(mail, this.m_checkMailNormalCritical, this.m_textMailAddressCritical, null);
-					}
-					// 不明の場合
-					else if(PriorityConstant.TYPE_UNKNOWN ==  mail.getPriority()){
-						this.setInputDataForMail(mail, this.m_checkMailNormalUnknown, this.m_textMailAddressUnknown, null);
-					}
-				}
-			}
-		}
-
-		// 有効／無効
-		if (notify.getValidFlg() != null && notify.getValidFlg() == ValidConstant.TYPE_INVALID) {
-			this.m_confirmValid.setSelection(false);
-		}
-		else {
-			this.m_confirmValid.setSelection(true);
+		// コマンド情報
+		NotifyMailInfo info = notify.getNotifyMailInfo();
+		if (info != null) {
+			this.setInputData(info);
 		}
 
 		// 必須入力項目を可視化
 		this.update();
 	}
 
-	/**
-	 * 引数で指定された通知ステータス情報の値を、各項目に設定します。
-	 * 
-	 * @param info 設定値として用いる通知メール情報
-	 * @param checkMailNormal 通知チェックボックス
-	 * @param textMailAddress メールアドレステキストボックス
-	 * @param checkMailInhibition 抑制チェックボックス
-	 */
-	protected void setInputDataForMail(NotifyMailInfo info,
-			Button checkMailNormal,
-			Text textMailAddress,
-			Button checkMailInhibition
-			) {
-		// メール通知
-		if (info.getValidFlg() != null && info.getValidFlg().intValue() == ValidConstant.TYPE_VALID) {
-			checkMailNormal.setSelection(true);
+	private void setInputData(NotifyMailInfo mail) {
+		if (mail.getMailTemplateId() != null) {
+			this.m_compositeMailTemplateIdList.setText(mail.getMailTemplateId());
 		}
-		// メールアドレス
-		if (info.getMailAddress() != null) {
-			textMailAddress.setText(info.getMailAddress());
+
+		Button[] checkMailNormals = new Button[] {
+				this.m_checkMailNormalInfo,
+				this.m_checkMailNormalWarning,
+				this.m_checkMailNormalCritical,
+				this.m_checkMailNormalUnknown
+		};
+		String[] mailAddresses = new String[] {
+				mail.getInfoMailAddress(),
+				mail.getWarnMailAddress(),
+				mail.getCriticalMailAddress(),
+				mail.getUnknownMailAddress()
+		};
+		Text[] textMailAddresses = new Text[] {
+				this.m_textMailAddressInfo,
+				this.m_textMailAddressWarning,
+				this.m_textMailAddressCritical,
+				this.m_textMailAddressUnknown
+		};
+
+		Integer[] validFlgs = getValidFlgs(mail);
+		for (int i = 0; i < validFlgs.length; i++) {
+			boolean valid = validFlgs[i] == ValidConstant.TYPE_VALID;
+			checkMailNormals[i].setSelection(valid);
+			WidgetTestUtil.setTestId(this, "checkMailNormals" + i, checkMailNormals[i]);
+			if (mailAddresses[i] != null) {
+				textMailAddresses[i].setText(mailAddresses[i]);
+				WidgetTestUtil.setTestId(this, "addreses" + i, textMailAddresses[i]);
+			}
 		}
 	}
 
-
 	/**
 	 * 入力値を設定した通知情報を返します。<BR>
 	 * 入力値チェックを行い、不正な場合は<code>null</code>を返します。
-	 * 
+	 *
 	 * @return 通知情報
-	 * 
+	 *
 	 * @see #createInputDataForMail(ArrayList, int, Button, Text, Button)
 	 */
 	@Override
 	protected NotifyInfo createInputData() {
-		NotifyInfo info = new NotifyInfo();
+		NotifyInfo info = super.createInputData();
+		if (info == null) {
+			return null;
+		}
 
 		// 通知タイプの設定
 		info.setNotifyType(TYPE_MAIL);
 
-		// 通知基本情報
-		validateResult = super.m_notifyBasic.createInputData(info, this.notifyId);
-		if(validateResult != null){
-			return null;
-		}
-
-		// 初回通知情報
-		validateResult = super.m_notifyInitial.createInputData(info);
-		if(validateResult != null){
-			return null;
-		}
-
-		// 抑制情報
-		validateResult = super.m_notifyInhibition.createInputData(info);
-		if(validateResult != null){
-			return null;
-		}
-
-		// メール情報
-		ArrayList<NotifyMailInfo> list = new ArrayList<NotifyMailInfo>();
-		list = this.createInputDataForMail(list, PriorityConstant.TYPE_INFO,	this.m_checkMailNormalInfo, this.m_textMailAddressInfo);
-		list = this.createInputDataForMail(list, PriorityConstant.TYPE_WARNING,	this.m_checkMailNormalWarning, this.m_textMailAddressWarning);
-		list = this.createInputDataForMail(list, PriorityConstant.TYPE_CRITICAL,this.m_checkMailNormalCritical, this.m_textMailAddressCritical);
-		list = this.createInputDataForMail(list, PriorityConstant.TYPE_UNKNOWN,	this.m_checkMailNormalUnknown, this.m_textMailAddressUnknown);
-
-		if(list == null){
-			return null;
-		}
-
-		List<NotifyMailInfo> notifyMailInfo = info.getNotifyMailInfo();
-		notifyMailInfo.clear();
-		notifyMailInfo.addAll(list);
-
-		// 有効/無効
-		if (this.m_confirmValid.getSelection()) {
-			info.setValidFlg(ValidConstant.TYPE_VALID);
-		} else {
-			info.setValidFlg(ValidConstant.TYPE_INVALID);
-		}
+		// イベント情報
+		NotifyMailInfo mail = createInputData(info.getNotifyId());
+		info.setNotifyMailInfo(mail);
 
 		return info;
 	}
 
-	/**
-	 * 入力値を設定した通知イベント情報を返します。<BR>
-	 * 入力値チェックを行い、不正な場合は<code>null</code>を返します。
-	 * 
-	 * @return 通知メール情報
-	 * 
-	 */
-	private ArrayList<NotifyMailInfo> createInputDataForMail(ArrayList<NotifyMailInfo> list,
-			int priority,
-			Button checkMailNormal,
-			Text textMailAddress
-			) {
-
-		if(list == null)
-			return null;
-
+	private NotifyMailInfo createInputData(String notifyId) {
 		NotifyMailInfo mail = new NotifyMailInfo();
+		mail.setNotifyId(notifyId);
 
-		// 重要度
-		mail.setPriority(priority);
 		// メール通知
-		if (checkMailNormal.getSelection()) {
-			mail.setValidFlg(new Integer(ValidConstant.TYPE_VALID));
-		} else {
-			mail.setValidFlg(new Integer(ValidConstant.TYPE_INVALID));
-		}
+		mail.setInfoValidFlg(ValidConstant.booleanToType(m_checkMailNormalInfo.getSelection()));
+		mail.setWarnValidFlg(ValidConstant.booleanToType(m_checkMailNormalWarning.getSelection()));
+		mail.setCriticalValidFlg(ValidConstant.booleanToType(m_checkMailNormalCritical.getSelection()));
+		mail.setUnknownValidFlg(ValidConstant.booleanToType(m_checkMailNormalUnknown.getSelection()));
+
 		// メールアドレス
-		if (textMailAddress.getText() != null
-				&& !"".equals((textMailAddress.getText()).trim())) {
-			mail.setMailAddress(textMailAddress.getText());
+		if (isNotNullAndBlank(m_textMailAddressInfo.getText())) {
+			mail.setInfoMailAddress(m_textMailAddressInfo.getText());
+		}
+		if (isNotNullAndBlank(m_textMailAddressWarning.getText())) {
+			mail.setWarnMailAddress(m_textMailAddressWarning.getText());
+		}
+		if (isNotNullAndBlank(m_textMailAddressCritical.getText())) {
+			mail.setCriticalMailAddress(m_textMailAddressCritical.getText());
+		}
+		if (isNotNullAndBlank(m_textMailAddressUnknown.getText())) {
+			mail.setUnknownMailAddress(m_textMailAddressUnknown.getText());
 		}
 
-		// メールテンプレートＩＤ（重要度に関係なく全て同じものを設定する）
+		// メールテンプレートＩＤ
 		String mailTemplateId = this.m_compositeMailTemplateIdList.getText();
 		// メールテンプレートID
-		if (mailTemplateId != null && !"".equals(mailTemplateId.trim())) {
+		if (isNotNullAndBlank(mailTemplateId)) {
 			mail.setMailTemplateId(mailTemplateId);
 		}
 
-		list.add(mail);
-		return list;
+		return mail;
 	}
 
 	/**
 	 * 入力値チェックをします。
-	 * 
+	 *
 	 * @return 検証結果
 	 */
 	@Override
@@ -571,9 +539,9 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * 入力値をマネージャに登録します。
-	 * 
+	 *
 	 * @return true：正常、false：異常
-	 * 
+	 *
 	 * @see com.clustercontrol.dialog.CommonDialog#action()
 	 */
 	@Override
@@ -584,11 +552,11 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 		if(info != null){
 			if (!this.updateFlg) {
 				// 作成の場合
-				result = new AddNotify().add(info);
+				result = new AddNotify().add(this.getInputManagerName(), info);
 			}
 			else{
 				// 変更の場合
-				result = new ModifyNotify().modify(info);
+				result = new ModifyNotify().modify(this.getInputManagerName(), info);
 			}
 		}
 
@@ -597,7 +565,7 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * ＯＫボタンのテキストを返します。
-	 * 
+	 *
 	 * @return ＯＫボタンのテキスト
 	 */
 	@Override
@@ -607,7 +575,7 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * キャンセルボタンのテキストを返します。
-	 * 
+	 *
 	 * @return キャンセルボタンのテキスト
 	 */
 	@Override
@@ -617,7 +585,7 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * 無効な入力値の情報を設定します。
-	 * 
+	 *
 	 * @param id ID
 	 * @param message メッセージ
 	 */
@@ -633,9 +601,9 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 	/**
 	 * ボタンを生成します。<BR>
 	 * 参照フラグが<code> true </code>の場合は閉じるボタンを生成し、<code> false </code>の場合は、デフォルトのボタンを生成します。
-	 * 
+	 *
 	 * @param parent ボタンバーコンポジット
-	 * 
+	 *
 	 * @see #createButtonsForButtonBar(Composite)
 	 */
 	@Override
@@ -646,13 +614,14 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 		}
 		else{
 			// 閉じるボタン
-			this.createButton(parent, IDialogConstants.CANCEL_ID, IDialogConstants.CLOSE_LABEL, false);
+			// TODO Remove the following hard-code. IDialogConstants.*_LABEL will causes IncompatibleClassChangeError on RAP
+			this.createButton(parent, IDialogConstants.CANCEL_ID, "Close", false);
 		}
 	}
 
 	/**
 	 * コンポジットの選択可/不可を設定します。
-	 * 
+	 *
 	 * @param enable 選択可の場合、<code> true </code>
 	 */
 	@Override
@@ -663,7 +632,7 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * 重要度のラベルを返します。
-	 * 
+	 *
 	 * @param parent 親のコンポジット
 	 * @param text ラベルに表示するテキスト
 	 * @param background ラベルの背景色
@@ -676,6 +645,7 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 
 		// ラベル（重要度）
 		Label label = new Label(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "labelpriority", label);
 		GridData gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_PRIORITY;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -689,14 +659,14 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * メールの実行チェックボックスを返します。
-	 * 
+	 *
 	 * @param parent 親のコンポジット
 	 * @return 生成されたチェックボックス
 	 */
 	private Button getCheckMailNormal(Composite parent) {
-
 		// チェックボックス（実行）
 		Button button = new Button(parent, SWT.CHECK);
+		WidgetTestUtil.setTestId(this, null, button);
 		GridData gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_CHECK;
 		gridData.horizontalAlignment = GridData.CENTER;
@@ -708,14 +678,14 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * メールのメールアドレステキストボックスを返します。
-	 * 
+	 *
 	 * @param parent 親のインスタンス
 	 * @return 生成されたテキストボックス
 	 */
 	private Text getTextMailAddress(Composite parent) {
-
 		// テキスト（送信先（セミコロン区切り））
 		Text text = new Text(parent, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, null, text);
 		GridData gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_MAIL_ADDRESS;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -725,10 +695,14 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 		return text;
 	}
 
-	@Override
-	public void setOwnerRoleId(String ownerRoleId) {
-		super.setOwnerRoleId(ownerRoleId);
-		this.m_compositeMailTemplateIdList.update(ownerRoleId);
+	private void setInputListeners(){
+		if( !this.updateFlg ){
+			m_notifyBasic.getManagerListComposite().addModifyListener(new ModifyListener(){
+				@Override
+				public void modifyText(ModifyEvent e) {
+					// TODO Reload role ID list -> reload calendar list, mail template list
+				}
+			});
+		}
 	}
-
-}
\ No newline at end of file
+}
