@@ -79,4 +79,12 @@ public class MonitorStatusEntity implements Serializable {
 		return String.format("%s [id = %s, counter = %d, lastUpdate = %s, priority = %d]", 
 				MonitorStatusEntity.class.getSimpleName(), id, counter, lastUpdate, priority);
 	};
+	
+	public MonitorStatusEntity clone() {
+		MonitorStatusEntity entity = new MonitorStatusEntity(id.getFacilityId(), id.getPluginId(), id.getMonitorId(), id.getSubKey());
+		entity.counter = this.counter;
+		entity.lastUpdate = this.lastUpdate;
+		entity.priority = this.priority;
+		return entity;
+	}
 }
\ No newline at end of file
