@@ -18,6 +18,8 @@ package com.clustercontrol.notify.session;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.List;
+import java.util.Map;
+import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
 
 import org.apache.commons.logging.Log;
@@ -864,6 +866,19 @@ public class NotifyControllerBean implements CheckFacility {
 		}
 		return lockObject;
 	}
+	
+	// ジョブは実行ごとにキャッシュができるためそれを消すための機構
+	public static void removeCache(String pluginId, Map<String, String> monitorMap) {
+		synchronized (m_keyMap) {
+			Set<MonitorStatusPK> keySet = m_keyMap.keySet();
+			for (MonitorStatusPK key : keySet) {
+				if (key.getPluginId().equals(pluginId) && monitorMap.containsKey(key.getMonitorId())) {
+					m_keyMap.remove(key);
+				}
+			}
+		}
+		return;
+	}
 
 	/**
 	 * 外部から直接通知処理を実行します。
