@@ -19,6 +19,7 @@ import org.eclipse.ui.IFolderLayout;
 import org.eclipse.ui.IPageLayout;
 
 import com.clustercontrol.ClusterControlPerspectiveBase;
+import com.clustercontrol.performance.view.PerformanceGraphView;
 
 /**
  * 性能管理のパースペクティブを生成するクラス
@@ -39,13 +40,10 @@ public class PerformancePerspective extends ClusterControlPerspectiveBase {
 		String editorArea = layout.getEditorArea();
 		float percent = 0.35f;
 		// エディタ領域の上部percent％を占めるフォルダを作成
-		IFolderLayout top = layout.createFolder("top",
-				IPageLayout.TOP, percent, editorArea);
+		IFolderLayout top = layout.createFolder( "top", IPageLayout.TOP, percent, editorArea );
 		// エディタ領域の下部(1-percent)％を占めるフォルダの作成
-		IFolderLayout bottom = layout.createFolder("bottom",
-				IPageLayout.BOTTOM, (1-percent), editorArea);
+		layout.createFolder( "bottom", IPageLayout.BOTTOM, (IPageLayout.RATIO_MAX-percent), editorArea).addPlaceholder( PerformanceGraphView.ID );
 
 		top.addView(com.clustercontrol.performance.view.PerformanceListView.ID);
-
 	}
-}
\ No newline at end of file
+}
