@@ -15,28 +15,22 @@ GNU General Public License for more details.
 
 package com.clustercontrol.performance.bean;
 
-import java.lang.Double;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
 import java.util.List;
 
-import javax.ejb.FinderException;
-import javax.naming.InitialContext;
-import javax.naming.NamingException;
-import javax.rmi.PortableRemoteObject;
 import javax.xml.bind.annotation.XmlType;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.bean.HinemosModuleConstant;
-import com.clustercontrol.fault.FacilityNotFound;
 import com.clustercontrol.performance.util.CalculationMethod;
 import com.clustercontrol.performance.util.CollectorMasterCache;
+import com.clustercontrol.plugin.impl.SharedTablePlugin;
 import com.clustercontrol.poller.NotInitializedException;
 import com.clustercontrol.repository.bean.NodeDeviceInfo;
-import com.clustercontrol.repository.factory.NodeProperty;
 import com.clustercontrol.sharedtable.DataTable;
 import com.clustercontrol.sharedtable.DataTableNotFoundException;
 import com.clustercontrol.sharedtable.SharedTable;
@@ -53,7 +47,6 @@ import com.clustercontrol.sharedtable.SharedTable;
 public class Node extends Facility {
 	private static final long serialVersionUID = -5989756829710363991L;
 
-	private final static String SHARED_TABLE_JNDI_NAME = "SharedTable";
 	//	ログ出力
 	private static Log m_log = LogFactory.getLog( Node.class );
 
@@ -61,13 +54,6 @@ public class Node extends Facility {
 
 	private static SharedTable _sharedTable = null;
 
-	/**
-	 * HashMap<monitorId, HashMap<facilityId, lastCollectTime>>
-	 * 監視ID/ファシリティIDに対する、最新の収集時刻を記録するマップ
-	 * 
-	 */
-	private static HashMap<String, HashMap<String, Long>> lastCollectTimeMap= null;
-
 	/**
 	 * キー ： デバイス種別
 	 * 値　　：　デバイス情報のリスト
@@ -93,21 +79,9 @@ public class Node extends Facility {
 			final List<? extends NodeDeviceInfo> deviceInfoList){
 		super(facilityId, faclityName, Facility.NODE);
 
-		String virtType = "";
-		try {
-			virtType = NodeProperty.getProperty(facilityId).getVirtualizationNodeType();
-		} catch (FacilityNotFound e) {
-			m_log.warn("FacilityNotFound " + e.getMessage());
-		}
-		if("controller".equals(virtType)){
-			this.subPlatformId ="";
-		}
-		else{
-			this.subPlatformId = subPlatformId;
-		}
-		m_log.debug("create Node " + facilityId + ", " + faclityName + ", " + platformId + ", " + subPlatformId);
-
 		this.platformId = platformId;
+		this.subPlatformId = subPlatformId;
+		m_log.debug("Node() : create Node " + facilityId + ", " + faclityName + ", " + this.platformId + ", " + this.subPlatformId);
 
 		m_deviceMap = new HashMap<String, HashMap<String, NodeDeviceInfo>>();
 
@@ -139,14 +113,7 @@ public class Node extends Facility {
 				return;
 			}
 
-			try {
-				// テーブル生成
-				InitialContext ctx = new InitialContext();
-				Object obj = ctx.lookup(SHARED_TABLE_JNDI_NAME);
-				_sharedTable = (SharedTable)PortableRemoteObject.narrow(obj, SharedTable.class);
-			} catch (NamingException e) {
-				m_log.error(e.getMessage(), e);
-			}
+			_sharedTable = SharedTablePlugin.getSharedTable();
 		}
 	}
 
@@ -162,43 +129,37 @@ public class Node extends Facility {
 	public double calcValue(final CollectorItemInfo itemInfo) throws NotInitializedException{
 		NodeDeviceInfo deviceData = null;
 
-		try {
-			// 収集項目から利用されるデバイス種別を特定
-			String deviceType = CollectorMasterCache.getDeviceType(itemInfo.getItemCode());
+		// 収集項目から利用されるデバイス種別を特定
+		String deviceType = CollectorMasterCache.getDeviceType(itemInfo.getItemCode());
+
+		// デバッグ出力
+		m_log.debug("DeviceType : " + deviceType);
+
+		if(deviceType != null && !"".equals(deviceType)){
+			HashMap<String, NodeDeviceInfo> deviceTypeMap = m_deviceMap.get(deviceType);
 
 			// デバッグ出力
-			m_log.debug("DeviceType : " + deviceType);
-
-			if(deviceType != null && !"".equals(deviceType)){
-				HashMap<String, NodeDeviceInfo> deviceTypeMap = m_deviceMap.get(deviceType);
-
-				// デバッグ出力
-				if(m_log.isDebugEnabled()){
-					Iterator<String> itr = deviceTypeMap.keySet().iterator();
-					while(itr.hasNext()){
-						String key = itr.next();
-						m_log.debug(deviceTypeMap.get(key));
-					}
-				}
-
-				if(deviceTypeMap != null){
-					deviceData = deviceTypeMap.get(itemInfo.getDisplayName());
+			if(m_log.isDebugEnabled()){
+				Iterator<String> itr = deviceTypeMap.keySet().iterator();
+				while(itr.hasNext()){
+					String key = itr.next();
+					m_log.debug(deviceTypeMap.get(key));
 				}
 			}
-		} catch (FinderException e) {
-			m_log.error(e.getMessage(), e);
-			return Double.NaN;
-		} catch (NamingException e) {
-			m_log.error(e.getMessage(), e);
-			return Double.NaN;
+
+			if(deviceTypeMap != null){
+				deviceData = deviceTypeMap.get(itemInfo.getDisplayName());
+			}
 		}
 
 		double value = Double.NaN;
 		if(currentTable != null && previousTable != null){
 			value = CalculationMethod.getPerformance(platformId, subPlatformId, itemInfo, deviceData, currentTable, previousTable);
 		} else {
-			m_log.debug("currentTable = null and previousTable = null");
-			throw new NotInitializedException("fetch error.");
+			NotInitializedException e = new NotInitializedException("fetch error.");
+			m_log.info("calcValue() currentTable = null and previousTable = null : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage());
+			throw e;
 		}
 
 		m_log.debug("calcValue() : " + getFacilityId() + " " +
@@ -227,15 +188,14 @@ public class Node extends Facility {
 
 		boolean success = false;
 		try{
-			long collectTime = fetchMibValue(monitorId);
-			if(isUpdate(monitorId, getFacilityId(), collectTime)){
-				success = true;
-			}
-			else{
-				success = false;
-			}
-
+			// 2枚のテーブル取得が可能か否か
+			fetchMibValue(monitorId);
+			success = true;
 		}catch (NotInitializedException e) {
+			// 2枚のテーブル取得がない場合にNotInitializedException発生。
+			m_log.debug("fetchSharedTable()", e);
+		}catch (DataTableNotFoundException e) {
+			// データテーブルがない場合にDataTableNotFoundException発生。
 			m_log.debug("fetchSharedTable()", e);
 		}
 		return success;
@@ -259,7 +219,7 @@ public class Node extends Facility {
 	 * @return 収集時刻（全てのノードで一致させるために最後に収集された値の収集時刻とする）
 	 * @throws NotInitializedException
 	 */
-	private long fetchMibValue(String monitorId) throws NotInitializedException {
+	private long fetchMibValue(String monitorId) throws NotInitializedException, DataTableNotFoundException {
 		m_log.debug("fetchMibValue() monitorId = " + monitorId);
 
 		try {
@@ -277,17 +237,18 @@ public class Node extends Facility {
 			this.lastCollectTime = currentTable.getLastModify();
 		} catch (DataTableNotFoundException e) {
 			String facilityId = getFacilityId();
-			m_log.warn("create table : " + " monitorId = " + monitorId + ", facilityId = " + facilityId);
+			m_log.debug("create table : " + " monitorId = " + monitorId + ", facilityId = " + facilityId, e);
 
 			// テーブルが存在しない場合は生成する
 			_sharedTable = null;
 			currentTable = null;
 			previousTable = null;
 			initialize();
+			throw e;
 		} catch (NotInitializedException e) {
 			// 2回分のポーリングが実行できていない場合
 			String facilityId = getFacilityId();
-			m_log.info(e.getMessage() + " monitorId = " + monitorId + ", facilityId = " + facilityId);
+			m_log.debug(e.getMessage() + " monitorId = " + monitorId + ", facilityId = " + facilityId);
 			_sharedTable = null;
 			currentTable = null;
 			previousTable = null;
@@ -311,75 +272,7 @@ public class Node extends Facility {
 	 * 自分自身をカウントして返す。
 	 */
 	@Override
-	public int getNodeCount(){
+	protected int getNodeCount(){
 		return 1;
 	}
-
-
-	/**
-	 * 監視IDとファシリティIDが指定されたときに、
-	 * それに該当するリソース監視のsharedTableの最新収集時刻が更新されているかを判定する
-	 * 
-	 * @param monitorId 監視ID
-	 * @param facilityId ファシリティID
-	 * @return
-	 */
-	private synchronized static boolean isUpdate(String monitorId, String facilityId, long collectTime){
-		m_log.debug("isUpdate() monitorId = " + monitorId + ", facilityId = " + facilityId + ", collectTime = " + collectTime);
-		// Mapが存在しなければ初期化
-		if(lastCollectTimeMap == null){
-			m_log.debug("isUpdate() new lastCollectTimeMap");
-			lastCollectTimeMap = new HashMap<String, HashMap<String,Long>>();
-		}
-
-		// monitorIdの情報があるか?
-		HashMap<String, Long> facilityCollectTimeMap = lastCollectTimeMap.get(monitorId);
-		if(facilityCollectTimeMap == null){
-			// ない場合は、今回が初回として現在値を設定してtrue返却
-			m_log.debug("isUpdate() new facilityCollectTimeMap");
-			facilityCollectTimeMap = new HashMap<String, Long>();
-			facilityCollectTimeMap.put(facilityId, new Long(collectTime));
-
-			lastCollectTimeMap.put(monitorId, facilityCollectTimeMap);
-			return false;
-		}
-
-		// facilityIdの情報があるか?
-		Long lastCollectTime = facilityCollectTimeMap.get(facilityId);
-		if(lastCollectTime == null){
-			// ない場合は、今回が初回として現在値を設定する
-			m_log.debug("isUpdate() new lastCollectTime");
-			lastCollectTime = new Long(collectTime);
-
-			facilityCollectTimeMap.put(facilityId, lastCollectTime);
-			return false;
-		}
-
-		// 最終収集時刻より新しいか
-		if(collectTime > lastCollectTime.longValue()){
-			m_log.debug("isUpdate() update lastCollectTime = " + lastCollectTime.longValue());
-			lastCollectTime = new Long(collectTime);
-			facilityCollectTimeMap.put(facilityId, lastCollectTime);
-			return true;
-		}else{
-			m_log.debug("isUpdate() not update lastCollectTime = " + lastCollectTime.longValue());
-			return false;
-		}
-	}
-	
-	/**
-	 * Mapのクリア
-	 * @param monitorId
-	 */
-	public synchronized static void clearMap(String monitorId){
-		m_log.debug("clearMap() monitorId = " + monitorId);
-		
-		if(lastCollectTimeMap == null){
-			try{
-				lastCollectTimeMap.remove(monitorId);
-			} catch (Exception e) {
-				m_log.debug("clearMap()", e);
-			}
-		}
-	}
 }
