@@ -15,19 +15,19 @@ GNU General Public License for more details.
 
 package com.clustercontrol.performance.monitor.factory;
 
-import javax.ejb.CreateException;
-import javax.ejb.FinderException;
-import javax.naming.NamingException;
-
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
-import com.clustercontrol.commons.scheduler.TriggerScheduler;
+import com.clustercontrol.fault.HinemosUnknown;
+import com.clustercontrol.fault.InvalidRole;
+import com.clustercontrol.fault.MonitorNotFound;
 import com.clustercontrol.monitor.run.factory.ModifyMonitorNumericValueType;
+import com.clustercontrol.monitor.run.model.MonitorInfoEntity;
 import com.clustercontrol.performance.monitor.bean.PerfCheckInfo;
-import com.clustercontrol.performance.monitor.ejb.entity.MonitorPerfInfoLocal;
-import com.clustercontrol.performance.monitor.ejb.entity.MonitorPerfInfoUtil;
+import com.clustercontrol.performance.monitor.model.MonitorPerfInfoEntity;
+import com.clustercontrol.performance.monitor.util.QueryUtil;
 import com.clustercontrol.performance.util.PerformanceProperties;
+import com.clustercontrol.plugin.impl.SchedulerPlugin.TriggerType;
 
 /**
  * リソース監視情報更新クラス
@@ -44,17 +44,21 @@ public class ModifyMonitorPerformance extends ModifyMonitorNumericValueType{
 	 * @see com.clustercontrol.monitor.run.factory.ModifyMonitor#modifyCheckInfo()
 	 */
 	@Override
-	protected boolean modifyCheckInfo() throws CreateException, FinderException, NamingException {
+	protected boolean modifyCheckInfo() throws MonitorNotFound, HinemosUnknown, InvalidRole {
 		m_log.debug("modifyCheckInfo() monitorId = " + m_monitorInfo.getMonitorId());
 
+		MonitorInfoEntity monitorEntity
+		= com.clustercontrol.monitor.run.util.QueryUtil.getMonitorInfoPK(m_monitorInfo.getMonitorId());
+
 		// 閾値監視情報を取得
-		MonitorPerfInfoLocal perfLocal = MonitorPerfInfoUtil.getLocalHome().findByPrimaryKey(m_monitorInfo.getMonitorId());
+		MonitorPerfInfoEntity entity = QueryUtil.getMonitorPerfInfoPK(m_monitorInfo.getMonitorId());
 		PerfCheckInfo perfCheck = m_monitorInfo.getPerfCheckInfo();
 
 		// 閾値監視情報を設定
-		perfLocal.setItemCode(perfCheck.getItemCode());
-		perfLocal.setDeviceDisplayName(perfCheck.getDeviceDisplayName());
-		perfLocal.setBreakdownFlg(perfCheck.getBreakdownFlg());
+		entity.setItemCode(perfCheck.getItemCode());
+		entity.setDeviceDisplayName(perfCheck.getDeviceDisplayName());
+		entity.setBreakdownFlg(perfCheck.getBreakdownFlg());
+		monitorEntity.setMonitorPerfInfoEntity(entity);
 
 		boolean result = true;
 
@@ -90,7 +94,7 @@ public class ModifyMonitorPerformance extends ModifyMonitorNumericValueType{
 	 * スケジュール実行種別を返します。
 	 */
 	@Override
-	protected String getTriggerType() {
-		return TriggerScheduler.TRIGGER_TYPE_CRON;
+	protected TriggerType getTriggerType() {
+		return TriggerType.CRON;
 	}
 }
