@@ -29,7 +29,10 @@ import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.bean.SnmpVersionConstant;
+import com.clustercontrol.commons.util.AbstractCacheManager;
+import com.clustercontrol.commons.util.CacheManagerFactory;
 import com.clustercontrol.commons.util.EmptyJpaTransactionCallback;
+import com.clustercontrol.commons.util.ICacheManager;
 import com.clustercontrol.commons.util.JpaTransactionManager;
 import com.clustercontrol.commons.util.ObjectSharingService;
 import com.clustercontrol.fault.FacilityNotFound;
@@ -401,6 +404,14 @@ public class PollingController implements Serializable {
 			// ポーリングは実行しない
 			// 取得値が空のテーブルを作成する
 			dataTable = new DataTable();
+			// 管理対象フラグがOFFの場合、ポーリング処理直後に管理対象フラグがONになった場合に
+			// 5.0.0までの実装では集計処理側で単純に「集計タイミングでの」管理対象フラグを見て、
+			// 結果として上でセットした空のデータを読んでしまうことで、不明となることへの対策。
+			// 
+			// 「管理対象フラグがOFFの状態で最後にポーリングの処理を通過した時間」をノード単位で記録しておくことで、
+			// 集計処理時にもしも「不明」となった場合には、ここでセットした時間と監視間隔をもとに、
+			// 通知をスキップするか否かを決定する。
+			setLastPollingSkipTime(nodeInfo.getFacilityId());
 		}
 
 		// ポーリングを行い値を収集
@@ -610,4 +621,136 @@ public class PollingController implements Serializable {
 	public int getStatus() {
 		return m_status;
 	}
+	
+	
+	/**
+	 * 指定されたノードの管理対象フラグの直近の状態を見て、リソース監視による通知をスキップすべきか否かを判定します。
+	 * @param facilityId 対象となるノードのfacilityId
+	 * @param interval 対象となる監視項目の監視間隔
+	 * @return リソース監視を行うために十分な時間、管理対象フラグが有効になっていなかった場合、trueが返る
+	 */
+	public static boolean skipResourceMonitorNotifyByNodeFlagHistory(String facilityId, int interval) {
+		long currentTime = System.currentTimeMillis();
+		long lastPollingSkipTime = getLastPollingSkipTime(facilityId);
+		if (currentTime - lastPollingSkipTime < interval * 1000 * 2 /* 2回分 */) {
+			// 管理対象フラグをOFFとしていた期間が、監視間隔 * 2 よりも直近で存在している、あるいは
+			// 直近でマネージャを再起動したなどの状態にあたるため、通知をスキップ
+			m_log.info("skipResourceMonitorNotifyByNodeFlagHistory() : skip resource monitor notify because of node flag change timing. "
+					+ "facilityId = " + facilityId + ", currentTime = " + currentTime + ", lastPollingSkipTime = " + lastPollingSkipTime);
+			return true;
+		}
+		// 管理対象フラグがOFFだった期間がかなり昔 or そのノードについて何の情報も登録されていない状態
+		// なので、通知はスキップしない
+		return false;
+	}
+	
+	/**
+	 * 指定されたノードの管理対象フラグの直近の状態を見て、プロセス監視による通知をスキップすべきか否かを判定します。
+	 * 監視結果が「不明」となった場合以外には本関数は呼び出さないでください。
+	 * @param facilityId 対象となるノードのfacilityId
+	 * @param interval 対象となる監視項目の監視間隔
+	 * @return 通知をスキップすべき状況（プロセス監視を行うために十分な時間、管理対象フラグが有効になっていなかったなど）の場合、trueが返る。<br>
+	 * 通知をスキップするべきでなければ、falseが返る。
+	 */
+	public static boolean skipProcessMonitorNotifyByNodeFlagHistory(String facilityId, int interval) {
+		long currentTime = System.currentTimeMillis();
+		long lastPollingSkipTime = getLastPollingSkipTime(facilityId);
+		if (currentTime - lastPollingSkipTime < interval * 1000 ) {
+			// 管理対象フラグをOFFとしていた期間が、監視間隔よりも直近で存在している、あるいは
+			// 直近でマネージャを再起動したなどの状態にあたるため、通知をスキップ
+			m_log.info("skipProcessMonitorNotifyByNodeFlagHistory() : skip process monitor notify because of node flag change timing. "
+					+ "facilityId = " + facilityId + ", currentTime = " + currentTime + ", lastPollingSkipTime = " + lastPollingSkipTime);
+			return true;
+		}
+		// 管理対象フラグがOFFだった期間がかなり昔 or そのノードについて何の情報も登録されていない状態
+		// なので、通知はスキップしない
+		return false;
+	}
+	
+	/**
+	 * 最も直近に管理対象フラグがたっていなかったことによりポーリングがスキップされた時間を返す。
+	 * @param facilityId
+	 * @return
+	 */
+	public static long getLastPollingSkipTime(String facilityId) {
+		HashMap<String, Long> lastPollingDisableTimeMap = getLastPollingSkipTimeMap();
+		Long lastPollingDisableTime = lastPollingDisableTimeMap.get(facilityId);
+		
+		if (lastPollingDisableTime != null) {
+			return lastPollingDisableTime;
+		} else { 
+			// キャッシュそのものが存在しない、キャッシュが異常、またはキャッシュ中にそのファシリティIDの情報が格納されていない場合、
+			// 従来通り、不明が出ても何の抑制もしないように、遠い過去(0L)を返す = 遥か昔の時点から管理対象がONであったことを示す 
+			return 0L;
+		}
+	}
+	
+	/**
+	 * 指定されたノードのポーリング処理を「管理対象フラグが立っていないこと」を理由にスキップした場合に呼び出す。<br>
+	 * （呼び出しにより、このファシリティIDのポーリングが最後にスキップされた時刻として現在時刻がセットされる）
+	 * @param facilityId 対象となるfacilityId
+	 */
+	public static void setLastPollingSkipTime(String facilityId) {
+		// キャッシュされたmapそのものをいじって再度キャッシュ機構に格納するため、
+		// 変更途中でのレースを防ぐ必要があり、synchronizedする
+		synchronized (AbstractCacheManager.KEY_POLLING_SKIP_TIME) {
+			HashMap<String, Long> lastPollingSkipTimeMap = getLastPollingSkipTimeMap();
+			
+			// mapに当該ファシリティIDをキーとして、現在時刻をセット
+			lastPollingSkipTimeMap.put(facilityId, System.currentTimeMillis());
+			
+			// キャッシュを再度キャッシュマネージャに格納
+			// （キャッシュマネージャから取り出したキャッシュは参照ではなくコピーなので、storeは省略不可）
+			ICacheManager cm = CacheManagerFactory.instance().create();
+			cm.store(AbstractCacheManager.KEY_POLLING_SKIP_TIME, lastPollingSkipTimeMap);
+			
+			if (m_log.isDebugEnabled()) {
+				m_log.debug("setLastPollingSkipTime() : current map size = " + lastPollingSkipTimeMap.size());
+				m_log.debug("setLastPollingSkipTime() : current map entry = " + lastPollingSkipTimeMap.entrySet());
+			}
+		}
+	}
+	
+	/**
+	 * 指定されたノードのポーリング処理の最終スキップ時刻の情報をリセットする。
+	 * 本関数は、ノードが削除された際に呼び出す。
+	 * @param facilityId 削除対象のfacilityId
+	 */
+	public static void removeLastPollingSkipTime(String facilityId) {
+		// キャッシュされたmapそのものをいじって再度キャッシュ機構に格納するため、
+		// 変更途中でのレースを防ぐ必要があり、synchronizedする
+		synchronized (AbstractCacheManager.KEY_POLLING_SKIP_TIME) {
+			HashMap<String, Long> lastPollingSkipTimeMap = getLastPollingSkipTimeMap();
+			
+			// mapに当該ファシリティの情報がある場合には削除する
+			lastPollingSkipTimeMap.remove(facilityId);
+			
+			// キャッシュを再度キャッシュマネージャに格納
+			// （キャッシュマネージャから取り出したキャッシュは参照ではなくコピーなので、storeは省略不可）
+			ICacheManager cm = CacheManagerFactory.instance().create();
+			cm.store(AbstractCacheManager.KEY_POLLING_SKIP_TIME, lastPollingSkipTimeMap);
+			
+			if (m_log.isDebugEnabled()) {
+				m_log.debug("setLastPollingSkipTime() : current map size = " + lastPollingSkipTimeMap.size());
+				m_log.debug("setLastPollingSkipTime() : current map entry = " + lastPollingSkipTimeMap.entrySet());
+			}
+		}
+	}
+	
+	/**
+	 * キャッシュ化されたポーリング最終スキップ時刻のmapを取得する。キャッシュ済みのmapがない場合は新規作成された空のマップが返る
+	 */
+	@SuppressWarnings("unchecked")
+	private static HashMap<String, Long> getLastPollingSkipTimeMap() {
+		ICacheManager cm = CacheManagerFactory.instance().create();
+		Serializable cache = cm.get(AbstractCacheManager.KEY_POLLING_SKIP_TIME);
+		if (cache != null) {
+			try {
+				return (HashMap<String, Long>)cache;
+			} catch (ClassCastException e) {
+				m_log.warn("getLastPollingDisableTimeMap() : can't cast cache to hashmap. (cache class = " + cache.getClass() + ")", e);
+			}
+		}
+		return new HashMap<String, Long>();
+	}
 }
