@@ -33,11 +33,11 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
 
+import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.bean.RequiredFieldColorConstant;
 import com.clustercontrol.monitor.run.dialog.CommonMonitorNumericDialog;
 import com.clustercontrol.monitor.util.MonitorSettingEndpointWrapper;
-import com.clustercontrol.notify.util.NotifyGroupIdGenerator;
 import com.clustercontrol.port.bean.PortRunCountConstant;
 import com.clustercontrol.port.bean.PortRunIntervalConstant;
 import com.clustercontrol.port.bean.ProtocolConstant;
@@ -49,7 +49,7 @@ import com.clustercontrol.ws.monitor.PortCheckInfo;
 
 /**
  * サービス･ポート監視作成・変更ダイアログクラスです。
- * 
+ *
  * @version 4.0.0
  * @since 2.4.0
  */
@@ -75,36 +75,36 @@ public class PortCreateDialog extends CommonMonitorNumericDialog {
 	private Text m_textPortNo = null;
 
 	/** 実行回数 */
-	private Combo m_comboRunCount = null;
+	private Text m_textRunCount = null;
 
 	/** 実行間隔（秒） */
-	private Combo m_comboRunInterval = null;
+	private Text m_textRunInterval = null;
 
 	// ----- コンストラクタ ----- //
 
 	/**
 	 * 作成用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent
 	 *            親のシェルオブジェクト
 	 */
 	public PortCreateDialog(Shell parent) {
-		super(parent);
+		super(parent, null);
 	}
 
 	/**
 	 * 変更用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent
 	 *            親のシェルオブジェクト
 	 * @param notifyId
 	 *            変更する通知ID
 	 * @param updateFlg
 	 *            更新するか否か（true:変更、false:新規登録）
-	 * 
+	 *
 	 */
-	public PortCreateDialog(Shell parent, String monitorId, boolean updateFlg) {
-		super(parent);
+	public PortCreateDialog(Shell parent, String managerName, String monitorId, boolean updateFlg) {
+		super(parent, managerName);
 
 		this.monitorId = monitorId;
 		this.updateFlg = updateFlg;
@@ -114,7 +114,7 @@ public class PortCreateDialog extends CommonMonitorNumericDialog {
 
 	/**
 	 * ダイアログエリアを生成します。
-	 * 
+	 *
 	 * @param parent
 	 *            親のインスタンス
 	 */
@@ -139,13 +139,14 @@ public class PortCreateDialog extends CommonMonitorNumericDialog {
 		 * チェック設定グループ（条件グループの子グループ）
 		 */
 		Group groupCheckRule = new Group(groupRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "checkrule", groupCheckRule);
 		GridLayout layout = new GridLayout(1, true);
-		layout.marginWidth = 5;
-		layout.marginHeight = 5;
-		layout.numColumns = 15;
+		layout.marginWidth = HALF_MARGIN;
+		layout.marginHeight = HALF_MARGIN;
+		layout.numColumns = BASIC_UNIT;
 		groupCheckRule.setLayout(layout);
 		gridData = new GridData();
-		gridData.horizontalSpan = 15;
+		gridData.horizontalSpan = BASIC_UNIT;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		groupCheckRule.setLayoutData(gridData);
@@ -156,8 +157,9 @@ public class PortCreateDialog extends CommonMonitorNumericDialog {
 		 */
 		// TCP接続のみ
 		this.m_radioTCP = new Button(groupCheckRule, SWT.RADIO);
+		WidgetTestUtil.setTestId(this, "tcp", m_radioTCP);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_TITLE;
+		gridData.horizontalSpan = WIDTH_TITLE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.m_radioTCP.setLayoutData(gridData);
@@ -166,8 +168,9 @@ public class PortCreateDialog extends CommonMonitorNumericDialog {
 
 		// サービス
 		this.m_radioService = new Button(groupCheckRule, SWT.RADIO);
+		WidgetTestUtil.setTestId(this, "service", m_radioService);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_TITLE;
+		gridData.horizontalSpan = WIDTH_TITLE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.m_radioService.setLayoutData(gridData);
@@ -181,8 +184,9 @@ public class PortCreateDialog extends CommonMonitorNumericDialog {
 
 		//コンボボックス
 		this.m_comboService = new Combo(groupCheckRule, SWT.DROP_DOWN | SWT.READ_ONLY);
+		WidgetTestUtil.setTestId(this, "service", m_comboService);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_VALUE;
+		gridData.horizontalSpan = WIDTH_VALUE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.m_comboService.setLayoutData(gridData);
@@ -199,8 +203,9 @@ public class PortCreateDialog extends CommonMonitorNumericDialog {
 
 		//空白
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space1", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = 4;
+		gridData.horizontalSpan = WIDTH_TEXT;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
@@ -210,16 +215,18 @@ public class PortCreateDialog extends CommonMonitorNumericDialog {
 		 */
 		// ラベル
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "portnumber", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_TITLE;
+		gridData.horizontalSpan = WIDTH_TITLE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
 		label.setText(Messages.getString("port.number") + " : ");
 		// テキスト
 		this.m_textPortNo = new Text(groupCheckRule, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, "protno", m_textPortNo);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_VALUE;
+		gridData.horizontalSpan = WIDTH_VALUE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.m_textPortNo.setLayoutData(gridData);
@@ -232,8 +239,9 @@ public class PortCreateDialog extends CommonMonitorNumericDialog {
 
 		// 空白
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space2", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = 9;
+		gridData.horizontalSpan = HALF_UNIT - (WIDTH_TITLE_LONG + WIDTH_VALUE_LONG);
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
@@ -241,70 +249,104 @@ public class PortCreateDialog extends CommonMonitorNumericDialog {
 		/*
 		 * 実行回数
 		 */
+		//空白
+		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space3", label);
+		gridData = new GridData();
+		gridData.horizontalSpan = MIN_UNIT;
+		gridData.horizontalAlignment = GridData.FILL;
+		gridData.grabExcessHorizontalSpace = true;
+		label.setLayoutData(gridData);
+
 		// ラベル
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "labelruncount", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_TITLE;
+		gridData.horizontalSpan = WIDTH_TITLE + MIN_UNIT;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
 		label.setText(Messages.getString("trial.run.count") + " : ");
-		// コンボボックス
-		this.m_comboRunCount = new Combo(groupCheckRule, SWT.DROP_DOWN | SWT.READ_ONLY);
+
+		// テキスト
+		this.m_textRunCount = new Text(groupCheckRule, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, "textruncount", m_textRunCount);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_VALUE;
+		gridData.horizontalSpan = WIDTH_VALUE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
-		this.m_comboRunCount.setLayoutData(gridData);
-		this.m_comboRunCount.add(PortRunCountConstant.STRING_COUNT_01);
-		this.m_comboRunCount.add(PortRunCountConstant.STRING_COUNT_02);
-		this.m_comboRunCount.add(PortRunCountConstant.STRING_COUNT_03);
+		this.m_textRunCount.setLayoutData(gridData);
+		this.m_textRunCount.addModifyListener(new ModifyListener(){
+			@Override
+			public void modifyText(ModifyEvent arg0) {
+				update();
+			}
+		});
 
-		// 空白
+		// 単位
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "labelcount", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = 9;
+		gridData.horizontalSpan = HALF_UNIT - (WIDTH_TITLE + WIDTH_VALUE + WIDTH_VALUE_LONG);
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
+		label.setText(Messages.getString("count"));
 
 		/*
 		 * 実行間隔
 		 */
 		// ラベル
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "trialruninterval", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_TITLE;
+		gridData.horizontalSpan = WIDTH_TITLE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
 		label.setText(Messages.getString("trial.run.interval") + " : ");
-		// コンボボックス
-		this.m_comboRunInterval = new Combo(groupCheckRule, SWT.DROP_DOWN | SWT.READ_ONLY);
+
+		// テキスト
+		this.m_textRunInterval = new Text(groupCheckRule, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, "runinterval", m_textRunInterval);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_VALUE;
+		gridData.horizontalSpan = WIDTH_VALUE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
-		this.m_comboRunInterval.setLayoutData(gridData);
-		this.m_comboRunInterval.add(PortRunIntervalConstant.STRING_SEC_01);
-		this.m_comboRunInterval.add(PortRunIntervalConstant.STRING_SEC_02);
-		this.m_comboRunInterval.add(PortRunIntervalConstant.STRING_SEC_05);
+		this.m_textRunInterval.setLayoutData(gridData);
+		this.m_textRunInterval.addModifyListener(new ModifyListener(){
+			@Override
+			public void modifyText(ModifyEvent arg0) {
+				update();
+			}
+		});
 
-		// 空白
+		// 単位
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "labelmillisec1", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = 9;
+		gridData.horizontalSpan = HALF_UNIT - (WIDTH_TITLE_LONG + WIDTH_VALUE_LONG);
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
+		label.setText(Messages.getString("milli.sec"));
 
 		/*
 		 * タイムアウト
 		 */
+		//空白
+		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "spacetimeout", label);
+		gridData = new GridData();
+		gridData.horizontalSpan = MIN_UNIT;
+		gridData.horizontalAlignment = GridData.FILL;
+		gridData.grabExcessHorizontalSpace = true;
+		label.setLayoutData(gridData);
 		// ラベル
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "labeltimeout", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_TITLE;
+		gridData.horizontalSpan = WIDTH_TITLE + MIN_UNIT;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
@@ -312,8 +354,9 @@ public class PortCreateDialog extends CommonMonitorNumericDialog {
 
 		// テキスト
 		this.m_textTimeout = new Text(groupCheckRule, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, "timeout", m_textTimeout);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_VALUE;
+		gridData.horizontalSpan = WIDTH_VALUE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.m_textTimeout.setLayoutData(gridData);
@@ -326,21 +369,14 @@ public class PortCreateDialog extends CommonMonitorNumericDialog {
 
 		// ラベル（単位）
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "labelmillisec2", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_VALUE;
+		gridData.horizontalSpan = HALF_UNIT - (WIDTH_TITLE + WIDTH_VALUE + WIDTH_VALUE_LONG);
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
 		label.setText(Messages.getString("milli.sec"));
 
-		// 空白
-		label = new Label(groupCheckRule, SWT.NONE);
-		gridData = new GridData();
-		gridData.horizontalSpan = 7;
-		gridData.horizontalAlignment = GridData.FILL;
-		gridData.grabExcessHorizontalSpace = true;
-		label.setLayoutData(gridData);
-
 		// 収集値表示名のデフォルト値を設定
 		this.itemName.setText(Messages.getString("response.time"));
 
@@ -359,7 +395,8 @@ public class PortCreateDialog extends CommonMonitorNumericDialog {
 		} else {
 			// 変更の場合、情報取得
 			try {
-				info = MonitorSettingEndpointWrapper.getMonitor(monitorId, HinemosModuleConstant.MONITOR_PORT);
+				MonitorSettingEndpointWrapper wrapper = MonitorSettingEndpointWrapper.getWrapper(managerName);
+				info = wrapper.getMonitor(monitorId, HinemosModuleConstant.MONITOR_PORT);
 			} catch (InvalidRole_Exception e) {
 				// アクセス権なしの場合、エラーダイアログを表示する
 				MessageDialog.openInformation(
@@ -387,7 +424,7 @@ public class PortCreateDialog extends CommonMonitorNumericDialog {
 
 	/**
 	 * 更新処理
-	 * 
+	 *
 	 */
 	@Override
 	public void update(){
@@ -408,7 +445,7 @@ public class PortCreateDialog extends CommonMonitorNumericDialog {
 
 	/**
 	 * 各項目に入力値を設定します。
-	 * 
+	 *
 	 * @param monitor
 	 *            設定値として用いる通知情報
 	 */
@@ -434,10 +471,10 @@ public class PortCreateDialog extends CommonMonitorNumericDialog {
 			this.m_textPortNo.setText(portInfo.getPortNo().toString());
 		}
 		if (portInfo.getRunCount() != null) {
-			this.m_comboRunCount.setText(PortRunCountConstant.typeToString(portInfo.getRunCount().intValue()));
+			this.m_textRunCount.setText(portInfo.getRunCount().toString());
 		}
 		if (portInfo.getRunInterval() != null) {
-			this.m_comboRunInterval.setText(PortRunIntervalConstant.typeToString(portInfo.getRunInterval().intValue()));
+			this.m_textRunInterval.setText(portInfo.getRunInterval().toString());
 		}
 		// タイムアウト
 		if (portInfo.getTimeout() != null) {
@@ -450,7 +487,7 @@ public class PortCreateDialog extends CommonMonitorNumericDialog {
 
 	/**
 	 * 入力値を用いて通知情報を生成します。
-	 * 
+	 *
 	 * @return 入力値を保持した通知情報
 	 */
 	@Override
@@ -486,14 +523,30 @@ public class PortCreateDialog extends CommonMonitorNumericDialog {
 			}
 		}
 		/** 試行回数 */
-		if (this.m_comboRunCount.getText() != null
-				&& !"".equals((this.m_comboRunCount.getText()).trim())) {
-			portInfo.setRunCount(PortRunCountConstant.stringToType(this.m_comboRunCount.getText()));
+
+		if (!"".equals((this.m_textRunCount.getText()).trim())) {
+
+			try{
+				Integer runcount = new Integer(this.m_textRunCount.getText().trim());
+				portInfo.setRunCount(runcount);
+			}
+			catch(NumberFormatException e){
+				this.setValidateResult(Messages.getString("message.hinemos.1"),Messages.getString("message.port.1"));
+				return null;
+			}
 		}
 		/** 試行間隔 */
-		if (this.m_comboRunInterval.getText() != null
-				&& !"".equals((this.m_comboRunInterval.getText()).trim())) {
-			portInfo.setRunInterval(PortRunIntervalConstant.stringToType(this.m_comboRunInterval.getText()));
+
+		if (!"".equals((this.m_textRunInterval.getText()).trim())) {
+
+			try{
+				Integer runinterval = new Integer(this.m_textRunInterval.getText().trim());
+				portInfo.setRunInterval(runinterval);
+			}
+			catch(NumberFormatException e){
+				this.setValidateResult(Messages.getString("message.hinemos.1"),Messages.getString("message.port.2"));
+				return null;
+			}
 		}
 		/** タイムアウト */
 		if (!"".equals((this.m_textTimeout.getText()).trim())) {
@@ -517,8 +570,6 @@ public class PortCreateDialog extends CommonMonitorNumericDialog {
 		}
 
 		// 通知関連情報とアプリケーションの設定
-		// 通知グループIDの設定
-		monitorInfo.setNotifyGroupId(NotifyGroupIdGenerator.createNotifyGroupId(HinemosModuleConstant.MONITOR_PORT, monitorInfo.getMonitorId()));
 		validateResult = m_notifyInfo.createInputData(monitorInfo);
 		if (validateResult != null) {
 			if(validateResult.getID() == null){	// 通知ID警告用出力
@@ -537,9 +588,9 @@ public class PortCreateDialog extends CommonMonitorNumericDialog {
 
 	/**
 	 * 入力値をマネージャに登録します。
-	 * 
+	 *
 	 * @return true：正常、false：異常
-	 * 
+	 *
 	 * @see com.clustercontrol.dialog.CommonDialog#action()
 	 */
 	@Override
@@ -548,11 +599,12 @@ public class PortCreateDialog extends CommonMonitorNumericDialog {
 
 		MonitorInfo info = this.inputData;
 		if(info != null){
-			String[] args = { info.getMonitorId() };
+			String[] args = { info.getMonitorId(), getManagerName() };
+			MonitorSettingEndpointWrapper wrapper = MonitorSettingEndpointWrapper.getWrapper(getManagerName());
 			if(!this.updateFlg){
 				// 作成の場合
 				try {
-					result = MonitorSettingEndpointWrapper.addMonitor(info);
+					result = wrapper.addMonitor(info);
 
 					if(result){
 						MessageDialog.openInformation(
@@ -592,7 +644,7 @@ public class PortCreateDialog extends CommonMonitorNumericDialog {
 				// 変更の場合
 				String errMessage = "";
 				try {
-					result = MonitorSettingEndpointWrapper.modifyMonitor(info);
+					result = wrapper.modifyMonitor(info);
 				} catch (InvalidRole_Exception e) {
 					// アクセス権なしの場合、エラーダイアログを表示する
 					MessageDialog.openInformation(
@@ -622,7 +674,7 @@ public class PortCreateDialog extends CommonMonitorNumericDialog {
 
 	/**
 	 * MonitorInfoに初期値を設定します
-	 * 
+	 *
 	 * @see com.clustercontrol.dialog.CommonMonitorDialog#setInfoInitialValue()
 	 */
 	@Override
@@ -642,4 +694,4 @@ public class PortCreateDialog extends CommonMonitorNumericDialog {
 		monitor.setPortCheckInfo(portCheckInfo);
 	}
 
-}
\ No newline at end of file
+}
