@@ -20,6 +20,7 @@ import java.text.NumberFormat;
 import java.util.ArrayList;
 import java.util.Calendar;
 import java.util.Date;
+import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Set;
@@ -39,7 +40,9 @@ import com.clustercontrol.monitor.run.factory.RunMonitor;
 import com.clustercontrol.monitor.run.factory.RunMonitorNumericValueType;
 import com.clustercontrol.plugin.impl.SharedTablePlugin;
 import com.clustercontrol.poller.NotInitializedException;
+import com.clustercontrol.poller.PollerManager;
 import com.clustercontrol.poller.PollingController;
+import com.clustercontrol.poller.PollingControllerConfig;
 import com.clustercontrol.poller.bean.PollerProtocolConstant;
 import com.clustercontrol.process.entity.MonitorProcessPollingMstData;
 import com.clustercontrol.process.entity.MonitorProcessPollingMstPK;
@@ -208,6 +211,14 @@ public class RunMonitorProcess extends RunMonitorNumericValueType {
 							m_message = Messages.getString("message.process.6");
 							return false;
 						}
+						
+						// カレンダー非稼働後の初回の可能性があるため、ポーリングを発動する
+					 	m_log.info("try polling after rescheduling poller. (" + facilityId + ", " + m_monitorId + ")");
+					 	PollerManager manager = PollerManager.getInstnace();
+					 	PollingController poller = manager.getPoller(m_monitorTypeId, facilityId);
+					 	PollingControllerConfig config = poller.getPollingConfig();
+					 	HashMap<String, List<String>> pollingTargetMap = config.getCurrentTargetMap(System.currentTimeMillis());
+					 	table = poller.polling(pollingTargetMap, -1, -1);
 					} catch (DataTableNotFoundException e) {
 						// 異常終了（メッセージ：「値を取得できませんでした」）
 						m_message = Messages.getString("message.process.6");
