@@ -43,15 +43,15 @@ public class RepositoryPerspective extends ClusterControlPerspectiveBase {
 		//エディタ領域のIDを取得
 		String editorArea = layout.getEditorArea();
 
-		//エディタ領域の左部60%を占めるフォルダを作成
-		IFolderLayout left = layout.createFolder("left", IPageLayout.LEFT,
-				0.65f, editorArea);
-		//エディタ領域の右部40%を占めるフォルダを作成
-		IFolderLayout right = layout.createFolder("right", IPageLayout.RIGHT,
-				0.35f, editorArea);
+		float topLeftRatio = 0.65f;
+		float bottomRatio = 0.6f;
+
+		//エディタ領域の左部65%を占めるフォルダを作成
+		IFolderLayout left = layout.createFolder( "left", IPageLayout.LEFT, topLeftRatio, editorArea );
+		//エディタ領域の右部35%を占めるフォルダを作成
+		IFolderLayout right = layout.createFolder( "right", IPageLayout.RIGHT, IPageLayout.RATIO_MAX-topLeftRatio, editorArea );
 		//エディタ左領域の下部40%を占めるフォルダを作成
-		IFolderLayout bottom = layout.createFolder("bottom",
-				IPageLayout.BOTTOM, 0.6f, "left");
+		IFolderLayout bottom = layout.createFolder( "bottom", IPageLayout.BOTTOM, bottomRatio, "left" );
 
 		left.addView(NodeListView.ID);
 		left.addView(AgentListView.ID);
@@ -59,4 +59,4 @@ public class RepositoryPerspective extends ClusterControlPerspectiveBase {
 		bottom.addView(ScopeListView.ID);
 		bottom.addView(NodeScopeView.ID);
 	}
-}
\ No newline at end of file
+}
