@@ -25,32 +25,39 @@ import com.clustercontrol.util.Messages;
 
 /**
  * エージェント一覧テーブルの定義を取得するクライアント側アクションクラス<BR>
- * 
+ *
  * @version 1.0.0
  * @since 1.0.0
  */
 public class GetAgentListTableDefine {
 
+	/** Manager Name */
+	public static final int MANAGER_NAME = 0;
+
 	/** ファシリティID */
-	public static final int FACILITY_ID = 0;
+	public static final int FACILITY_ID = 1;
 
 	/** ファシリティ名 */
-	public static final int FACILITY_NAME = 1;
+	public static final int FACILITY_NAME = 2;
 
 	/** エージェント起動時刻 */
-	public static final int STARTUP_TIME = 2;
+	public static final int STARTUP_TIME = 3;
 
 	/** エージェント最終接続時刻 */
-	public static final int LAST_LOGIN = 3;
+	public static final int LAST_LOGIN = 4;
 
 	/** 多重度 */
-	public static final int MULTIPLICITY = 4;
+	public static final int MULTIPLICITY = 5;
 
 	/** new/old */
-	public static final int NEW_OLD = 5;
+	public static final int NEW_OLD = 6;
+
+	/** ダミー**/
+	public static final int DUMMY = 7;
 
 	/** 初期表示時ソートカラム */
-	public static final int SORT_COLUMN_INDEX = FACILITY_ID;
+	public static final int SORT_COLUMN_INDEX1 = MANAGER_NAME;
+	public static final int SORT_COLUMN_INDEX2 = FACILITY_ID;
 
 	/** 初期表示時ソートオーダー */
 	public static final int SORT_ORDER = 1;
@@ -60,7 +67,7 @@ public class GetAgentListTableDefine {
 
 	/**
 	 * 全てのノード一覧を取得します。
-	 * 
+	 *
 	 * @return ノード一覧
 	 */
 	public static ArrayList<TableColumnInfo> get() {
@@ -69,6 +76,9 @@ public class GetAgentListTableDefine {
 		Locale locale = Locale.getDefault();
 
 		/** メイン処理 */
+		// Manager Name
+		tableDefine.add(MANAGER_NAME,
+				new TableColumnInfo(Messages.getString("facility.manager", "Manager", locale), TableColumnInfo.MANAGER_NAME, 100, SWT.LEFT));
 		tableDefine.add(FACILITY_ID,
 				new TableColumnInfo(Messages.getString("facility.id", locale), TableColumnInfo.FACILITY_ID, 100, SWT.LEFT));
 		tableDefine.add(FACILITY_NAME,
@@ -81,7 +91,9 @@ public class GetAgentListTableDefine {
 				new TableColumnInfo(Messages.getString("job.multiplicity", locale), TableColumnInfo.NONE, 110, SWT.LEFT));
 		tableDefine.add(NEW_OLD,
 				new TableColumnInfo(Messages.getString("update.e", locale), TableColumnInfo.NONE, 90, SWT.LEFT));
+		tableDefine.add(DUMMY,
+				new TableColumnInfo("", TableColumnInfo.DUMMY, 200, SWT.LEFT));
 
 		return tableDefine;
 	}
-}
\ No newline at end of file
+}
