@@ -356,20 +356,32 @@ public class NodeInfoDeviceSearch implements Serializable
 			this.newNodeInfo = lastNode.clone();
 			//取得した情報で更新
 			if (equalsBasic == false) {
-				this.newNodeInfo.setPlatformFamily(this.nodeInfo.getPlatformFamily());
-				this.newNodeInfo.setSubPlatformFamily(this.nodeInfo.getSubPlatformFamily());
-				this.newNodeInfo.setHardwareType(this.nodeInfo.getHardwareType());
-				this.newNodeInfo.setIconImage(this.nodeInfo.getIconImage());
-				this.newNodeInfo.setIpAddressVersion(this.nodeInfo.getIpAddressVersion());
-				this.newNodeInfo.setIpAddressV4(this.nodeInfo.getIpAddressV4());
-				this.newNodeInfo.setIpAddressV6(this.nodeInfo.getIpAddressV6());
-				this.newNodeInfo.setNodeHostnameInfo(this.nodeInfo.getNodeHostnameInfo());
-				this.newNodeInfo.setNodeName(this.nodeInfo.getNodeName());
-				this.newNodeInfo.setOsName(this.nodeInfo.getOsName());
-				this.newNodeInfo.setOsRelease(this.nodeInfo.getOsRelease());
-				this.newNodeInfo.setOsVersion(this.nodeInfo.getOsVersion());
-				this.newNodeInfo.setCharacterSet(this.nodeInfo.getCharacterSet());
-				this.newNodeInfo.setAgentAwakePort(this.nodeInfo.getAgentAwakePort());
+				// サーバ基本情報->ハードウェア
+				if (HinemosPropertyUtil.getHinemosPropertyBool("repository.device.search.prop.basic.hardware", false)) {
+					this.newNodeInfo.setPlatformFamily(this.nodeInfo.getPlatformFamily());
+					this.newNodeInfo.setSubPlatformFamily(this.nodeInfo.getSubPlatformFamily());
+					this.newNodeInfo.setHardwareType(this.nodeInfo.getHardwareType());
+					this.newNodeInfo.setIconImage(this.nodeInfo.getIconImage());
+				}
+				// サーバ基本情報->ネットワーク
+				if (HinemosPropertyUtil.getHinemosPropertyBool("repository.device.search.prop.basic.network", true)) {
+					this.newNodeInfo.setIpAddressVersion(this.nodeInfo.getIpAddressVersion());
+					this.newNodeInfo.setIpAddressV4(this.nodeInfo.getIpAddressV4());
+					this.newNodeInfo.setIpAddressV6(this.nodeInfo.getIpAddressV6());
+					this.newNodeInfo.setNodeHostnameInfo(this.nodeInfo.getNodeHostnameInfo());
+				}
+				// サーバ基本情報->OS
+				if (HinemosPropertyUtil.getHinemosPropertyBool("repository.device.search.prop.basic.os", false)) {
+					this.newNodeInfo.setNodeName(this.nodeInfo.getNodeName());
+					this.newNodeInfo.setOsName(this.nodeInfo.getOsName());
+					this.newNodeInfo.setOsRelease(this.nodeInfo.getOsRelease());
+					this.newNodeInfo.setOsVersion(this.nodeInfo.getOsVersion());
+					this.newNodeInfo.setCharacterSet(this.nodeInfo.getCharacterSet());
+				}
+				// サーバ基本情報->Hinemosエージェント
+				if (HinemosPropertyUtil.getHinemosPropertyBool("repository.device.search.prop.basic.agent", false)) {
+					this.newNodeInfo.setAgentAwakePort(this.nodeInfo.getAgentAwakePort());
+				}
 			}
 			if (equalsCpu == false) {
 				this.newNodeInfo.setNodeCpuInfo(this.nodeInfo.getNodeCpuInfo());
