@@ -548,7 +548,7 @@ public class NodeCreateDialog extends CommonDialog {
 								NodeCreateDialog.this.m_managerComposite.getText(),
 								ipAddress, port, community, version,
 								PropertyDefineConstant.MODE_MODIFY, facilityId,
-								user, securityLevel, authPassword,
+								securityLevel, user, authPassword,
 								privPassword, authProtocol, privProtocol);
 
 						List<DeviceSearchMessageInfo> list = nodeSnmp.getDeviceSearchMessageInfo();
