@@ -117,6 +117,8 @@ public class FacilitySelector {
 		} finally {
 			_scopeNodeFacilityIdCacheLock.writeUnlock();
 		}
+		
+		m_log.info("Static Initialization [Thread : " + Thread.currentThread() + ", User : " + (String)HinemosSessionContext.instance().getProperty(HinemosSessionContext.LOGIN_USER_ID) + "]");
 	}
 	
 	/** ----- ファシリティの木情報のキャッシュ ----- */
@@ -1498,12 +1500,11 @@ public class FacilitySelector {
 	private static void refreshNodenameFacilityIdCache() {
 		long start = System.currentTimeMillis();
 		
+		HashMap<String, HashSet<String>> nodenameFacilityIdMap = new HashMap<String, HashSet<String>>();
 		try {
 			_nodenameFacilityIdCacheLock.writeLock();
 			
-			List<FacilityEntity> allNodes = QueryUtil.getAllNode();
-			
-			HashMap<String, HashSet<String>> nodenameFacilityIdMap = new HashMap<String, HashSet<String>>();
+			List<FacilityEntity> allNodes = QueryUtil.getAllNode_NONE();
 
 			for(FacilityEntity facility : allNodes){
 				NodeEntity node = facility.getNodeEntity();
@@ -1531,7 +1532,7 @@ public class FacilitySelector {
 			_nodenameFacilityIdCacheLock.writeUnlock();
 			
 			m_log.info("refresh nodenameFacilityIdMap(Cache). " +
-					(System.currentTimeMillis() - start) + "ms.");
+					(System.currentTimeMillis() - start) + "ms. key size=" + nodenameFacilityIdMap.size());
 		}
 	}
 	
@@ -1557,12 +1558,11 @@ public class FacilitySelector {
 	private static void refreshIpaddrFacilityIdCache() {
 		long start = System.currentTimeMillis();
 		
+		HashMap<InetAddress, HashSet<String>> inetAddressFacilityIdMap = new HashMap<InetAddress, HashSet<String>>();
 		try {
 			_ipaddrFacilityIdCacheLock.writeLock();
 			
-			List<FacilityEntity> allNodes = QueryUtil.getAllNode();
-
-			HashMap<InetAddress, HashSet<String>> inetAddressFacilityIdMap = new HashMap<InetAddress, HashSet<String>>();
+			List<FacilityEntity> allNodes = QueryUtil.getAllNode_NONE();
 
 			for(FacilityEntity facility : allNodes){
 				NodeEntity node = facility.getNodeEntity();
@@ -1602,7 +1602,7 @@ public class FacilitySelector {
 			_ipaddrFacilityIdCacheLock.writeUnlock();
 			
 			m_log.info("refresh inetAddressFacilityIdMap(Cache). " +
-					(System.currentTimeMillis() - start) + "ms.");
+					(System.currentTimeMillis() - start) + "ms. key size=" + inetAddressFacilityIdMap.size());
 		}
 	}
 	
@@ -1628,13 +1628,12 @@ public class FacilitySelector {
 	private static void refreshHostnameFacilityIdCache() {
 		long start = System.currentTimeMillis();
 		
+		HashMap<String, HashSet<String>> hostnameFacilityIdMap = new HashMap<String, HashSet<String>>();
 		try {
 			_hostnameFacilityIdCacheLock.writeLock();
 			
 			List<NodeHostnameEntity> allNodes = QueryUtil.getAllNodeHostname();
 
-			HashMap<String, HashSet<String>> hostnameFacilityIdMap = new HashMap<String, HashSet<String>>();
-
 			for(NodeHostnameEntity node : allNodes){
 				String facilityId = node.getId().getFacilityId();
 
@@ -1651,9 +1650,8 @@ public class FacilitySelector {
 				// その中にエンティティが含まれない場合は、該当ホスト名のノードは存在するが、全て無効だったことなる。
 				FacilityEntity entity = null;
 				try {
-					entity = QueryUtil.getFacilityPK(facilityId);
+					entity = QueryUtil.getFacilityPK_NONE(facilityId);
 				} catch (FacilityNotFound e) {
-				} catch (InvalidRole e) {
 				}
 				if(entity != null && entity.getValid() == ValidConstant.TYPE_VALID){
 					hostnameFacilityIdSet.add(facilityId);
@@ -1665,7 +1663,7 @@ public class FacilitySelector {
 			_hostnameFacilityIdCacheLock.writeUnlock();
 			
 			m_log.info("refresh hostnameFacilityIdMap(Cache). " +
-					(System.currentTimeMillis() - start) + "ms.");
+					(System.currentTimeMillis() - start) + "ms. key size=" + hostnameFacilityIdMap.size());
 		}
 	}
 
