@@ -16,13 +16,20 @@ PURPOSE.  See the GNU General Public License for more details.
 package com.clustercontrol.repository.view.action;
 
 import java.util.List;
+import java.util.Map;
 
-import org.eclipse.jface.action.IAction;
+import org.eclipse.core.commands.AbstractHandler;
+import org.eclipse.core.commands.ExecutionEvent;
+import org.eclipse.core.commands.ExecutionException;
 import org.eclipse.jface.dialogs.IDialogConstants;
-import org.eclipse.jface.viewers.ISelection;
 import org.eclipse.jface.viewers.StructuredSelection;
-import org.eclipse.ui.IViewActionDelegate;
-import org.eclipse.ui.IViewPart;
+import org.eclipse.ui.IWorkbenchPage;
+import org.eclipse.ui.IWorkbenchPart;
+import org.eclipse.ui.IWorkbenchWindow;
+import org.eclipse.ui.PlatformUI;
+import org.eclipse.ui.commands.IElementUpdater;
+import org.eclipse.ui.handlers.HandlerUtil;
+import org.eclipse.ui.menus.UIElement;
 
 import com.clustercontrol.repository.action.GetNodeListTableDefine;
 import com.clustercontrol.repository.dialog.NodeCreateDialog;
@@ -31,50 +38,53 @@ import com.clustercontrol.viewer.CommonTableViewer;
 
 /**
  * ノードの作成・変更ダイアログによる、ノード変更を行うクライアント側アクションクラス<BR>
- * 
- * @version 2.2.0
+ *
+ * @version 5.0.0
  * @since 1.0.0
  */
-public class NodeModifyAction implements IViewActionDelegate {
-	public static final String ID = "com.clustercontrol.repository.view.action.NodeModifyAction";
+public class NodeModifyAction extends AbstractHandler implements IElementUpdater {
+	public static final String ID = NodeModifyAction.class.getName();
 
 	//	 ----- instance フィールド ----- //
 
-	private IViewPart viewPart; // ビュー
+	private IWorkbenchPart viewPart;
+
+	/**
+	 * Dispose
+	 */
+	@Override
+	public void dispose() {
+		this.viewPart = null;
+	}
 
 	// ----- instance メソッド ----- //
 
 	/**
-	 * @see org.eclipse.ui.IViewActionDelegate#init(org.eclipse.ui.IViewPart)
+	 * @see org.eclipse.core.commands.IHandler#execute
 	 */
 	@Override
-	public void init(IViewPart viewPart) {
-		this.viewPart = viewPart;
-	}
+	public Object execute(ExecutionEvent event) throws ExecutionException {
+		this.viewPart = HandlerUtil.getActivePart(event);
 
-	/**
-	 * @see org.eclipse.ui.IActionDelegate#run(org.eclipse.jface.action.IAction)
-	 */
-	@Override
-	public void run(IAction action) {
 		// ノード一覧より、選択されているノードのファシリティIDを取得
-
 		NodeListView view = (NodeListView) this.viewPart
 				.getAdapter(NodeListView.class);
 
 		StructuredSelection selection = (StructuredSelection) view
 				.getComposite().getTableViewer().getSelection();
 
-		List list = (List) selection.getFirstElement();
+		List<?> list = (List<?>) selection.getFirstElement();
+		String managerName = null;
 		String facilityId = null;
 		if (list != null) {
+			managerName = (String) list.get(GetNodeListTableDefine.MANAGER_NAME);
 			facilityId = (String) list.get(GetNodeListTableDefine.FACILITY_ID);
 		}
 
 		if (facilityId != null) {
 			// ダイアログを生成
 			NodeCreateDialog dialog = new NodeCreateDialog(this.viewPart
-					.getSite().getShell(), facilityId, true);
+					.getSite().getShell(), managerName, facilityId, true);
 
 			// ダイアログにて変更が選択された場合、入力内容をもって更新を行う。
 			if (dialog.open() == IDialogConstants.OK_ID) {
@@ -85,13 +95,31 @@ public class NodeModifyAction implements IViewActionDelegate {
 				viewer.setSelection(viewer.getSelection());
 			}
 		}
+		return null;
 	}
 
-	/**
-	 * @see org.eclipse.ui.IActionDelegate#selectionChanged(org.eclipse.jface.action.IAction,
-	 *      org.eclipse.jface.viewers.ISelection)
-	 */
 	@Override
-	public void selectionChanged(IAction action, ISelection selection) {
+	public void updateElement(UIElement element, @SuppressWarnings("rawtypes") Map parameters) {
+		IWorkbenchWindow window = PlatformUI.getWorkbench().getActiveWorkbenchWindow();
+		// page may not start at state restoring
+		if( null != window ){
+			IWorkbenchPage page = window.getActivePage();
+			if( null != page ){
+				IWorkbenchPart part = page.getActivePart();
+
+				boolean editEnable = false;
+				if(part instanceof NodeListView){
+					// Enable button when 1 item is selected
+					NodeListView view = (NodeListView)part;
+
+					if(view.getSelectedNum() > 0) {
+						editEnable = true;
+					}
+				}
+				this.setBaseEnabled(editEnable);
+			} else {
+				this.setBaseEnabled(false);
+			}
+		}
 	}
-}
\ No newline at end of file
+}
