@@ -27,11 +27,12 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
 
+import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.bean.RequiredFieldColorConstant;
 import com.clustercontrol.bean.SnmpVersionConstant;
+import com.clustercontrol.monitor.bean.MonitorTypeMstConstant;
 import com.clustercontrol.monitor.run.dialog.CommonMonitorNumericDialog;
-import com.clustercontrol.notify.util.NotifyGroupIdGenerator;
 import com.clustercontrol.snmp.action.AddSnmp;
 import com.clustercontrol.snmp.action.GetSnmp;
 import com.clustercontrol.snmp.action.ModifySnmp;
@@ -42,7 +43,7 @@ import com.clustercontrol.ws.monitor.SnmpCheckInfo;
 
 /**
  * SNMP監視（数値）作成・変更ダイアログクラス<BR>
- * 
+ *
  * @version 4.0.0
  * @since 2.0.0
  */
@@ -56,42 +57,43 @@ public class SnmpNumericCreateDialog extends CommonMonitorNumericDialog {
 	/** 取得値の加工 */
 	private Combo m_comboConvertValue = null;
 
-
 	// ----- コンストラクタ ----- //
 
 	/**
 	 * 作成用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent
 	 *            親のシェルオブジェクト
 	 */
 	public SnmpNumericCreateDialog(Shell parent) {
-		super(parent);
+		super(parent, null);
 	}
 
 	/**
 	 * 作成用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent 親のシェルオブジェクト
 	 * @param monitorType 監視判定タイプ
 	 */
-	public SnmpNumericCreateDialog(Shell parent, int monitorType) {
-		super(parent);
+	public SnmpNumericCreateDialog(Shell parent, String managerName, int monitorType) {
+		super(parent, managerName);
 
+		this.managerName = managerName;
 		this.m_monitorType = monitorType;
 	}
 
 	/**
 	 * 変更用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent 親のシェルオブジェクト
 	 * @param monitorId 変更する監視項目ID
 	 * @param updateFlg 更新するか否か（true:変更、false:新規登録）
-	 * 
+	 *
 	 */
-	public SnmpNumericCreateDialog(Shell parent, String monitorId, boolean updateFlg) {
-		super(parent);
+	public SnmpNumericCreateDialog(Shell parent, String managerName, String monitorId, boolean updateFlg) {
+		super(parent, managerName);
 
+		this.managerName = managerName;
 		this.monitorId = monitorId;
 		this.updateFlg = updateFlg;
 	}
@@ -100,7 +102,7 @@ public class SnmpNumericCreateDialog extends CommonMonitorNumericDialog {
 
 	/**
 	 * ダイアログエリアを生成します。
-	 * 
+	 *
 	 * @param parent
 	 *            親のインスタンス
 	 */
@@ -124,13 +126,14 @@ public class SnmpNumericCreateDialog extends CommonMonitorNumericDialog {
 		 * チェック設定グループ（条件グループの子グループ）
 		 */
 		Group groupCheckRule = new Group(groupRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "checkrule", groupCheckRule);
 		GridLayout layout = new GridLayout(1, true);
-		layout.marginWidth = 5;
-		layout.marginHeight = 5;
-		layout.numColumns = 15;
+		layout.marginWidth = HALF_MARGIN;
+		layout.marginHeight = HALF_MARGIN;
+		layout.numColumns = BASIC_UNIT;
 		groupCheckRule.setLayout(layout);
 		gridData = new GridData();
-		gridData.horizontalSpan = 15;
+		gridData.horizontalSpan = BASIC_UNIT;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		groupCheckRule.setLayoutData(gridData);
@@ -141,16 +144,18 @@ public class SnmpNumericCreateDialog extends CommonMonitorNumericDialog {
 		 */
 		// ラベル
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "oid", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_TITLE;
+		gridData.horizontalSpan = WIDTH_TITLE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
 		label.setText(Messages.getString("oid") + " : ");
 		// テキスト
 		this.m_textOid = new Text(groupCheckRule, SWT.BORDER | SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "oid", m_textOid);
 		gridData = new GridData();
-		gridData.horizontalSpan = 8;
+		gridData.horizontalSpan = WIDTH_TEXT_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.m_textOid.setLayoutData(gridData);
@@ -164,7 +169,7 @@ public class SnmpNumericCreateDialog extends CommonMonitorNumericDialog {
 		// 空白
 		label = new Label(groupCheckRule, SWT.NONE);
 		gridData = new GridData();
-		gridData.horizontalSpan = 2;
+		gridData.horizontalSpan = WIDTH_VALUE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
@@ -175,15 +180,16 @@ public class SnmpNumericCreateDialog extends CommonMonitorNumericDialog {
 		// ラベル
 		label = new Label(groupCheckRule, SWT.NONE);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_TITLE;
+		gridData.horizontalSpan = WIDTH_TITLE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
 		label.setText(Messages.getString("convert.value") + " : ");
 		// コンボボックス
 		this.m_comboConvertValue = new Combo(groupCheckRule, SWT.DROP_DOWN | SWT.READ_ONLY);
+		WidgetTestUtil.setTestId(this, "convertvalue", m_comboConvertValue);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_VALUE * 2;
+		gridData.horizontalSpan = WIDTH_TEXT;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.m_comboConvertValue.setLayoutData(gridData);
@@ -193,17 +199,11 @@ public class SnmpNumericCreateDialog extends CommonMonitorNumericDialog {
 		// 空白
 		label = new Label(groupCheckRule, SWT.NONE);
 		gridData = new GridData();
-		gridData.horizontalSpan = 6;
+		gridData.horizontalSpan = 12;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
 
-		// 収集値表示名のデフォルト値を設定
-		this.itemName.setText(Messages.getString("select.value"));
-
-		// 収集値単位のデフォルト値を設定
-		this.measure.setText("");
-
 		// ダイアログを調整
 		this.adjustDialog();
 
@@ -216,14 +216,14 @@ public class SnmpNumericCreateDialog extends CommonMonitorNumericDialog {
 		}
 		else{
 			// 変更の場合、情報取得
-			info = new GetSnmp().getSnmp(this.monitorId);
+			info = new GetSnmp().getSnmp(this.getManagerName(), this.monitorId, MonitorTypeMstConstant.MONITOR_TYPE_NUMERIC);
 		}
 		this.setInputData(info);
 	}
 
 	/**
 	 * 更新処理
-	 * 
+	 *
 	 */
 	@Override
 	public void update(){
@@ -239,7 +239,7 @@ public class SnmpNumericCreateDialog extends CommonMonitorNumericDialog {
 
 	/**
 	 * 各項目に入力値を設定します。
-	 * 
+	 *
 	 * @param monitor
 	 *            設定値として用いる監視情報
 	 */
@@ -275,7 +275,7 @@ public class SnmpNumericCreateDialog extends CommonMonitorNumericDialog {
 
 	/**
 	 * 入力値を用いて通知情報を生成します。
-	 * 
+	 *
 	 * @return 入力値を保持した通知情報
 	 */
 	@Override
@@ -286,13 +286,13 @@ public class SnmpNumericCreateDialog extends CommonMonitorNumericDialog {
 		}
 
 		//SNMP監視固有情報を設定
-		monitorInfo.setMonitorTypeId(HinemosModuleConstant.MONITOR_SNMP);
+		monitorInfo.setMonitorTypeId(HinemosModuleConstant.MONITOR_SNMP_N);
 
 		// 監視条件 SNMP監視情報
 		SnmpCheckInfo snmpInfo = new SnmpCheckInfo();
 		snmpInfo.setConvertFlg(ConvertValueConstant.TYPE_DELTA);
 		snmpInfo.setSnmpVersion(SnmpVersionConstant.STRING_V1);
-		snmpInfo.setMonitorTypeId(HinemosModuleConstant.MONITOR_SNMP);
+		snmpInfo.setMonitorTypeId(HinemosModuleConstant.MONITOR_SNMP_N);
 		snmpInfo.setMonitorId(monitorInfo.getMonitorId());
 
 		if (this.m_textOid.getText() != null
@@ -309,8 +309,6 @@ public class SnmpNumericCreateDialog extends CommonMonitorNumericDialog {
 		monitorInfo.setSnmpCheckInfo(snmpInfo);
 
 		// 通知関連情報とアプリケーションの設定
-		// 通知グループIDの設定
-		monitorInfo.setNotifyGroupId(NotifyGroupIdGenerator.createNotifyGroupId(HinemosModuleConstant.MONITOR_SNMP, monitorInfo.getMonitorId()));
 		validateResult = m_notifyInfo.createInputData(monitorInfo);
 		if (validateResult != null) {
 			if(validateResult.getID() == null){	// 通知ID警告用出力
@@ -335,9 +333,9 @@ public class SnmpNumericCreateDialog extends CommonMonitorNumericDialog {
 
 	/**
 	 * 入力値をマネージャに登録します。
-	 * 
+	 *
 	 * @return true：正常、false：異常
-	 * 
+	 *
 	 * @see com.clustercontrol.dialog.CommonDialog#action()
 	 */
 	@Override
@@ -345,14 +343,15 @@ public class SnmpNumericCreateDialog extends CommonMonitorNumericDialog {
 		boolean result = false;
 
 		MonitorInfo info = this.inputData;
+		String managerName = this.getManagerName();
 		if(info != null){
 			if(!this.updateFlg){
 				// 作成の場合
-				result = new AddSnmp().add(info);
+				result = new AddSnmp().add(managerName, info);
 			}
 			else{
 				// 変更の場合
-				result = new ModifySnmp().modify(info);
+				result = new ModifySnmp().modify(managerName, info);
 			}
 		}
 
@@ -361,7 +360,7 @@ public class SnmpNumericCreateDialog extends CommonMonitorNumericDialog {
 
 	/**
 	 * MonitorInfoに初期値を設定します
-	 * 
+	 *
 	 * @see com.clustercontrol.dialog.CommonMonitorDialog#setInfoInitialValue()
 	 */
 	@Override
@@ -374,4 +373,4 @@ public class SnmpNumericCreateDialog extends CommonMonitorNumericDialog {
 		snmpCheckInfo.setSnmpVersion(SnmpVersionConstant.STRING_V1);
 		monitor.setSnmpCheckInfo(snmpCheckInfo);
 	}
-}
\ No newline at end of file
+}
