@@ -412,6 +412,21 @@ AsnInteger GetMemTotalSwap(){
 
 	ret = (long)((memstatex.ullTotalPageFile  - memstatex.ullTotalPhys) / DIV_MEMORY);
 
+	/*
+	memstatex.ullTotalPageFile = 物理メモリ + ページングファイル - オーバヘッド
+	memstatex.ullTotalPhys     = 物理メモリ
+	(オーバヘッドはメモリサイズが2GB以上の場合に用意される様子。)
+	
+	ret = memstatex.ullTotalPageFile - memstatex.ullTotalPhys = ページングファイル - オーバヘッド
+	ページングファイルが0の場合は、GetMemTotalSwapがマイナスになってしまうため、
+	ret < 0の場合はret=0にする。
+	
+	注:本来はオーバヘッドの値を取ってくるべきだが、その方法がわからず。。。
+	*/
+	if (ret < 0) {
+		ret = 0;
+	}
+
 	if(verbose == 1){
 		PostEvtLogDWORDLONG( EVENTLOG_INFORMATION_TYPE, "GetMemTotalSwap", "GlobalMemoryStatusEx ullTotalPageFile", memstatex.ullTotalPageFile);
 		PostEvtLogDWORDLONG( EVENTLOG_INFORMATION_TYPE, "GetMemTotalSwap", "GlobalMemoryStatusEx ullTotalPhys", memstatex.ullTotalPhys);
@@ -941,13 +956,21 @@ double GetPagingFileUsage(void) {
 	
 	// カウンタ値を更新
 	status = PdhCollectQueryData(hQuery);
-	if(verbose == 1 && CheckErrorCode(status) && status != 0x800007d5){	// PDH_NO_DATA(0x800007d5)の場合はイベントを出さない
+	// PDH_NO_DATA(0x800007d5)の場合はページングファイル使用率を0とする。
+	if(status == 0x800007d5) {
+		return 0;
+	}
+	if(verbose == 1 && CheckErrorCode(status)){
 		PostEvtLog( errorEventLevel, "GetPagingFileUsage", "PdhCollectQueryData", status);
 	}
 
 	// カウンタ値を取得
 	status = PdhGetFormattedCounterValue(hCounter, PDH_FMT_DOUBLE, NULL, &fmtValue);
-	if(verbose == 1 && CheckErrorCode(status) && status != 0xC0000BC6){	// PDH_INVALID_DATA(0xC0000BC6)場合(スワップなし設定)はイベントを出さない
+	// PDH_INVALID_DATA(0xC0000BC6)場合(ページングファイルなし設定)はページングファイル使用率を0とする。
+	if(status == 0xC0000BC6) {
+		return 0;
+	}
+	if(verbose == 1 && CheckErrorCode(status)){
 		PostEvtLog( errorEventLevel, "GetPagingFileUsage", "PdhGetFormattedCounterValue", status);
 	}
 
