@@ -71,7 +71,7 @@ AsnInteger GetLaLoadInt1(void);
 AsnInteger GetLaLoadInt2(void);
 AsnInteger GetLaLoadInt3(void);
 
-AsnCounter GetDiskIOIndex(char *);
+AsnInteger GetDiskIOIndex(char *);
 char *	   GetDiskIODevice(char *);
 AsnCounter GetDiskIORead(char *);
 AsnCounter GetDiskIOWrite(char *);
