@@ -21,6 +21,7 @@ import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.bean.PriorityConstant;
+import com.clustercontrol.fault.HinemosUnknown;
 import com.clustercontrol.fault.MonitorNotFound;
 import com.clustercontrol.monitor.run.bean.MonitorJudgementInfo;
 import com.clustercontrol.monitor.run.factory.RunMonitor;
@@ -83,15 +84,7 @@ public class RunMonitorWinService extends RunMonitorTruthValueType {
 				return false;
 			}
 
-			// バージョンを先に読み込んでIPv4とIPv6のどちらを読み出すか選択する。
-			Integer ipProtNum = info.getIpAddressVersion();
-
-			String ipAddress = "";
-			if (ipProtNum != null && ipProtNum == 6) {
-				ipAddress = info.getIpAddressV6();
-			} else {
-				ipAddress = info.getIpAddressV4();
-			}
+			String ipAddress = info.getAvailableIpAddress();
 
 			String user = info.getWinrmUser();
 			String userPassword = info.getWinrmUserPassword();
@@ -114,7 +107,7 @@ public class RunMonitorWinService extends RunMonitorTruthValueType {
 			m_nodeDate = m_request.getDate();
 
 			return true;
-		} catch (WsmanException e) {
+		} catch (WsmanException | HinemosUnknown e) {
 			// 不明
 			m_message = "unknown error . facilityId = " + m_facilityId;
 			m_messageOrg = "unknown error . facilityId = " + m_facilityId + ". " + e.getMessage();
